---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2011-06-23;118
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20110726&codiceRedaz=011G0160&dataVigenza=20251104
dataGU: 20110726
codiceRedaz: 011G0160
dataVigenza: 20251104
---

# Disposizioni in materia di armonizzazione dei sistemi contabili e degli schemi di bilancio delle Regioni, degli enti locali e dei loro organismi, a norma degli articoli 1 e 2 della legge 5 maggio 2009, n. 42. (11G0160)

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76, 87, 117 e 119 della Costituzione;

Vista la legge 5 maggio 2009, n. 42, recante delega al Governo in materia di federalismo fiscale, in attuazione dell'articolo 119 della Costituzione, e in particolare l'articolo 2, comma 1 e comma 2, lettera h);

Vista la legge 31 dicembre 2009, n. 196, recante la legge di contabilita' e finanza pubblica e, in particolare, l'articolo 1, comma 4, e l'articolo 2, comma 6;

Vista la preliminare deliberazione del Consiglio dei Ministri, adottata nella riunione del 17 dicembre 2010;

Vista l'intesa sancita in Conferenza unificata ai sensi dell'articolo 3 del decreto legislativo 28 agosto 1997, n. 281, nella riunione del 3 marzo 2011;

Visti il parere della Commissione parlamentare per l'attuazione del federalismo fiscale di cui all'articolo 3 della legge 5 maggio 2009, n. 42 e i pareri delle Commissioni parlamentari competenti per le conseguenze di carattere finanziario della Camera dei deputati e del Senato della Repubblica;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 9 giugno 2011;

Sulla proposta del Ministro dell'economia e delle finanze, del Ministro per le riforme per il federalismo, del Ministro per la semplificazione normativa e del Ministro per i rapporti con le regioni e per la coesione territoriale, di concerto con i Ministri dell'interno, della salute e per la pubblica amministrazione e l'innovazione;

Emana il seguente decreto legislativo:

## Principi contabili generali e applicati per le regioni, le province autonome e gli enti locali

### Art. 1. - Oggetto e ambito di applicazione

((

1. Ai sensi dell'art. 117, secondo comma, lettera e), della Costituzione, il presente titolo e il titolo III disciplinano l'armonizzazione dei sistemi contabili e degli schemi di bilancio delle Regioni, ad eccezione dei casi in cui il Titolo II disponga diversamente, con particolare riferimento alla fattispecie di cui all'art. 19, comma 2, lettera b), degli enti locali di cui all'art. 2 del decreto legislativo 18 agosto 2000, n. 267, e dei loro enti e organismi strumentali, esclusi gli enti di cui al titolo II del presente decreto. A decorrere dal 1° gennaio 2015 cessano di avere efficacia le disposizioni legislative regionali incompatibili con il presente decreto.

2. Ai fini del presente decreto:

- a) per enti strumentali si intendono gli enti di cui all'art. 11-ter, distinti nelle tipologie definite in corrispondenza delle missioni del bilancio;
- b) per organismi strumentali delle regioni e degli enti locali si intendono le loro articolazioni organizzative, anche a livello territoriale, dotate di autonomia gestionale e contabile, prive di personalita' giuridica. Le gestioni fuori bilancio autorizzate da legge e le istituzioni di cui all'art. 114, comma 2, del decreto legislativo 18 agosto 2000, n. 267, sono organismi strumentali. Gli organismi strumentali sono distinti nelle tipologie definite in corrispondenza delle missioni del bilancio.

))

3. ((COMMA ABROGATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).

4. ((COMMA ABROGATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).

5. Per gli enti coinvolti nella gestione della spesa sanitaria finanziata con le risorse destinate al Servizio sanitario nazionale, come individuati all'articolo 19, si applicano le disposizioni recate dal Titolo II.

### Art. 2. - Adozione di sistemi contabili omogenei

1. Le Regioni e gli enti locali di cui all'articolo 2 del decreto legislativo 18 agosto 2000, n. 267 adottano la contabilita' finanziaria cui affiancano, ai fini conoscitivi, un sistema di contabilita' economico-patrimoniale, garantendo la rilevazione unitaria dei fatti gestionali sia sotto il profilo finanziario che sotto il profilo economico-patrimoniale.

2. Gli enti strumentali delle amministrazioni di cui al comma 1 che adottano la contabilita' finanziaria affiancano alla stessa, ai fini conoscitivi, un sistema di contabilita' economico-patrimoniale, garantendo la rilevazione unitaria dei fatti gestionali, sia sotto il profilo finanziario che sotto il profilo economico-patrimoniale.

3. Le istituzioni degli enti locali di cui all'articolo 114 del decreto legislativo 18 agosto 2000, n. 267 e gli altri organismi strumentali delle amministrazioni pubbliche di cui al comma 1 adottano il medesimo sistema contabile dell' amministrazione di cui fanno parte. 4.((COMMA ABROGATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).

### Art. 3. - Principi contabili generali e applicati

1. Le amministrazioni pubbliche di cui all'art. 2, conformano la propria gestione ai principi contabili generali contenuti nell'allegato 1 ed ai seguenti principi contabili applicati, che costituiscono parte integrante al presente decreto:

- a) della programmazione (allegato n. 4/1);
- b) della contabilita' finanziaria (allegato n. 4/2);
- c) della contabilita' economico-patrimoniale (allegato n. 4/3);
- d) del bilancio consolidato (allegato n. 4/4).

2. I principi applicati di cui al comma 1 garantiscono il consolidamento e la trasparenza dei conti pubblici secondo le direttive dell'Unione europea e l'adozione di sistemi informativi omogenei e interoperabili.

3. Gli enti strumentali delle amministrazioni di cui all'art. 2, comma 1, che adottano la contabilita' economico-patrimoniale conformano la propria gestione ai principi contabili generali contenuti nell' allegato 1 e ai principi del codice civile.

4. Al fine di dare attuazione al principio contabile generale della competenza finanziaria enunciato nell'allegato 1, gli enti di cui al comma 1 provvedono, annualmente, al riaccertamento dei residui attivi e passivi, verificando, ai fini del rendiconto, le ragioni del loro mantenimento. Le regioni escludono dal riaccertamento ordinario dei residui quelli derivanti dal perimetro sanitario cui si applica il titolo II e, fino al 31 dicembre 2015, i residui passivi finanziati da debito autorizzato e non contratto. Possono essere conservati tra i residui attivi le entrate accertate esigibili nell'esercizio di riferimento, ma non incassate. Possono essere conservate tra i residui passivi le spese impegnate, liquidate o liquidabili nel corso dell'esercizio, ma non pagate. Le entrate e le spese accertate e impegnate non esigibili nell'esercizio considerato, sono immediatamente reimputate all'esercizio in cui sono esigibili. La reimputazione degli impegni e' effettuata incrementando, di pari importo, il fondo pluriennale di spesa, al fine di consentire, nell'entrata degli esercizi successivi, l'iscrizione del fondo pluriennale vincolato a copertura delle spese reimputate. La costituzione del fondo pluriennale vincolato non e' effettuata in caso di reimputazione contestuale di entrate e di spese. Le variazioni agli stanziamenti del fondo pluriennale vincolato e agli stanziamenti correlati, dell'esercizio in corso e dell'esercizio precedente, necessarie alla reimputazione delle entrate e delle spese riaccertate, sono effettuate con provvedimento amministrativo della giunta entro i termini previsti per l'approvazione del rendiconto dell'esercizio precedente. Il riaccertamento ordinario dei residui e' effettuato anche nel corso dell'esercizio provvisorio o della gestione provvisoria. Al termine delle procedure di riaccertamento non sono conservati residui cui non corrispondono obbligazioni giuridicamente perfezionate.

4-bis. Le regioni che hanno partecipato alla sperimentazione nell'anno 2014, nell'ambito del riaccertamento ordinario effettuato nel 2015 ai fini del rendiconto 2014, provvedono al riaccertamento dei residui attivi e passivi relativi alla politica regionale unitaria --- cooperazione territoriale non effettuato in occasione del riaccertamento straordinario effettuato ai sensi dell'articolo 14 del decreto del Presidente del Consiglio dei ministri 28 dicembre 2011, pubblicato nel supplemento ordinario n. 285 alla Gazzetta Ufficiale n. 304 del 31 dicembre 2011.

5. Al fine di dare attuazione al principio contabile generale della competenza finanziaria enunciato nell'allegato 1 al presente decreto, gli enti di cui al comma 1, a decorrere dall'anno 2015, iscrivono negli schemi di bilancio di cui all'art. 11, comma 1, lettere a) e b), il fondo per la copertura degli impegni pluriennali derivanti da obbligazioni sorte negli esercizi precedenti, di seguito denominato fondo pluriennale vincolato, costituito:

- a) in entrata, da due voci riguardanti la parte corrente e il conto capitale del fondo, per un importo corrispondente alla sommatoria degli impegni assunti negli esercizi precedenti ed imputati sia all'esercizio considerato sia agli esercizi successivi, finanziati da risorse accertate negli esercizi precedenti, determinato secondo le modalita' indicate nel principio applicato della programmazione, di cui all'allegato 4/1;
- b) nella spesa, da una voce denominata «fondo pluriennale vincolato», per ciascuna unita' di voto riguardante spese a carattere pluriennale e distintamente per ciascun titolo di spesa. Il fondo e' determinato per un importo pari alle spese che si prevede di impegnare nel corso del primo anno considerato nel bilancio, con imputazione agli esercizi successivi e alle spese gia' impegnate negli esercizi precedenti con imputazione agli esercizi successivi a quello considerato. La copertura della quota del fondo pluriennale vincolato riguardante le spese impegnate negli esercizi precedenti e' costituita dal fondo pluriennale iscritto in entrata, mentre la copertura della quota del fondo pluriennale vincolato riguardante le spese che si prevede di impegnare nell'esercizio di riferimento con imputazione agli esercizi successivi, e' costituita dalle entrate che si prevede di accertare nel corso dell'esercizio di riferimento. Agli stanziamenti di spesa riguardanti il fondo pluriennale vincolato e' attribuito il codice della missione e del programma di spesa cui il fondo si riferisce e il codice del piano dei conti relativo al fondo pluriennale vincolato. Nel corso dell'esercizio, sulla base dei risultati del rendiconto, e' determinato l'importo definivo degli stanziamenti riguardanti il fondo pluriennale vincolato e degli impegni assunti negli esercizi precedenti di cui il fondo pluriennale vincolato costituisce la copertura.

6. I principi contabili applicati di cui al comma 1 sono aggiornati con decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, di concerto con il Ministero dell'interno - Dipartimento per gli affari interni e territoriali e la Presidenza del Consiglio dei ministri - Dipartimento per gli affari regionali, su proposta della Commissione per l'armonizzazione contabile degli enti territoriali di cui all'art. 3-bis.

7. Al fine di adeguare i residui attivi e passivi risultanti al 1° gennaio 2015 al principio generale della competenza finanziaria enunciato nell'allegato n. 1, le amministrazioni pubbliche di cui al comma 1, ((...)) con delibera di Giunta, previo parere dell'organo di revisione economico-finanziario, provvedono, contestualmente all'approvazione del rendiconto 2014, al riaccertamento straordinario dei residui, consistente:

- a) nella cancellazione dei propri residui attivi e passivi, cui non corrispondono obbligazioni perfezionate e scadute alla data del 1° gennaio 2015. Non sono cancellati i residui delle regioni derivanti dal perimetro sanitario cui si applica il titolo II e i residui passivi finanziati da debito autorizzato e non contratto. Per ciascun residuo eliminato in quanto non scaduto sono indicati gli esercizi nei quali l'obbligazione diviene esigibile, secondo i criteri individuati nel principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2. Per ciascun residuo passivo eliminato in quanto non correlato a obbligazioni giuridicamente perfezionate, e' indicata la natura della fonte di copertura;
- b) nella conseguente determinazione del fondo pluriennale vincolato da iscrivere in entrata del bilancio dell'esercizio 2015, distintamente per la parte corrente e per il conto capitale, per un importo pari alla differenza tra i residui passivi ed i residui attivi eliminati ai sensi della lettera a), se positiva, e nella rideterminazione del risultato di amministrazione al 1° gennaio 2015 a seguito del riaccertamento dei residui di cui alla lettera a);
- c) nella variazione del bilancio di previsione annuale 2015 autorizzatorio, del bilancio pluriennale 2015-2017 autorizzatorio e del bilancio di previsione finanziario 2015-2017 predisposto con funzione conoscitiva, in considerazione della cancellazione dei residui di cui alla lettera a). In particolare gli stanziamenti di entrata e di spesa degli esercizi 2015, 2016 e 2017 sono adeguati per consentire la reimputazione dei residui cancellati e l'aggiornamento degli stanziamenti riguardanti il fondo pluriennale vincolato;
- d) nella reimputazione delle entrate e delle spese cancellate in attuazione della lettera a), a ciascuno degli esercizi in cui l'obbligazione e' esigibile, secondo i criteri individuati nel principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2. La copertura finanziaria delle spese reimpegnate cui non corrispondono entrate riaccertate nel medesimo esercizio e' costituita dal fondo pluriennale vincolato, salvi i casi di disavanzo tecnico di cui al comma 13;
- e) nell'accantonamento di una quota del risultato di amministrazione al 1° gennaio 2015, rideterminato in attuazione di quanto previsto dalla lettera b), al fondo crediti di dubbia esigibilita'. L'importo del fondo e' determinato secondo i criteri indicati nel principio applicato della contabilita' finanziaria di cui all'allegato n. 4.2. Tale vincolo di destinazione opera anche se il risultato di amministrazione non e' capiente o e' negativo (disavanzo di amministrazione).

8. L'operazione di riaccertamento di cui al comma 7 e' oggetto di un unico atto deliberativo. Al termine del riaccertamento straordinario dei residui non sono conservati residui cui non corrispondono obbligazioni giuridicamente perfezionate e esigibili. La delibera di giunta di cui al comma 7, cui sono allegati i prospetti riguardanti la rideterminazione del fondo pluriennale vincolato e del risultato di amministrazione, secondo lo schema di cui agli allegati 5/1 e 5/2, e' tempestivamente trasmessa al Consiglio. In caso di mancata deliberazione del riaccertamento straordinario dei residui al 1° gennaio 2015, contestualmente all'approvazione del rendiconto 2014, agli enti locali si applica la procedura prevista dal comma 2, primo periodo, dell'art. 141 del decreto legislativo 18 agosto 2000, n. 267. ((7))

9. Il riaccertamento straordinario dei residui di cui al comma 7 e' effettuato anche in caso di esercizio provvisorio o di gestione provvisoria del bilancio, registrando nelle scritture contabili le reimputazioni di cui al comma 7, lettera d), anche nelle more dell'approvazione dei bilanci di previsione. Il bilancio di previsione eventualmente approvato successivamente al riaccertamento dei residui e' predisposto tenendo conto di tali registrazioni.

10. La quota libera del risultato di amministrazione al 31 dicembre 2014 non e' applicata al bilancio di previsione 2015 in attesa del riaccertamento straordinario dei residui di cui al comma 7, esclusi gli enti che, nel 2014, hanno partecipato alla sperimentazione di cui all'art. 74, che applicano i principi applicati della contabilita' finanziaria di cui all'allegato 4/2.

11. Il principio generale n. 16 della competenza finanziaria di cui all'allegato n. 1 e' applicato con riferimento a tutte le operazioni gestionali registrate nelle scritture finanziarie di esercizio, che nel 2015, sono rappresentate anche negli schemi di bilancio di cui all'art. 11, comma 12.

12. L'adozione dei principi applicati della contabilita' economico-patrimoniale e il conseguente affiancamento della contabilita' economico patrimoniale alla contabilita' finanziaria previsto dall'art. 2, commi 1 e 2, unitamente all'adozione del piano dei conti integrato di cui all'art. 4, puo' essere rinviata all'anno 2016, con l'esclusione degli enti che nel 2014 hanno partecipato alla sperimentazione di cui all'art. 78.

13. Nel caso in cui a seguito del riaccertamento straordinario di cui al comma 7, i residui passivi reimputati ad un esercizio sono di importo superiore alla somma del fondo pluriennale vincolato stanziato in entrata e dei residui attivi reimputati al medesimo esercizio, tale differenza puo' essere finanziata con le risorse dell'esercizio o costituire un disavanzo tecnico da coprirsi, nei bilanci degli esercizi successivi con i residui attivi reimputati a tali esercizi eccedenti rispetto alla somma dei residui passivi reimputati e del fondo pluriennale vincolato di entrata. Gli esercizi per i quali si e' determinato il disavanzo tecnico possono essere approvati in disavanzo di competenza, per un importo non superiore al disavanzo tecnico.

14. Nel caso in cui a seguito del riaccertamento straordinario di cui al comma 7, i residui attivi reimputati ad un esercizio sono di importo superiore alla somma del fondo pluriennale vincolato stanziato in entrata e dei residui passivi reimputati nel medesimo esercizio, tale differenza e' vincolata alla copertura dell'eventuale eccedenza degli impegni reimputati agli esercizi successivi rispetto alla somma del fondo pluriennale vincolato di entrata e dei residui attivi. Nel bilancio di previsione dell'esercizio in cui si verifica tale differenza e' effettuato un accantonamento di pari importo agli stanziamenti di spesa del fondo pluriennale vincolato.

15. Le modalita' e i tempi di copertura dell'eventuale maggiore disavanzo al 1° gennaio 2015 rispetto al risultato di amministrazione al 31 dicembre 2014, derivante dalla rideterminazione del risultato di amministrazione a seguito dell'attuazione del comma 7, sono definiti con decreto del Ministero dell'economia e delle finanze, di concerto con il Ministero dell'interno, in considerazione dei risultati al 1° gennaio 2015 e prevedendo incentivi, anche attraverso la disciplina del patto di stabilita' interno e dei limiti di spesa del personale, per gli enti che, alla data del 31 dicembre 2017, non presentano quote di disavanzo derivanti dal riaccertamento straordinario dei residui. Per le regioni non rilevano i disavanzi derivanti dal debito autorizzato non contratto. Sulla base dei rendiconti delle regioni e dei consuntivi degli enti locali relativi all'anno 2014 e delle delibere di riaccertamento straordinario dei residui sono acquisite le informazioni riguardanti il maggiore disavanzo al 1º gennaio 2015 e quelle relative agli enti che hanno partecipato alla sperimentazione, incluso l'importo dell'accantonamento al fondo crediti di dubbia esigibilita', con tempi e modalita' definiti con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro dell'interno e sentita la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, e successive modificazioni. In base alle predette informazioni sono definiti i tempi di copertura del maggiore disavanzo, secondo modalita' differenziate in considerazione dell'entita' del fenomeno e della dimensione demografica e di bilancio dei singoli enti. Gli enti che non trasmettono le predette informazioni secondo le modalita' e i tempi previsti dal decreto di cui al terzo periodo ripianano i disavanzi nei tempi piu' brevi previsti dal decreto di cui al primo periodo.

16. Nelle more dell'emanazione del decreto di cui al comma 15, l'eventuale maggiore disavanzo di amministrazione al 1° gennaio 2015, determinato dal riaccertamento straordinario dei residui effettuato a seguito dell'attuazione del comma 7 e dal primo accantonamento al fondo crediti di dubbia esigibilita' e' ripianato in non piu' di 30 esercizi a quote costanti. In attesa del decreto di cui al comma 15, sono definiti criteri e modalita' di ripiano dell'eventuale disavanzo di amministrazione di cui al periodo precedente, attraverso un decreto del Ministero dell'economia e delle finanze, di concerto con il Ministero dell'interno, previa intesa in sede di Conferenza unificata. Tale decreto si attiene ai seguenti criteri:

- a) utilizzo di quote accantonate o destinate del risultato di amministrazione per ridurre la quota del disavanzo di amministrazione;
- b) ridefinizione delle tipologie di entrata utilizzabili ai fini del ripiano del disavanzo;
- c) individuazione di eventuali altre misure finalizzate a conseguire un sostenibile passaggio alla disciplina contabile prevista dal presente decreto.

17. Il decreto di cui al comma 15 estende gli incentivi anche agli enti che hanno partecipato alla sperimentazione prevista dall'art. 78 se, alla data del 31 dicembre 2015, non presentano quote di disavanzo risalenti all'esercizio 2012. Nelle more dell'adozione del decreto di cui al comma 15, la copertura dell'eventuale disavanzo di amministrazione di cui all'art. 14, commi 2 e 3, del decreto del Presidente del Consiglio dei ministri 28 dicembre 2011, puo' essere effettuata fino all'esercizio 2042 da parte degli enti coinvolti nella sperimentazione che hanno effettuato il riaccertamento straordinario dei residui nel 2012, e fino al 2043 da parte degli enti coinvolti nella sperimentazione che hanno effettuato il riaccertamento straordinario dei residui al 1º gennaio 2014.

((17-bis. Gli enti che hanno partecipato alla sperimentazione hanno la facolta' di procedere ad un nuovo riaccertamento straordinario al 1° gennaio 2015 di cui al comma 7, lettera a), limitatamente alla cancellazione dei residui attivi e passivi che non corrispondono ad obbligazioni perfezionate, compilando il prospetto di cui all'allegato n. 5/2 riguardante la determinazione del risultato di amministrazione all'1 gennaio 2015. Con il decreto di cui al comma 16 e' disciplinata la modalita' di ripiano dell'eventuale maggiore disavanzo in non piu' di 30 esercizi in quote costanti, compreso l'accantonamento al fondo crediti di dubbia esigibilita'.))

------------- AGGIORNAMENTO (7) Il D.L. 19 giugno 2015, n. 78, convertito con modificazioni dalla L. 6 agosto 2015, n. 125 ha disposto (con l'art. 2, comma 1) che "In deroga a quanto previsto dall'articolo 3, comma 8, del decreto legislativo n. 118 del 2011, e successive modificazioni, la procedura prevista dal comma 2, primo periodo, dell'articolo 141 del decreto legislativo 18 agosto 2000, n. 267, eventualmente gia' avviata, cessa di avere efficacia nei confronti degli enti locali che deliberano il riaccertamento straordinario dei residui al 1° gennaio 2015 entro il 15 giugno 2015".

### Art. 3-bis. - (( (Commissione per l'armonizzazione degli enti territoriali).))

((

1. Presso il Ministero dell'economia e delle finanze e' istituita, senza nuovi o maggiori oneri per la finanza pubblica, la Commissione per l'armonizzazione degli enti territoriali.

2. La Commissione di cui al comma 1 ha il compito di promuovere l'armonizzazione dei sistemi contabili e degli schemi di bilancio degli enti territoriali e dei loro organismi e enti strumentali, esclusi gli enti coinvolti nella gestione della spesa sanitaria finanziata con le risorse destinate al Servizio sanitario nazionale, e di aggiornare gli allegati al titolo I del presente decreto in relazione al processo evolutivo delle fonti normative che concorrono a costituirne il presupposto e alle esigenze del monitoraggio e del consolidamento dei conti pubblici, nonche' del miglioramento della raccordabilita' dei conti delle amministrazioni pubbliche con il Sistema europeo dei conti nazionali. La Commissione agisce in reciproco raccordo con l'Osservatorio sulla finanza e la contabilita' degli enti locali di cui all'art. 154 del decreto legislativo 18 agosto 2000, n. 267.

3. Con decreto del Ministro dell'economia e delle finanze sono disciplinate le modalita' di organizzazione e di funzionamento della Commissione di cui al comma 1 cui possono essere attribuite ulteriori funzioni nell'ambito delle finalita' generali del comma 2.

4. La Commissione di cui al comma 1 si avvale delle strutture e dell'organizzazione del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria Generale dello stato. Ai componenti della Commissione non e' corrisposto alcun compenso, ne' indennita', ne' rimborso di spese.

))

### Art. 4. - Piano dei conti integrato

1. Al fine di consentire il consolidamento ed il monitoraggio dei conti pubblici, nonche' il miglioramento della raccordabilita' dei conti delle amministrazioni pubbliche con il Sistema europeo dei conti nazionali nell'ambito delle rappresentazioni contabili, le amministrazioni di cui all'articolo 2, adottano il piano dei conti integrato di cui all'allegato n. 6, raccordato al piano dei conti di cui all'art. 4, comma 3, lettera a), del decreto legislativo 31 maggio 2011, n. 91.

2. Il piano dei conti integrato, ispirato a comuni criteri di contabilizzazione, e' costituito dall'elenco delle articolazioni delle unita' elementari del bilancio finanziario gestionale e dei conti economico-patrimoniali, definito in modo da evidenziare, attraverso i principi contabili applicati, le modalita' di raccordo, anche in una sequenza temporale, dei dati finanziari ed economico-patrimoniali, nonche' consentire la rilevazione unitaria dei fatti gestionali.

3. L'elenco dei conti economico-patrimoniali comprende i conti necessari per le operazioni di integrazione, rettifica e ammortamento, effettuate secondo le modalita' e i tempi necessari alle esigenze conoscitive della finanza pubblica.

4. Il piano dei conti di ciascun comparto di enti puo' essere articolato in considerazione alla specificita' dell' attivita' svolta, fermo restando la riconducibilita' delle predette voci alle aggregazioni previste dal piano dei conti integrato comune di cui al comma 1.

5. Il livello del piano dei conti integrato comune rappresenta la struttura di riferimento per la predisposizione dei documenti contabili e di finanza pubblica delle amministrazioni pubbliche. Ai fini del raccordo con i capitoli e gli articoli, ove previsti, il livello minimo di articolazione del piano dei conti e' costituito almeno dal quarto livello. Ai fini della gestione, il livello minimo di articolazione del piano dei conti e' costituito dal quinto livello.

6. Al fine di facilitare il monitoraggio e il confronto delle grandezze di finanza pubblica rispetto al consuntivo, le amministrazioni di cui all'articolo 2, trasmettono le previsioni di bilancio, aggregate secondo la struttura del quarto livello de piano dei conti, alla banca dati unitaria delle amministrazioni pubbliche di cui all'art. 13, comma 3, della legge 31 dicembre 2009, n. 196, sulla base di schemi, tempi e modalita' definiti con decreto del Ministro dell'economia e delle finanze.

7. Al fine di fornire supporto all' analisi degli scostamenti in sede di consuntivo rispetto alle previsioni, ((le amministrazioni di cui all'art. 2, trasmettono le risultanze del consuntivo, aggregate secondo la struttura del piano dei conti, alla banca dati unitaria delle amministrazioni pubbliche di cui all'art. 13, comma 3, della legge 31 dicembre 2009, n. 196, sulla base di schemi, tempi e modalita' definiti con decreto del Ministro dell'economia e delle finanze.))

7-bis. Entro 60 giorni dalla pubblicazione del presente decreto nella Gazzetta Ufficiale, a fini conoscitivi, e' pubblicato nel sito internet www.arconet.rgs.tesoro.it:

- a) il piano dei conti dedicato alle regioni e agli enti regionali, derivato dal piano dei conti degli enti territoriali di cui al comma 1;
- b) il piano dei conti dedicato alle province, ai comuni e agli enti locali, derivato dal piano dei conti degli enti territoriali di cui al comma 1.

7-ter. A seguito degli aggiornamenti del piano dei conti integrato di cui all'art. 4, comma 3, lettera a), del decreto legislativo 31 maggio 2011, n. 91, l'allegato n. 6 puo' essere modificato con decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, di concerto con il Ministero dell'interno - Dipartimento per gli affari interni e territoriali e la Presidenza del Consiglio dei ministri - Dipartimento per gli affari regionali, su proposta della Commissione per l'armonizzazione contabile degli enti territoriali. La commissione per l'armonizzazione contabile degli enti territoriali promuove le modifiche e le integrazioni del piano dei conti di cui all'art. 4, comma 3, lettera a), del decreto legislativo 31 maggio 2011, n. 91, di interesse degli enti territoriali.

### Art. 5. - Definizione della transazione elementare

1. Ogni atto gestionale genera una transazione elementare.

2. Ad ogni transazione elementare e' attribuita una codifica che deve consentire di tracciare le operazioni contabili e di movimentare il piano dei conti integrato.

3. Le amministrazioni di cui all'articolo 2((...)), organizzano il proprio sistema informativo-contabile in modo tale da non consentire ((l'accertamento, la riscossione o il versamento di entrate e l'impegno, la liquidazione, l'ordinazione e il pagamento di spese,)) in assenza di una codifica completa che ne permetta l'identificazione.

((

3-bis. Negli ordinativi di incasso e di pagamento la codifica della transazione elementare e' inserita nei campi liberi a disposizione dell'ente, non gestiti dal tesoriere.

))

### Art. 6. - Struttura della codifica della transazione elementare

1. La struttura della codifica della transazione elementare e' definita ((dall'allegato n. 7.)) ((...)).

((

1-bis. La codifica della transazione elementare e' aggiornata con decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, di concerto con il Ministero dell'interno - Dipartimento per gli affari interni e territoriali e la Presidenza del Consiglio dei ministri - Dipartimento per gli affari regionali, su proposta della Commissione per l'armonizzazione contabile degli enti territoriali con validita' dall'esercizio successivo alla data di pubblicazione.

))

### Art. 7. - Modalita' di codificazione delle transazioni elementari

1. Al fine di garantire l'omogeneita' dei bilanci pubblici, le amministrazioni di cui all'articolo 2((...)) codificano le transazioni elementari uniformandosi alle istruzioni degli appositi glossari. E' vietato:

- a) l'adozione del criterio della prevalenza ((, salvi i casi in cui e' espressamente previsto));
- b) l'imputazione provvisoria di operazioni alle partite di giro/servizi per conto terzi;
- c) assumere impegni sui fondi di riserva((e sugli altri accantonamenti stanziati in bilancio.)).

((

1-bis. I residui provenienti dagli esercizi precedenti all'entrata in vigore del presente decreto, che non sono stati oggetto del riaccertamento di cui all'art. 3, comma 7, non imputabili ad una sola tipologia di entrata, o ad un solo programma di spesa, possono essere codificati adottando il criterio della prevalenza.

))

### Art. 8. - Adeguamento SIOPE

((

1. Con le modalita' definite dall'art. 14, comma 8, della legge 31 dicembre 2009, n. 196, dal 1° gennaio 2017 le codifiche SIOPE degli enti territoriali e dei loro enti strumentali in contabilita' finanziaria sono sostituite con quelle previste nella struttura del piano dei conti integrato. Le codifiche SIOPE degli enti in contabilita' civilistica sono aggiornate in considerazione della struttura del piano dei conti integrato degli enti in contabilita' finanziaria.

))

2. Eventuali ulteriori livelli di articolazione delle codifiche SIOPE sono riconducibili alle aggregazioni previste dal piano dei conti integrati.

### Art. 9. - Il sistema di bilancio

1. Il sistema di bilancio delle amministrazioni pubbliche di cui all'articolo 2 costituisce lo strumento essenziale per il processo di programmazione, previsione, gestione e rendicontazione. Le sue finalita' sono quelle di fornire informazioni in merito ai programmi futuri, a quelli in corso di realizzazione ed all'andamento dell'ente, a favore dei soggetti interessati al processo di decisione politica, sociale ed economico-finanziaria.

### Art. 10. - Bilanci di previsione finanziari

1. Il bilancio di previsione finanziario e' almeno triennale, ha carattere autorizzatorio ed e' aggiornato annualmente in occasione della sua approvazione. Le previsioni di entrata e di spesa sono elaborate distintamente per ciascun esercizio, in coerenza con i documenti di programmazione dell'ente, restando esclusa ogni quantificazione basata sul criterio della spesa storica incrementale.

2. A seguito di eventi intervenuti successivamente all'approvazione del bilancio, la giunta, nelle more della necessaria variazione di bilancio e al solo fine di garantire gli equilibri di bilancio, puo' limitare la natura autorizzatoria degli stanziamenti del bilancio di previsione, compresi quelli relativi agli esercizi successivi al primo. Con riferimento a tali stanziamenti, non possono essere assunte obbligazioni giuridiche.

3. Gli impegni di spesa sono assunti nei limiti dei rispettivi stanziamenti di competenza del bilancio di previsione, con imputazione agli esercizi in cui le obbligazioni passive sono esigibili. Non possono essere assunte obbligazioni che danno luogo ad impegni di spesa corrente:

- a) sugli esercizi successivi a quello in corso considerati nel bilancio di previsione, a meno che non siano connesse a contratti o convenzioni pluriennali o siano necessarie per garantire la continuita' dei servizi connessi con le funzioni fondamentali, fatta salva la costante verifica del mantenimento degli equilibri di bilancio;
- b) sugli esercizi non considerati nel bilancio, a meno delle spese derivanti da contratti di somministrazione, di locazione, relative a prestazioni periodiche o continuative di servizi di cui all'art. 1677 del codice civile, imputate anche agli esercizi considerati nel bilancio di previsione, delle spese correlate a finanziamenti comunitari e delle rate di ammortamento dei prestiti, inclusa la quota capitale.

((

4. Nei casi in cui il tesoriere e' tenuto ad effettuare controlli sui pagamenti, alle variazioni di bilancio, disposte nel rispetto di quanto previsto dai rispettivi ordinamenti finanziari, sono allegati i prospetti di cui all'allegato 8, da trasmettere al tesoriere.

))

4-bis. Il conto del tesoriere e' predisposto secondo lo schema di cui all'allegato n. 17.

### Art. 11. - Schemi di bilancio

1. Le amministrazioni pubbliche di cui all'art. 2 adottano i seguenti comuni schemi di bilancio finanziari, economici e patrimoniali e comuni schemi di bilancio consolidato con i propri enti ed organismi strumentali, aziende, societa' controllate e partecipate e altri organismi controllati:

- a) allegato n. 9, concernente lo schema del bilancio di previsione finanziario, costituito dalle previsioni delle entrate e delle spese, di competenza e di cassa del primo esercizio, dalle previsioni delle entrate e delle spese di competenza degli esercizi successivi, dai relativi riepiloghi, e dai prospetti riguardanti il quadro generale riassuntivo e gli equilibri;
- b) allegato n. 10, concernente lo schema del rendiconto della gestione, che comprende il conto del bilancio, i relativi riepiloghi, i prospetti riguardanti il quadro generale riassuntivo e la verifica degli equilibri, lo stato patrimoniale e il conto economico;
- c) allegato n. 11 concernente lo schema del bilancio consolidato disciplinato dall'art. 11-ter.

2. Le amministrazioni pubbliche di cui all'art. 2 redigono un rendiconto semplificato per il cittadino, da divulgare sul proprio sito internet, recante una esposizione sintetica dei dati di bilancio, con evidenziazione delle risorse finanziarie umane e strumentali utilizzate dall'ente nel perseguimento delle diverse finalita' istituzionali, dei risultati conseguiti con riferimento al livello di copertura ed alla qualita' dei servizi pubblici forniti ai cittadini.

3. Al bilancio di previsione finanziario di cui al comma 1, lettera a), sono allegati, oltre a quelli previsti dai relativi ordinamenti contabili:

- a) il prospetto esplicativo del presunto risultato di amministrazione;
- b) il prospetto concernente la composizione, per missioni e programmi, del fondo pluriennale vincolato per ciascuno degli esercizi considerati nel bilancio di previsione;
- c) il prospetto concernente la composizione del fondo crediti di dubbia esigibilita' per ciascuno degli esercizi considerati nel bilancio di previsione;
- d) il prospetto dimostrativo del rispetto dei vincoli di indebitamento;
- e) per i soli enti locali, il prospetto delle spese previste per l'utilizzo di contributi e trasferimenti da parte di organismi comunitari e internazionali, per ciascuno degli anni considerati nel bilancio di previsione;
- f) per i soli enti locali, il prospetto delle spese previste per lo svolgimento delle funzioni delegate dalle regioni per ciascuno degli anni considerati nel bilancio di previsione;
- g) la nota integrativa redatta secondo le modalita' previste dal comma 5;
- h) la relazione del collegio dei revisori dei conti.

4. Al rendiconto della gestione sono allegati oltre a quelli previsti dai relativi ordinamenti contabili:

- a) il prospetto dimostrativo del risultato di amministrazione;
- b) il prospetto concernente la composizione, per missioni e programmi, del fondo pluriennale vincolato;
- c) il prospetto concernente la composizione del fondo crediti di dubbia esigibilita';
- d) il prospetto degli accertamenti per titoli, tipologie e categorie;
- e) il prospetto degli impegni per missioni, programmi e macroaggregati;
- f) la tabella dimostrativa degli accertamenti assunti nell'esercizio in corso e negli esercizi precedenti imputati agli esercizi successivi;
- g) la tabella dimostrativa degli impegni assunti nell'esercizio in corso e negli esercizi precedenti imputati agli esercizi successivi;
- h) il prospetto rappresentativo dei costi sostenuti per missione;
- i) per le sole regioni, il prospetto dimostrativo della ripartizione per missioni e programmi della politica regionale unitaria e cooperazione territoriale, a partire dal periodo di programmazione 2014 - 2020;
- j) per i soli enti locali, il prospetto delle spese sostenute per l'utilizzo di contributi e trasferimenti da parte di organismi comunitari e internazionali;
- k) per i soli enti locali, il prospetto delle spese sostenute per lo svolgimento delle funzioni delegate dalle regioni;
- l) il prospetto dei dati SIOPE;
- m) l'elenco dei residui attivi e passivi provenienti dagli esercizi anteriori a quello di competenza, distintamente per esercizio di provenienza e per capitolo;
- n) l'elenco dei crediti inesigibili, stralciati dal conto del bilancio, sino al compimento dei termini di prescrizione;
- o) la relazione sulla gestione dell'organo esecutivo redatta secondo le modalita' previste dal comma 6;
- p) la relazione del collegio dei revisori dei conti.

5. La nota integrativa allegata al bilancio di previsione indica:

- a) i criteri di valutazione adottati per la formulazione delle previsioni, con particolare riferimento agli stanziamenti riguardanti gli accantonamenti per le spese potenziali e al fondo crediti di dubbia esigibilita', dando illustrazione dei crediti per i quali non e' previsto l'accantonamento a tale fondo;
- b) l'elenco analitico delle quote vincolate e accantonate del risultato di amministrazione presunto al 31 dicembre dell'esercizio precedente, distinguendo i vincoli derivanti dalla legge e dai principi contabili, dai trasferimenti, da mutui e altri finanziamenti, vincoli formalmente attribuiti dall'ente;
- c) l'elenco analitico degli utilizzi delle quote vincolate e accantonate del risultato di amministrazione presunto, distinguendo i vincoli derivanti dalla legge e dai principi contabili, dai trasferimenti, da mutui e altri finanziamenti, vincoli formalmente attribuiti dall'ente;
- d) l'elenco degli interventi programmati per spese di investimento finanziati col ricorso al debito e con le risorse disponibili;
- e) nel caso in cui gli stanziamenti riguardanti il fondo pluriennale vincolato comprendono anche investimenti ancora in corso di definizione, le cause che non hanno reso possibile porre in essere la programmazione necessaria alla definizione dei relativi cronoprogrammi;
- f) l'elenco delle garanzie principali o sussidiarie prestate dall'ente a favore di enti e di altri soggetti ai sensi delle leggi vigenti;
- g) gli oneri e gli impegni finanziari stimati e stanziati in bilancio, derivanti da contratti relativi a strumenti finanziari derivati o da contratti di finanziamento che includono una componente derivata;
- h) l'elenco dei propri enti ed organismi strumentali, precisando che i relativi bilanci consuntivi sono consultabili nel proprio sito internet fermo restando quanto previsto per gli enti locali dall'art. 172, comma 1, lettera a) del decreto legislativo 18 agosto 2000, n. 267;
- i) l'elenco delle partecipazioni possedute con l'indicazione della relativa quota percentuale;
- j) altre informazioni riguardanti le previsioni, richieste dalla legge o necessarie per l'interpretazione del bilancio.

6. La relazione sulla gestione allegata al rendiconto e' un documento illustrativo della gestione dell'ente, nonche' dei fatti di rilievo verificatisi dopo la chiusura dell'esercizio e di ogni eventuale informazione utile ad una migliore comprensione dei dati contabili. In particolare la relazione illustra:

- a) i criteri di valutazione utilizzati;
- b) le principali voci del conto del bilancio;
- c) le principali variazioni alle previsioni finanziarie intervenute in corso d'anno, comprendendo l'utilizzazione dei fondi di riserva e gli utilizzi delle quote vincolate e accantonate del risultato di amministrazione al 1° gennaio dell'esercizio precedente, distinguendo i vincoli derivanti dalla legge e dai principi contabili, dai trasferimenti, da mutui e altri finanziamenti, vincoli formalmente attribuiti dall'ente;
- d) l'elenco analitico delle quote vincolate e accantonate del risultato di amministrazione al 31 dicembre dell'esercizio precedente, distinguendo i vincoli derivanti dalla legge e dai principi contabili, dai trasferimenti, da mutui e altri finanziamenti, vincoli formalmente attribuiti dall'ente;
- d-bis) solo con riferimento alle regioni, l'elenco degli impegni per spese di investimento di competenza dell'esercizio finanziati con il ricorso al debito non contratto;
- d-ter) solo con riferimento alle regioni, l'elenco degli impegni per spese di investimento che hanno determinato il disavanzo da debito autorizzato e non contratto alla fine dell'anno, distintamente per esercizio di formazione
- e) le ragioni della persistenza dei residui con anzianita' superiore ai cinque anni e di maggiore consistenza, nonche' sulla fondatezza degli stessi, compresi i crediti di cui al comma 4, lettera n);
- f) l'elenco delle movimentazioni effettuate nel corso dell'esercizio sui capitoli di entrata e di spesa riguardanti l'anticipazione, evidenziando l'utilizzo medio e l'utilizzo massimo dell'anticipazione nel corso dell'anno, nel caso in cui il conto del bilancio, in deroga al principio generale dell'integrita', espone il saldo al 31 dicembre dell'anticipazione attivata al netto dei relativi rimborsi;
- g) l'elencazione dei diritti reali di godimento e la loro illustrazione;
- h) l'elenco dei propri enti e organismi strumentali, con la precisazione che i relativi rendiconti o bilanci di esercizio sono consultabili nel proprio sito internet;
- i) l'elenco delle partecipazioni dirette possedute con l'indicazione della relativa quota percentuale;
- j) gli esiti della verifica dei crediti e debiti reciproci con i propri enti strumentali e le societa' controllate e partecipate. La predetta informativa, asseverata dai rispettivi organi di revisione, evidenzia analiticamente eventuali discordanze e ne fornisce la motivazione; in tal caso l'ente assume senza indugio, e comunque non oltre il termine dell'esercizio finanziario in corso, i provvedimenti necessari ai fini della riconciliazione delle partite debitorie e creditorie;
- k) gli oneri e gli impegni sostenuti, derivanti da contratti relativi a strumenti finanziari derivati o da contratti di finanziamento che includono una componente derivata;
- l) l'elenco delle garanzie principali o sussidiarie prestate dall'ente a favore di enti e di altri soggetti ai sensi delle leggi vigenti, con l'indicazione delle eventuali richieste di escussione nei confronti dell'ente e del rischio di applicazione dell'art. 3, comma 17 della legge 24 dicembre 2003, n. 350;
- m) l'elenco descrittivo dei beni appartenenti al patrimonio immobiliare dell'ente alla data di chiusura dell'esercizio cui il conto si riferisce, con l'indicazione delle rispettive destinazioni e degli eventuali proventi da essi prodotti;
- n) gli elementi richiesti dall'art. 2427 e dagli altri articoli del codice civile, nonche' da altre norme di legge e dai documenti sui principi contabili applicabili;
- o) altre informazioni riguardanti i risultati della gestione, richieste dalla legge o necessarie per l'interpretazione del rendiconto.

7. Al documento tecnico di accompagnamento delle regioni di cui all'art. 39, comma 10, e al piano esecutivo di gestione degli enti locali di cui all'art. 169 del decreto legislativo 18 agosto 2000, n. 267, sono allegati:

- a) il prospetto delle previsioni di entrata per titoli, tipologie e categorie per ciascuno degli anni considerati nel bilancio di previsione, distinguendo le entrate ricorrenti e non ricorrenti, secondo lo schema di cui all'allegato 12/1;
- b) il prospetto delle previsioni di spesa per missioni, programmi e macroaggregati per ciascuno degli anni considerati nel bilancio di previsione, distinguendo le spese ricorrenti e non ricorrenti, secondo lo schema di cui all'allegato 12/2.

8. Le amministrazioni di cui al comma 1 articolate in organismi strumentali come definiti dall'art. 1, comma 2, approvano, contestualmente al rendiconto della gestione di cui al comma 1, lettera b), anche il rendiconto consolidato con i propri organismi strumentali. Il rendiconto consolidato delle regioni comprende anche i risultati della gestione del consiglio regionale.

9. Il rendiconto consolidato di cui al comma 8, predisposto nel rispetto dello schema previsto dal comma 1, lettera b), e' costituito dal conto del bilancio, dai relativi riepiloghi, dai prospetti riguardanti il quadro generale riassuntivo e la verifica degli equilibri, dallo stato patrimoniale e dal conto economico, ed e' elaborato aggiungendo alle risultanze riguardanti la gestione dell'ente, quelle dei suoi organismi strumentali ed eliminando le risultanze relative ai trasferimenti interni. Al rendiconto consolidato sono allegati i prospetti di cui al comma 4, lettere da

- a) a g). Al fine di consentire l'elaborazione del rendiconto consolidato l'ente disciplina tempi e modalita' di approvazione e acquisizione dei rendiconti dei suoi organismi strumentali.

10. Per i comuni con popolazione inferiore a 5.000 abitanti, la predisposizione degli allegati di cui al comma 3, lettere e) ed f), e di cui al comma 4, lettere d), e), h), j) e k), e' facoltativa.

11. Gli schemi di bilancio di cui al presente articolo sono modificati ed integrati con decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, di concerto con il Ministero dell'interno - Dipartimento per gli affari interni e territoriali e la Presidenza del Consiglio dei ministri - Dipartimento per gli affari regionali, su proposta della Commissione per l'armonizzazione contabile degli enti territoriali. A decorrere dal 2016, gli allegati riguardanti gli equilibri sono integrati in attuazione dell'art. 9, della legge 24 dicembre 2012, n. 243.

12. Nel 2015 gli enti di cui al comma 1 adottano gli schemi di bilancio e di rendiconto vigenti nel 2014, che conservano valore a tutti gli effetti giuridici, anche con riguardo alla funzione autorizzatoria, ai quali affiancano quelli previsti dal comma 1, cui e' attribuita funzione conoscitiva. Il bilancio pluriennale 2015-2017 adottato secondo lo schema vigente nel 2014 svolge funzione autorizzatoria. Nel 2015, come prima voce dell'entrata degli schemi di bilancio autorizzatori annuali e pluriennali e' inserito il fondo pluriennale vincolato come definito dall'art. 3, comma 4, mentre in spesa il fondo pluriennale e' incluso nei singoli stanziamenti del bilancio annuale e pluriennale.

13. Il bilancio di previsione e il rendiconto relativi all'esercizio 2015 predisposti secondo gli schemi di cui agli allegati 9 e 10 sono allegati ai corrispondenti documenti contabili aventi natura autorizzatoria. Il rendiconto relativo all'esercizio 2015 predisposto secondo lo schema di cui all'allegato 10 degli enti che si sono avvalsi della facolta' di cui all'art. 3, comma 12, non comprende il conto economico e lo stato patrimoniale. Al primo rendiconto di affiancamento della contabilita' economico patrimoniale alla contabilita' finanziaria previsto dall'art. 2, commi 1 e 2, e' allegato anche lo stato patrimoniale iniziale.

14. A decorrere dal 2016 gli enti di cui all'art. 2 adottano gli schemi di bilancio previsti dal comma 1 che assumono valore a tutti gli effetti giuridici, anche con riguardo alla funzione autorizzatoria.

15. A decorrere dal 2015 gli enti che nel 2014 hanno partecipato alla sperimentazione di cui all'art. 78 adottano gli schemi di bilancio di cui al comma 1 che assumono valore a tutti gli effetti giuridici, anche con riguardo alla funzione autorizzatoria cui affiancano nel 2015, con funzione conoscitiva, gli schemi di bilancio e di rendiconto vigenti nel 2014, salvo gli allegati n. 17, 18 e 20 del decreto del Presidente della Repubblica n. 194 del 1996 che possono non essere compilati.

16. In caso di esercizio provvisorio o gestione provvisoria nell'esercizio 2015, gli enti di cui al comma 1 applicano la relativa disciplina vigente nel 2014, ad esclusione degli enti che nel 2014 hanno partecipato alla sperimentazione di cui all'art. 78, per i quali trova applicazione la disciplina dell'esercizio provvisorio prevista dal principio contabile applicato della contabilita' finanziaria di cui all'allegato 4/2.

17. In caso di esercizio provvisorio o gestione provvisoria nell'esercizio 2016 gli enti di cui al comma 1 gestiscono gli stanziamenti di spesa previsti nel bilancio pluriennale autorizzatorio 2015 - 2017 per l'annualita' 2016, riclassificati secondo lo schema di cui all'allegato 9.

### Art. 11-bis. - (( (Bilancio consolidato).))

((

1. Gli enti di cui all'art. 1, comma 1, redigono il bilancio consolidato con i propri enti ed organismi strumentali, aziende, societa' controllate e partecipate, secondo le modalita' ed i criteri individuati nel principio applicato del bilancio consolidato di cui all'allegato n. 4/4.

2. Il bilancio consolidato e' costituito dal conto economico consolidato, dallo stato patrimoniale consolidato e dai seguenti allegati:

- a) la relazione sulla gestione consolidata che comprende la nota integrativa;
- b) la relazione del collegio dei revisori dei conti.

3. Ai fini dell'inclusione nel bilancio consolidato, si considera qualsiasi ente strumentale, azienda, societa' controllata e partecipata, indipendentemente dalla sua forma giuridica pubblica o privata, anche se le attivita' che svolge sono dissimili da quelle degli altri componenti del gruppo, con l'esclusione degli enti cui si applica il titolo II.

4. Gli enti di cui al comma 1 possono rinviare l'adozione del bilancio consolidato con riferimento all'esercizio 2016, salvo gli enti che, nel 2014, hanno partecipato alla sperimentazione.

))

### Art. 11-ter. - (Enti strumentali)

1. Si definisce ente strumentale controllato di una regione o di un ente locale di cui all'art. 2 del decreto legislativo 18 agosto 2000, n. 267, l'azienda o l'ente, pubblico o privato, nei cui confronti la regione o l'ente locale ha una delle seguenti condizioni:

- a) il possesso, diretto o indiretto, della maggioranza dei voti esercitabili nell'ente o nell'azienda;
- b) il potere assegnato da legge, statuto o convenzione di nominare o rimuovere la maggioranza dei componenti degli organi decisionali, competenti a definire le scelte strategiche e le politiche di settore, nonche' a decidere in ordine all'indirizzo, alla pianificazione ed alla programmazione dell'attivita' di un ente o di un'azienda;
- c) la maggioranza, diretta o indiretta, dei diritti di voto nelle sedute degli organi decisionali, competenti a definire le scelte strategiche e le politiche di settore, nonche' a decidere in ordine all'indirizzo, alla pianificazione ed alla programmazione dell'attivita' dell'ente o dell'azienda;
- d) l'obbligo di ripianare i disavanzi, nei casi consentiti dalla legge, per percentuali superiori alla propria quota di partecipazione;
- e) un'influenza dominante in virtu' di contratti o clausole statutarie, nei casi in cui la legge consente tali contratti o clausole. I contratti di servizio pubblico e di concessione, stipulati con enti o aziende che svolgono prevalentemente l'attivita' oggetto di tali contratti, comportano l'esercizio di influenza dominante.

2. Si definisce ente strumentale partecipato da una regione o da un ente locale di cui all'art. 2 del decreto legislativo 18 agosto 2000, n. 267, l'azienda o l'ente, pubblico o privato, nel quale la regione o l'ente locale ha una partecipazione, in assenza delle condizioni di cui al comma 1.

3. Gli enti strumentali di cui ai commi 1 e 2 sono distinti nelle seguenti tipologie, corrispondenti alle missioni del bilancio:

- a) servizi istituzionali, generali e di gestione;
- b) istruzione e diritto allo studio;
- c) ordine pubblico e sicurezza;
- d) tutela e valorizzazione dei beni ed attivita' culturali;
- e) politiche giovanili, sport e tempo libero;
- f) turismo;
- g) assetto del territorio ed edilizia abitativa;
- h) sviluppo sostenibile e tutela del territorio e dell'ambiente;
- i) trasporti e diritto alla mobilita';
- j) soccorso civile;
- k) diritti sociali, politiche sociali e famiglia;
- l) tutela della salute;
- m) sviluppo economico e competitivita';
- n) politiche per il lavoro e la formazione professionale;
- o) agricoltura, politiche agroalimentari e pesca;
- p) energia e diversificazione delle fonti energetiche;
- q) relazione con le altre autonomie territoriali e locali;
- r) relazioni internazionali. ((18))

------------- AGGIORNAMENTO (18) Il D.L. 20 giugno 2017, n. 91, convertito con modificazioni dalla L. 3 agosto 2017, n. 123, ha disposto (con l'art. 8, comma 1-quater) che "L'articolo 11-ter del decreto legislativo 23 giugno 2011, n. 118, non si applica ai Corpi volontari dei vigili del fuoco, nonche' alle relative unioni".

### Art. 11-quater. - (Societa' controllate)

1. ((Ai fini dell'elaborazione del bilancio consolidato, si definisce)) controllata da una regione o da un ente locale la societa' nella quale la regione o l'ente locale ha una delle seguenti condizioni:

- a) il possesso, diretto o indiretto, anche sulla scorta di patti parasociali, della maggioranza dei voti esercitabili nell'assemblea ordinaria o dispone di voti sufficienti per esercitare una influenza dominante sull'assemblea ordinaria;
- b) il diritto, in virtu' di un contratto o di una clausola statutaria, di esercitare un'influenza dominante, quando la legge consente tali contratti o clausole.

2. I contratti di servizio pubblico e gli atti di concessione stipulati con societa' che svolgono prevalentemente l'attivita' oggetto di tali contratti comportano l'esercizio di influenza dominante.

3. Le societa' controllate sono distinte nelle medesime tipologie previste per gli enti strumentali.

4. In fase di prima applicazione del presente decreto, con riferimento agli esercizi 2015-2017, non sono considerate le societa' quotate e quelle da esse controllate ai sensi dell'art. 2359 del codice civile. A tal fine, per societa' quotate degli enti di cui al presente articolo si intendono le societa' emittenti strumenti finanziari quotati in mercati regolamentari.

### Art. 11-quinquies. - (Societa' partecipate)

1. ((Ai fini dell'elaborazione del bilancio consolidato, per societa' partecipata)) da una regione o da un ente locale, si intende la societa' nella quale la regione o l'ente locale, direttamente o indirettamente, dispone di una quota di voti, esercitabili in assemblea, pari o superiore al 20 per cento, o al 10 per cento se trattasi di societa' quotata.

2. Le societa' partecipate sono distinte nelle medesime tipologie previste per gli enti strumentali.

3. In fase di prima applicazione del presente decreto, con riferimento agli esercizi 2015 - 2017, per societa' partecipata da una regione o da un ente locale, si intende la societa' a totale partecipazione pubblica affidataria di servizi pubblici locali della regione o dell'ente locale, indipendentemente dalla quota di partecipazione.

### Art. 12. - Omogeneita' della classificazione delle spese

1. Allo scopo di assicurare maggiore trasparenza delle informazioni riguardanti il processo di allocazione delle risorse pubbliche e la destinazione delle stesse alle politiche pubbliche settoriali, e al fine di consentire la confrontabilita' dei dati di bilancio in coerenza con le classificazioni economiche e funzionali individuate dai regolamenti comunitari in materia di contabilita' nazionale e relativi conti satellite, le amministrazioni pubbliche di cui all'articolo 2 ((...)) adottano uno schema di bilancio articolato per missioni e programmi che evidenzi le finalita' della spesa.

### Art. 13. - Definizione del contenuto di missione e programma

1. La rappresentazione della spesa per missioni e programmi costituisce uno dei fondamentali principi contabili di cui all'articolo 3. Le missioni rappresentano le funzioni principali e gli obiettivi strategici perseguiti dalle amministrazioni di cui all'articolo 2 ((...)) utilizzando risorse finanziarie, umane e strumentali ad esse destinate. I programmi rappresentano gli aggregati omogenei di attivita' volte a perseguire gli obiettivi definiti nell'ambito delle missioni.

2. L'unita' di voto per l'approvazione del bilancio di previsione delle amministrazioni di cui all'articolo 2 ((...)) e' costituita dai programmi.

### Art. 14. - Criteri per la specificazione e classificazione delle spese

1. Unitamente alle rilevazioni contabili in termini finanziari, economici e patrimoniali, i documenti di bilancio previsivi e consuntivi delle Amministrazioni pubbliche di cui all'articolo 2 ((...)) in attuazione di quanto previsto dall'articolo 13 ripartiscono le spese in:

- a) missioni, come definite all'articolo 13, comma 1, secondo periodo. Le missioni sono definite in relazione al riparto di competenza di cui agli articoli 117 e 118 della Costituzione. Al fine di assicurare un piu' agevole consolidamento e monitoraggio dei conti pubblici, le missioni sono definite anche tenendo conto di quelle individuate per il bilancio dello Stato;
- c) ((LETTERA ABROGATA DAL D.LGS. 10 AGOSTO 2014, N. 126)).

2. ((COMMA ABROGATO DAL D.LGS. 10 AGOSTO 2014, N. 126)).

3. Le amministrazioni pubbliche di cui all'articolo 2 ((...)) allegano al bilancio consuntivo un apposito allegato che includa una rappresentazione riassuntiva dei costi sostenuti per ((per le missioni di cui agli articoli 12 e 13 secondo lo schema previsto dall'art. 11, comma 4, lettera h) )).

((

3-bis. Le Regioni, a seguito di motivate ed effettive difficolta' gestionali per la sola spesa di personale, possono utilizzare in maniera strumentale, per non piu' di due esercizi finanziari, il programma "Risorse umane", all'interno della missione "Servizi istituzionali, generali e di gestione". La disaggregazione delle spese di personale per le singole missioni e i programmi rappresentati a bilancio deve essere comunque esplicitata in apposito allegato alla legge di bilancio, aggiornata con la legge di assestamento e definitivamente contabilizzata con il rendiconto.

3-ter. L'elenco delle missioni, programmi, titoli e macroaggregati, indicato nell'allegato n. 14, e' aggiornato con decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, di concerto con il Ministero dell'interno - Dipartimento per gli affari interni e territoriali e la Presidenza del Consiglio dei ministri - Dipartimento per gli affari regionali, su proposta della Commissione per l'armonizzazione contabile degli enti territoriali. L'allegato 14 comprende il glossario delle missioni e dei programmi che individua anche le corrispondenze tra i programmi e la classificazione COFOG di secondo livello (Gruppi).

))

### Art. 15. - Criteri per la specificazione e la classificazione delle entrate

1. Le entrate degli schemi di bilancio finanziario di cui all' articolo 11 sono classificate secondo i successivi livelli di dettaglio:

- a) titoli, definiti secondo la fonte di provenienza delle entrate;
- b) tipologie, definite in base alla natura delle entrate, nell'ambito di ciascuna fonte di provenienza, ai fini dell'approvazione in termini di unita' di voto; ((Ai fini della gestione e della rendicontazione le tipologie sono ripartite in categorie, capitoli ed eventualmente in articoli secondo il rispettivo oggetto. I capitoli e gli articoli, ove previsti, si raccordano con il quarto livello di articolazione del piano dei conti integrato di cui all'art. 4. La Giunta contestualmente alla proposta di bilancio trasmette al Consiglio, a fini conoscitivi, la proposta di articolazione delle tipologie in categorie.));
- c) ((LETTERA ABROGATA DAL D.LGS. 10 AGOSTO 2014, N. 126)).

((

2. Nell'ambito delle categorie e' data separata evidenza delle eventuali quote di entrata non ricorrente. L'elenco dei titoli, delle tipologie e delle categorie, indicato nell'allegato n. 13, e' aggiornato con decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, di concerto con il Ministero dell'interno - Dipartimento per gli affari interni e territoriali e la Presidenza del Consiglio dei ministri - Dipartimento per gli affari regionali, su proposta della Commissione per l'armonizzazione contabile degli enti territoriali.

))

### Art. 16. - (( (Flessibilita' degli stanziamenti di bilancio).))

((

1. Al fine di migliorare l'utilizzo delle risorse pubbliche, anche in termini di riqualificazione della spesa, le amministrazioni pubbliche di cui all'art. 2 possono effettuare, in sede di gestione, variazioni compensative tra le dotazioni delle missioni e dei programmi, limitatamente alle spese per il personale, conseguenti a provvedimenti di trasferimento del personale all'interno dell'amministrazione.

2. Resta in ogni caso precluso l'utilizzo delle entrate in conto capitale e derivanti dall'accensione di prestiti per il finanziamento delle spese correnti.

))

### Art. 17. - Tassonomia per gli enti in contabilita' civilistica

1. ((Gli enti strumentali)) di cui all'articolo 3, ((comma 3)), predispongono un budget economico.

((

1-bis. Gli enti di cui al comma 1 sono tenuti alla redazione di un rendiconto finanziario in termini di cassa predisposto ai sensi dell'art. 2428, comma 2, del codice civile.

))

2. Al fine di consentire il consolidamento dei propri dati di cassa con quelli delle altre amministrazioni pubbliche, gli enti di cui ((al comma 1 che rientrano nella definizione di amministrazioni pubbliche di cui all'art. 1, comma 2, della legge 31 dicembre 2009, n. 196,)), riclassificano i propri ((incassi e pagamenti)) attraverso la rilevazione SIOPE di cui all'articolo 14, comma 6, della legge 31 dicembre 2009, n. 196.

((

3. Al fine di fornire informazioni in merito alla classificazione della propria spesa complessiva in missioni e programmi, come definiti dall'art. 13 del presente decreto, le amministrazioni pubbliche di cui al comma 2, elaborano un apposito prospetto, predisposto secondo le modalita' di cui all'allegato n. 15, concernente la ripartizione della propria spesa per missioni e programmi, accompagnata dalla corrispondente classificazione secondo la nomenclatura COFOG di secondo livello secondo le corrispondenze individuate nel glossario delle missioni e dei programmi di cui all'allegato 14. Nel caso di corrispondenza non univoca tra programma e funzioni COFOG di secondo livello, vanno indicate le funzioni COFOG con l'indicazione delle percentuali di attribuzione della spesa del programma a ciascuna di esse.

))

4. Tale prospetto((...)) e' allegato al budget e al bilancio di esercizio in coerenza con i risultati della tassonomia effettuata attraverso la rilevazione SIOPE.

5. La relazione sulla gestione attesta - nell'ambito del quadro di riferimento in cui operano i soggetti di cui al comma 1, a corredo delle informazioni, e in coerenza con la missione - le attivita' riferite a ciascun programma di spesa.

6. Gli organi interni di controllo vigilano sull'attuazione di quanto previsto dai precedenti commi, attestando tale adempimento nella relazione di cui all'articolo 2429 del codice civile.

((

6-bis. Al fine di consentire la rilevazione SIOPE, gli enti di cui al comma 1 si avvalgono di un servizio di cassa che prevede l'utilizzo di ordinativi di incasso e di pagamento.

6-ter. Gli enti di cui al comma 1, ancora non coinvolti nella rilevazione SIOPE, rinviano l'attuazione dei commi da 2 a 6 all'emanazione del decreto del Ministro dell'economia e delle finanze concernente l'attuazione della rilevazione SIOPE per gli enti del proprio comparto.

6-quater. Il prospetto di cui all'allegato n. 15 e' aggiornato con decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, di concerto con il Ministero dell'interno - Dipartimento per gli affari interni e territoriali e la Presidenza del Consiglio dei ministri - Dipartimento per gli affari regionali, su proposta della Commissione per l'armonizzazione contabile degli enti territoriali.

))

### Art. 18. - Termini di approvazione dei bilanci

1. Le amministrazioni pubbliche di cui all'articolo 1, comma 1, approvano:

- a) il bilancio di previsione o il budget economico entro il 31 dicembre dell'anno precedente;
- b) il rendiconto o il bilancio di esercizio entro il 30 aprile dell' anno successivo le regioni approvano il rendiconto entro il 31 luglio dell'anno successivo, con preventiva approvazione da parte della giunta entro il 30 aprile, per consentire la parifica delle sezioni regionali di controllo della Corte dei conti;
- c) il bilancio consolidato entro il 30 settembre dell'anno successivo. ((32))

2. Le amministrazioni pubbliche di cui all'articolo 1 trasmettono i loro bilanci preventivi ed i bilanci consuntivi alla Banca dati unitaria delle· amministrazioni pubbliche, secondo gli schemi e le modalita' previste dall'articolo 13, comma 3, della legge 31 dicembre 2009, n. 196. Gli schemi , standardizzati ed omogenei, assicurano l'effettiva comparabilita' delle informazioni tra i diversi enti territoriali.

--------------- AGGIORNAMENTO (32) Il D.L. 19 maggio 2020, n. 34 ha disposto (con l'art. 110, comma 1) che "Il termine per l'approvazione del bilancio consolidato 2019 di cui all'articolo 18, comma 1, lettera c), del decreto legislativo 23 giugno 2011, n. 118 e' differito al 30 novembre 2020".

### Art. 18-bis. - (( (Indicatori di bilancio) ))

((

1. Al fine di consentire la comparazione dei bilanci, gli enti adottano un sistema di indicatori semplici, denominato «Piano degli indicatori e dei risultati attesi di bilancio» misurabili e riferiti ai programmi e agli altri aggregati del bilancio, costruiti secondo criteri e metodologie comuni.

2. Le regioni e i loro enti ed organismi strumentali, entro 30 giorni dall'approvazione del bilancio di previsione o del budget di esercizio e del bilancio consuntivo o del bilancio di esercizio, presentano il documento di cui al comma 1, il quale e' parte integrante dei documenti di programmazione e di bilancio di ciascuna amministrazione pubblica. Esso viene divulgato anche attraverso la pubblicazione sul sito internet istituzionale dell'amministrazione stessa nella sezione «Trasparenza, valutazione e merito», accessibile dalla pagina principale (home page).

3. Gli enti locali ed i loro enti e organismi strumentali allegano il "Piano" di cui al comma 1 al bilancio di previsione o del budget di esercizio e del bilancio consuntivo o del bilancio di esercizio.

4. Il sistema comune di indicatori di risultato delle Regioni e dei loro enti ed organismi strumentali, e' definito con decreto del Ministero dell'economia e delle finanze su proposta della Commissione sull'armonizzazione contabile degli enti territoriali. Il sistema comune di indicatori di risultato degli enti locali e dei loro enti ed organismi strumentali e' definito con decreto del Ministero dell'interno, su proposta della Commissione sull'armonizzazione contabile degli enti territoriali. L'adozione del Piano di cui al comma 1 e' obbligatoria a decorrere dall'esercizio successivo all'emanazione dei rispettivi decreti.

))

## Principi contabili generali e applicati per il settore sanitario

### Art. 19. - Oggetto e ambito di applicazione

1. Le disposizioni del presente titolo, che costituiscono principi fondamentali del coordinamento della finanza pubblica ai sensi dell'articolo 117, comma 3, della Costituzione e sono finalizzate alla tutela dell'unita' economica della Repubblica italiana, ai sensi dell'articolo 120, secondo comma, della Costituzione, al fine di garantire che gli enti coinvolti nella gestione della spesa finanziata con le risorse destinate al Servizio sanitario nazionale concorrano al perseguimento degli obiettivi di finanza pubblica sulla base di principi di armonizzazione dei sistemi contabili e dei bilanci, sono dirette a disciplinare le modalita' di redazione e di consolidamento dei bilanci da parte dei predetti enti, nonche' a dettare i principi contabili cui devono attenersi gli stessi per l'attuazione delle disposizioni ivi contenute.

2. Gli enti destinatari delle disposizioni del presente titolo sono:

- a) le regioni, per la parte del bilancio regionale che riguarda il finanziamento e la spesa del relativo servizio sanitario, rilevata attraverso scritture di contabilita' finanziaria;
- b) le regioni: i) per la parte del finanziamento del servizio sanitario, regionale direttamente gestito, rilevata attraverso scritture di contabilita' economico-patrimoniale, qualora le singole regioni esercitino la scelta di gestire direttamente presso la regione una quota del finanziamento del proprio servizio sanitario, d'ora in poi denominata gestione sanitaria accentrata presso la regione; ii) per il consolidamento dei conti degli enti sanitari di cui alla lettera c) e, ove presente ai sensi del punto i), della gestione sanitaria accentrata presso la regione;
- c) aziende sanitarie locali; aziende ospedaliere; istituti di ricovero e cura a carattere scientifico pubblici, anche se trasformati in fondazioni; aziende. ospedaliere universitarie integrate con il Servizio sanitario nazionale;
- d) istituti zooprofilattici di cui al decreto legislativo 30 giugno 1993, n. 270.

### Art. 20. - Trasparenza dei conti sanitari e finalizzazione delle risorse al finanziamento dei singoli servizi sanitari regionali

1. Nell'ambito del bilancio regionale le regioni garantiscono un'esatta perimetrazione delle entrate e delle uscite relative al finanziamento del proprio servizio sanitario regionale, al fine di consentire la confrontabilita' immediata fra le entrate e le spese sanitarie iscritte nel bilancio regionale e le risorse indicate negli atti di determinazione del fabbisogno sanitario regionale standard e di individuazione delle correlate fonti di finanziamento, nonche' un'agevole verifica delle ulteriori risorse rese disponibili dalle regioni per il finanziamento del medesimo servizio sanitario regionale per l'esercizio in corso. A tal fine le regioni adottano un'articolazione in capitoli tale da garantire, sia nella sezione dell'entrata che nella sezione della spesa, ivi compresa l'eventuale movimentazione di partite di giro, separata evidenza delle seguenti grandezze: A) Entrate:

- a) finanziamento sanitario ordinario corrente quale derivante dalle fonti di finanziamento definite nell'atto formale di determinazione del fabbisogno sanitario regionale standard e di individuazione delle relative fonti di finanziamento intercettate dall'ente regionale, ivi compresa la mobilita' attiva programmata per l'esercizio;
- b) finanziamento sanitario aggiuntivo corrente, quale derivante dagli eventuali atti regionali di incremento di aliquote fiscali per il finanziamento della sanita' regionale, dagli automatismi fiscali intervenuti ai sensi della vigente legislazione in materia di copertura dei disavanzi sanitari, da altri atti di finanziamento regionale aggiuntivo, ivi compresi quelli di erogazione dei livelli di assistenza superiori rispetto ai LEA, da pay back e da iscrizione volontaria al Servizio sanitario nazionale;
- c) finanziamento regionale del disavanzo sanitario pregresso;
- d) finanziamento per investimenti in ambito sanitario, con separata evidenza degli interventi per l'edilizia sanitaria finanziati ai sensi dell' articolo 20, della legge n. 67 del 1988; B) Spesa: a) spesa sanitaria corrente per il finanziamento dei LEA, ivi compresa la mobilita' passiva programmata per l'esercizio e il pay back; b) spesa sanitaria aggiuntiva per il finanziamento di livelli di assistenza sanitaria superiori ai LEA; c) spesa sanitaria per il finanziamento di disavanzo sanitario pregresso; d) spesa per investimenti in. ambito sanitario, con separata evidenza degli interventi per l'edilizia sanitaria finanziati ai sensi dell' articolo 20, della legge n. 67 del 1988.

2. Per garantire effettivita' al finanziamento dei livelli di assistenza sanitaria, le regioni:

- a) accertano ed impegnano nel corso dell'esercizio l'intero importo corrispondente al finanziamento sanitario corrente, ivi compresa la quota premiale condizionata alla verifica degli adempimenti regionali, e le quote di finanziamento sanitario vincolate o finalizzate. Ove si verifichi la perdita definitiva di quote di finanziamento condizionate alla verifica di adempimenti regionali, ai sensi della legislazione vigente, detto evento e' registrato come cancellazione dei residui attivi nell'esercizio nel quale la perdita si determina definitivamente;
- b) accertano ed impegnano nel corso dell'esercizio l'intero importo corrispondente al finanziamento regionale del disavanzo sanitario pregresso;

2-bis. I gettiti derivanti dalle manovre fiscali regionali e destinati al finanziamento del Servizio sanitario regionale sono iscritti nel bilancio regionale nell'esercizio di competenza dei tributi.

2-ter. La quota dei gettiti derivanti dalle manovre fiscali regionali destinata obbligatoriamente al finanziamento del servizio sanitario regionale, ai sensi della legislazione vigente sui piani di rientro dai disavanzi sanitari, e' iscritta nel bilancio regionale triennale, nell'esercizio di competenza dei tributi, obbligatoriamente per l'importo stimato dal competente Dipartimento delle finanze del Ministero dell'economia e delle finanze, ovvero per il minore importo destinato al Servizio sanitario regionale ai sensi dell'art. 1, comma 80, della legge 23 dicembre 2009, n. 191. Tale iscrizione comporta l'automatico e contestuale accertamento e impegno dell'importo nel bilancio regionale. La regione non puo' disimpegnare tali somme, se non a seguito di espressa autorizzazione da parte del Tavolo di verifica degli adempimenti, ai sensi e per gli effetti dell'art. 1, comma 80, della legge 23 dicembre 2009, n. 191. In relazione a tale autorizzazione la regione e' tenuta a trasmettere al Tavolo di verifica degli adempimenti la relativa documentazione corredata dalla valutazione d'impatto operata dal competente Dipartimento delle finanze. Ove si verifichi in sede di consuntivazione dei gettiti fiscali un minore importo effettivo delle risorse derivanti dalla manovra fiscale regionale rispetto all'importo che ha formato oggetto di accertamento e di impegno, detto evento e' contabilmente registrato nell'esercizio nel quale tale perdita si determina come cancellazione di residui attivi.

3. Per la parte in conto capitale riferita all'edilizia sanitaria di cui all'articolo 20 della legge 11 marzo 1988, n. 67, e successive modificazioni, le regioni accertano e impegnano nel corso dell'esercizio l'importo corrispondente a quello indicato nel decreto di ammissione al finanziamento. In caso di revoca dell' ammissione a finanziamento ai sensi dell'articolo 1, comma 310, della legge 23 dicembre 2005, n. 266, le regioni registrano detto evento nell'esercizio nel quale la revoca e' disposta. (16) ((22))

------------- AGGIORNAMENTO (16) Il D.L. 24 aprile 2017, n. 50, convertito con modificazioni dalla L. 21 giugno 2017, n. 96, ha disposto (con l'art. 31, comma 1) che "In deroga alle disposizioni recate dall'articolo 20, comma 3, primo periodo, del decreto legislativo 23 giugno 2011, n. 118, le somme per interventi di edilizia sanitaria compresi in accordi di programma sottoscritti nel 2016 ammessi a finanziamento nel 2017 sono accertate in entrata dalle regioni nel 2018. I termini di risoluzione degli accordi di programma di cui all'articolo 1, comma 310, della legge 23 dicembre 2005, n. 266 sono prorogati in ragione del periodo di sospensione che si realizza nel 2017". ------------- AGGIORNAMENTO (22) La L. 27 dicembre 2017, n. 205 ha disposto (con l'art. 1, comma 777) che "In deroga alle disposizioni recate dall'articolo 20, comma 3, primo periodo, del decreto legislativo 23 giugno 2011, n. 118, le somme per interventi di edilizia sanitaria compresi in accordi di programma sottoscritti nel 2017 ammessi a finanziamento nel 2018 sono accertate in entrata dalle regioni nel 2019".

### Art. 21. - Accensione di conti di tesoreria intestati alla sanita'

1. Per garantire trasparenza e confrontabilita' dei flussi di cassa relativi al finanziamento del fabbisogno sanitario regionale standard:

- a) le risorse destinate al finanziamento del fabbisogno sanitario regionale standard che affluiscono nei conti di tesoreria unica intestati alle singole regioni e a titolo di trasferimento dal Bilancio dello Stato e di anticipazione mensile di tesoreria sono versate in conti di tesoreria unica appositamente istituiti per il finanziamento del servizio sanitario nazionale e funzionanti secondo le modalita' di cui all'articolo 7 del decreto legislativo 7 agosto 1997, n. 279;
- b) le ulteriori risorse destinate al finanziamento del Servizio sanitario nazionale sono versate in appositi conti correnti intestati alla sanita' presso i tesorieri delle regioni secondo le modalita' previste dall'articolo 77-quater, comma 2, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133.

2. Ai fini della rilevazione SIOPE le regioni sono identificate da distinti codici-ente, riguardanti la gestione non sanitaria e la gestione sanitaria.

### Art. 22. - Individuazione delle responsabilita' all'interno delle regioni nel caso di sussistenza della gestione sanitaria accentrata presso la regione

1. Le regioni che esercitano la scelta di gestire direttamente presso la regione una quota del finanziamento del proprio servizio sanitario di cui all'articolo 19, comma 2, lettera b), punto i), individuano nella propria struttura organizzativa uno specifico centro di responsabilita', d'ora in poi denominato gestione sanitaria accentrata presso la regione, deputato all'implementazione ed alla tenuta di una contabilita' di tipo economico-patrimoniale atta a rilevare, in maniera sistematica e continuativa, i rapporti economici, patrimoniali e finanziari intercorrenti fra la singola regione e lo Stato, le altre regioni, le aziende sanitarie, gli altri enti pubblici ed i terzi vari, inerenti le operazioni finanziate con risorse destinate ai rispettivi servizi sanitari regionali.

2. Il responsabile della gestione sanitaria accentrata presso la regione registra i fatti gestionali nel libro giornale e li imputa ai conti relativi a singole categorie di valori omogenei, provvedendo alla rilevazione dei costi, dei ricavi e delle variazioni negli elementi attivi e passivi del patrimonio, in modo da dame rappresentazione nel bilancio di esercizio.

3. Le regioni individuano il responsabile della gestione sanitaria accentrata presso la regione che e' tenuto:

- a) all'elaborazione e all'adozione del bilancio di esercizio della gestione sanitaria accentrata presso la regione;
- b) alla coerente compilazione, con il bilancio di esercizio della gestione sanitaria accentrata presso la regione, dei modelli ministeriali CE e SP di cui al decreto ministeriale 13 novembre 2007 e successive modificazioni ed integrazioni, e relativi all'ente ivi identificato con il codice "000";
- c) alla redazione del bilancio sanitario consolidato mediante il consolidamento dei conti della gestione accentrata stessa e dei conti degli enti di cui all'articolo 19, comma 2, lettera c), secondo le modalita' definite nell'articolo 32. In sede di consolidamento, il responsabile della gestione sanitaria accentrata presso la regione garantisce la coerenza del bilancio sanitario consolidato con le risultanze dei modelli ministeriali CE e SP di cui al decreto ministeriale 13 novembre 2007 e s.m.i. e relative all'ente ivi identificato con il codice "999". In sede di consolidamento, il responsabile della gestione sanitaria accentrata presso la regione ed il responsabile della predisposizione del bilancio regionale, assicurano l'integrale raccordo e riconciliazione tra le poste iscritte e contabilizzate in termini di contabilita' economico-patrimoniale e quelle iscritte in termini di contabilita' finanziaria. Tale riconciliazione e' obbligatoriamente riportata nella nota integrativa di cui all'articolo 32;
- d) Le regioni individuano un responsabile regionale che certifichi, con riferimento alla gestione sanitaria accertata presso la regione: i. in sede di rendicontazione trimestrale, la regolare tenuta dei libri contabili e della contabilita', la riconciliazione dei dati della gestione accentrata con le risultanze del bilancio finanziario, la riconciliazione dei dati di cassa, la coerenza dei dati inseriti nei modelli ministeriali di rilevazione dei conti con le risultanze della contabilita'; ii. in sede di rendicontazione annuale, quando indicato al punto i), nonche' la corrispondenza del bilancio alle risultanze della contabilita'.

### Art. 23. - Individuazione delle responsabilita' all'interno delle regioni nel caso di gestione integrale del finanziamento del servizio sanitario regionale presso gli enti di cui del servizio sanitario regionale

1. Le regioni che non esercitano la scelta di gestire direttamente presso la regione una quota del finanziamento del proprio servizio sanitario di cui all' articolo 19, comma 2, lettera b), punto i):

- a) ne danno preventivamente comunicazione ai Ministeri dell'economia e delle finanze e della salute;
- b) trattano presso la regione le sole operazioni di consolidamento dei conti sanitari degli enti di cui all'articolo 19, comma 2, lettera c), come disciplinato dall'articolo 22, comma 3, lettera c). A tal fine e' comunque formalmente individuato un responsabile presso la regione, al quale si applicano le disposizioni recate dall'articolo 32;
- c) non possono effettuare, a valere sui capitoli di spesa del servizio sanitario regionale, operazioni di gestione diverse dal mero trasferimento delle somme agli enti del servizio sanitario regionale di cui all'articolo 19, comma 2, lettera c). A tal fine le regioni destinano in ciascun esercizio agli enti del servizio sanitario regionale l'intero importo del finanziamento previsto nell'esercizio di riferimento.

### Art. 24. - Libri obbligatori della gestione sanitaria accentrata presso la regione

1. Nelle regioni che esercitano la scelta di gestire direttamente presso la regione una quota del finanziamento del proprio servizio sanitario di cui all'articolo 19, comma 2, lettera b), punto i), i libri contabili obbligatori della gestione sanitaria accentrata presso la regione sono il libro giornale ed il libro degli inventari. Il libro giornale registra indistintamente, in ordine cronologico, tutti i fatti di gestione che abbiano rilievo sui risultati d'esercizio. Il libro degli inventari contiene l'indicazione e la valutazione di tutte le attivita' e le passivita' relative alla gestione sanitaria accentrata presso la regione. All'aggiornamento del libro degli inventari si provvede al termine dell'esercizio.

### Art. 25. - Bilancio preventivo economico annuale

1. Gli enti di cui all'articolo 19, comma 2, lettera b), punto i), ove ricorrano le condizioni ivi previste, e lettera c) predispongono un bilancio preventivo economico annuale, in coerenza con la programmazione sanitaria e con la programmazione economico-finanziaria della regione.

((1-bis. Le regioni e le province autonome di Trento e di Bolzano devono garantire una programmabilita' degli investimenti da effettuare nel proprio ambito territoriale, attraverso la predisposizione di piani annuali di investimento accompagnati da un'adeguata analisi dei fabbisogni e della relativa sostenibilita' economico-finanziaria complessiva, da attuare anche in sede di predisposizione del previsto piano dei flussi di cassa prospettici di cui al comma 2))

2. Il bilancio preventivo economico annuale include un conto economico preventivo e un piano dei flussi di cassa prospettici, redatti secondo gli schemi di conto economico e di rendiconto finanziario previsti dall'articolo 26. Al conto economico preventivo e' allegato il conto economico dettagliato, secondo lo schema CE di cui al decreto ministeriale 13 novembre 2007 e successive modificazioni ed integrazioni.

3. Il bilancio preventivo economico annuale e' corredato da una nota illustrativa, dal piano degli investimenti e da una relazione redatta dal direttore generale per gli enti di cui alla lettera c) del comma 2 dell'articolo 19 e dal responsabile della gestione sanitaria accentrata presso la regione per gli enti di cui all'articolo 19, comma 2, lettera b), punto i), ove ricorrano le condizioni ivi previste. La nota illustrativa esplicita i criteri impiegati nell' elaborazione del bilancio preventivo economico annuale; la relazione del direttore generale o del responsabile della gestione sanitaria accentrata evidenzia i collegamenti con gli altri atti di programmazione aziendali e regionali; il piano degli investimenti definisce gli investimenti da effettuare nel triennio e le relative modalita' di finanziamento. Il bilancio preventivo economico annuale degli enti di cui all'articolo 19, comma 2, lettera c) e lettera b), punto i), ove ricorrano le condizioni ivi previste, deve essere corredato dalla relazione del collegio sindacale.

4. Gli enti di cui alla lettera d), del comma 2 dell'articolo 19 predispongono un bilancio preventivo economico annuale, corredato da una nota illustrativa che espliciti i criteri impiegati nell'elaborazione dello stesso, nonche' da un piano degli investimenti che definisca gli investimenti da effettuare nel triennio e le relative modalita' di finanziamento. Il bilancio preventivo economico annuale deve essere corredato dalla relazione del collegio dei revisori. Con delibera del direttore generale, il bilancio preventivo economico annuale, corredato dalla nota illustrativa, dal piano triennale degli investimenti e dalla relazione del collegio dei revisori, viene sottoposto al Consiglio di amministrazione dell'ente per l'approvazione.

### Art. 26. - Bilancio di esercizio e schemi di bilancio degli enti del SSN

1. Il bilancio d'esercizio e' redatto con riferimento all'anno solare. Si compone dello stato patrimoniale, del conto economico, del rendiconto finanziario e della nota integrativa ed e' corredato da una relazione sulla gestione sottoscritta dal direttore generale, per gli enti di cui alle lettere c) e d) del comma 2 dell'articolo 19, e dal responsabile della gestione sanitaria accentrata presso la regione, per gli enti di cui all'articolo 19, comma 2, lettera b), punto i), ove ricorrano le condizioni ivi previste.

2. Il bilancio di esercizio predisposto dagli enti di cui alla lettera d), comma 2, dell'articolo 19 viene sottoposto al Consiglio di amministrazione dell'ente per l'approvazione.

3. Per conferire struttura uniforme alle voci del bilancio preventivo economico annuale e del bilancio d'esercizio, nonche' omogeneita' ai valori inseriti in tali voci, gli enti di cui all'articolo 19, comma 2, lettera c) e lettera b), punto i), ove ricorrano le condizioni ivi previste redigono il bilancio di esercizio secondo gli appositi schemi di cui all'allegato n. 2, che costituiscono parte integrante del presente decreto legislativo. Gli enti di cui alla lettera d), comma 2, dell'articolo 19 adottano i medesimi schemi di bilancio, adattando la nota integrativa e la relazione sulla gestione alle specificita' del proprio ambito operativo. ((3))

4. Per gli enti di cui all'articolo 19, comma 2, lettera c) e lettera b), punto i), ove ricorrano le condizioni ivi previste, la nota integrativa deve contenere anche i modelli CE ed SP per l'esercizio in chiusura e per l'esercizio precedente e la relazione sulla gestione deve contenere anche il modello di rilevazione LA, di cui al decreto ministeriale 18 giugno 2004 e successive modificazioni ed integrazioni, per l'esercizio in chiusura e per l'esercizio precedente, nonche' un'analisi dei costi sostenuti per l'erogazione dei servizi sanitari, distinti per ciascun livello essenziale di assistenza.

-------------- AGGIORNAMENTO (3) Il Decreto 20 marzo 2013 (in SO n. 30, relativo alla G.U. 15/04/2013, n. 88) ha disposto (con l'art. 1, comma 1) che "Gli schemi dello Stato Patrimoniale, del Conto Economico e della Nota Integrativa di cui agli articoli 26, comma 3 e 32, comma 6 del decreto legislativo 23 giugno 2011, n. 118, sono modificati rispettivamente secondo gli schemi di cui agli allegati 1, 2 e 3 al presente decreto".

### Art. 27. - Piano dei conti

1. Al fine di soddisfare le esigenze di standardizzazione delle procedure contabili e dei debiti informativi previsti dalla normativa vigente, ciascuna voce del piano dei conti degli enti di cui all'articolo 19, comma 2, lettera c) e lettera b), punto i), ove ricorrano le condizioni ivi previste, deve essere univocamente riconducibile ad una sola voce dei modelli di rilevazione SP o CE di cui al decreto ministeriale 13 novembre 2007 e successive modificazioni ed integrazioni.

2. Gli enti di cui al comma 1 possono dettagliare il proprio piano dei conti inserendo ulteriori sottovoci, rispetto a quelle di cui ai modelli di rilevazione SP e CE di cui al decreto ministeriale 13 novembre 2007 e successive modificazioni ed integrazioni, secondo le proprie esigenze informative.

### Art. 28. - Norme generali di riferimento

1. Per la redazione del bilancio d'esercizio gli enti di cui alle lettere b), punto i), c) e d) del comma 2 dell'articolo 19 applicano gli articoli da 2423 a 2428 del codice civile, fatto salvo quanto diversamente disposto nel presente titolo.

### Art. 29. - Principi di valutazione specifici del settore sanitario

1. Al fine di soddisfare il principio generale di chiarezza e di rappresentazione veritiera e corretta, nonche' di garantire l'omogeneita', la confrontabilita' ed il consolidamento dei bilanci dei servizi sanitari regionali, sono individuate le modalita' di rappresentazione, da parte degli enti di cui all'articolo 19, comma 2, lettera c) e lettera b), punto i), ove ricorrano le condizioni ivi previste, delle seguenti fattispecie:

- a) il costo delle rimanenze di beni fungibili e' calcolato con il metodo della media ponderata;
- c) i contributi in conto capitale da regione sono rilevati sulla base del provvedimento di assegnazione. I contributi sono iscritti in un'apposita voce di patrimonio netto, con contestuale rilevazione di un credito verso regione. Laddove siano impiegati per l'acquisizione di cespiti ammortizzabili, i contributi vengono successivamente stornati a proventi con un criterio sistematico, commisurato all'ammortamento dei cespiti cui si riferiscono, producendo la sterilizzazione dell'ammortamento stesso. Nel caso di cessione di beni acquisiti tramite contributi in conto capitale con generazione di minusvalenza, viene stornata a provento una quota di contributo commisurata alla minusvalenza. La quota di contributo residua resta iscritta nell'apposita voce di patrimonio netto ed e' utilizzata per sterilizzare l'ammortamento dei beni acquisiti con le disponibilita' generate dalla dismissione. Nel caso di cessione di beni acquisiti tramite contributi in conto capitale con generazione di plusvalenza, la plusvalenza viene direttamente iscritta in una riserva del patrimonio netto, senza influenzare il risultato economico dell'esercizio. La quota di contributo residua resta iscritta nell'apposita voce di patrimonio netto ed e' utilizzata, unitamente alla riserva derivante dalla plusvalenza, per sterilizzare l'ammortamento dei beni acquisiti con le disponibilita' generate dalla dismissione. Le presenti disposizioni si applicano anche ai contributi in conto capitale dallo Stato e da altri enti pubblici, a lasciti e donazioni vincolati all'acquisto di immobilizzazioni, nonche' a conferimenti, lasciti e donazioni di immobilizzazioni da parte dello Stato, della regione, di altri soggetti pubblici o privati;
- d) i contributi per ripiano perdite sono rilevati in un'apposita voce del patrimonio netto sulla base del provvedimento regionale di assegnazione, con contestuale iscrizione di un credito verso regione. Al momento dell'incasso del credito, il contributo viene stornato dall'apposita voce del patrimonio netto e portato a diretta riduzione della perdita all'interno della voce «utili e perdite portati a nuovo»;
- e) le quote di contributi di parte corrente finanziati con somme relative al fabbisogno sanitario regionale standard, vincolate ai sensi della normativa nazionale vigente e non utilizzate nel corso dell'esercizio, sono accantonate nel medesimo esercizio in apposito fondo spese per essere rese disponibili negli esercizi successivi di effettivo utilizzo;
- f) le plusvalenze, le minusvalenze, le donazioni che non consistano in immobilizzazioni, ne' siano vincolate all'acquisto di immobilizzazioni, nonche' le sopravvenienze e le insussistenze, sono iscritte fra i proventi e gli oneri straordinari;
- g) lo stato dei rischi aziendali e' valutato dalla regione, che verifica l'adeguatezza degli accantonamenti ai fondi rischi e oneri iscritti nei bilanci di esercizio degli enti. Il collegio sindacale dei suddetti enti attesta l'avvenuto rispetto degli adempimenti necessari per procedere all'iscrizione dei fondi rischi ed oneri ed al relativo utilizzo;
- h) le somme di parte corrente assegnate alle regioni, a titolo di finanziamento ordinario del Servizio sanitario nazionale, tramite atto formale di individuazione del fabbisogno sanitario regionale standard e delle relative fonti di finanziamento, sono iscritte, ove sussista la gestione di cui all'articolo 19, comma 2, lettera b), punto i), dal responsabile della gestione sanitaria accentrata presso la regione nella propria contabilita' generale, come credito e contestualmente come passivita' per finanziamenti da allocare. Ai fini della contabilizzazione della mobilita' sanitaria extraregionale attiva e passiva, si prende a riferimento la matrice della mobilita' extraregionale approvata dal Presidente della Conferenza delle Regioni e delle Province autonome ed inserita nell' atto formale di individuazione del fabbisogno sanitario regionale standard e delle relative fonti di finanziamento dell'anno di riferimento;
- i) ove sussista la gestione di cui all'articolo 19, comma 2, lettera b), punto i), per la parte di finanziamento assegnata dalla regione agli enti di cui alla lettera c) del comma 2 dell'articolo 19, mensilmente il responsabile della gestione sanitaria accentrata presso la regione storna la passivita' per finanziamenti da allocare in ragione di un dodicesimo dell'intero importo, iscrivendo parimenti debiti verso le singole aziende in dodicesimi. Gli enti di cui alla predetta lettera c) del comma 2 dell'articolo 19 contestualmente rilevano un credito verso la regione e un ricavo sempre in ragione di un dodicesimo. Per la parte di finanziamento assegnata agli enti di cui all'articolo 19, comma 2, lettera b), punto i), limitatamente alla quota riferita alla spesa sanitaria direttamente gestita, dal momento dell'assegnazione il responsabile della gestione sanitaria accentrata presso la regione storna la passivita' per finanziamenti da allocare, iscrivendo proventi in ragione di un dodicesimo per ogni mese. Al termine dell'esercizio, eventuali quote non assegnate ne' agli enti di cui all'articolo 19, comma 2, lettera b), punto i), ne' agli enti di cui alla predetta lettera c) si intendono attribuite alla gestione sanitaria accentrata presso la regione e, conseguentemente, stornate da passivita' per finanziamenti da allocare a proventi della stessa gestione sanitaria accentrata. Il responsabile della gestione sanitaria accentrata presso la regione impartisce disposizioni agli enti di cui alla predetta lettera c) sulla rilevazione dei proventi e dei costi per mobilita' extraregionale, al fine di garantire la corrispondenza dei dati aziendali con quanto disposto nell'ultimo periodo della lettera h);
- j) con modalita' analoghe a quelle previste per le somme di parte corrente, di cui al primo periodo della lettera h), ove sussista la gestione di cui all'articolo 19, comma 2, lettera b), punto i), il responsabile della gestione sanitaria accentrata presso la regione iscrive nella propria contabilita' generale le altre entrate regionali per l'assistenza sanitaria e ne definisce l'assegnazione alle aziende sanitarie. Tali assegnazioni sono rilevate dalle aziende con le modalita' stabilite alla lettera i) se destinate al finanziamento di parte corrente; sono invece rilevate con le modalita' stabilite alle lettere c) e d) se destinate rispettivamente al finanziamento degli investimenti o al ripiano delle perdite. In tutti i casi va garantita la corrispondenza tra i crediti verso regione iscritti nei bilanci degli enti di cui alla lettera c) del comma 2 dell'articolo 19 del presente titolo e i debiti verso aziende iscritti nel bilancio della gestione sanitaria accentrata presso la regione;
- k) alle disposizioni recate dalle lettere h), i) e j), qualora le singole regioni non esercitino la scelta di gestire direttamente presso la regione o la provincia autonoma una quota del finanziamento del proprio servizio sanitario, provvedono le singole aziende di cui all'articolo 19, comma 2, lettera c), per quanto di loro competenza, sulla base delle assegnazioni del finanziamento del servizio sanitario regionale effettuate dalla regione in loro favore a seguito di atto formale di individuazione del fabbisogno sanitario regionale standard e delle relative fonti di finanziamento. In tutti i casi va garantita la corrispondenza fra il finanziamento complessivo del servizio sanitario regionale e la somma dei finanziamenti registrati dalle aziende di cui all'articolo 19, comma 2, lettera c). (1)

------------- AGGIORNAMENTO (1) La Corte Costituzionale, con sentenza 2 - 11 luglio 2012, n. 178 (in G.U. 1a s.s. 18/7/2012, n. 29) ha dichiarato "l'illegittimita' costituzionale dell'alinea e della lettera k) del comma 1 dell'art. 29 del d.lgs. n. 118 del 2011, nella parte in cui si applicano direttamente alle Regioni autonome ed alle Province autonome".

### Art. 30. - Destinazione del risultato d'esercizio degli enti del SSN

1. L'eventuale risultato positivo di esercizio degli enti di cui alle lettere b), punto i), c) e d) del comma 2 dell'articolo 19 e' portato a ripiano delle eventuali perdite di esercizi precedenti. L'eventuale eccedenza e' accantonata a riserva ovvero, limitatamente agli enti di cui alle lettere b) punto i), e c) del comma 2 dell'articolo 19, e' reso disponibile per il ripiano delle perdite del servizio sanitario regionale. ((Fermo restando quanto previsto dall'articolo 2, comma 80, della legge 23 dicembre 2009, n. 191, eventuali risparmi nella gestione del Servizio sanitario nazionale effettuati dalle regioni rimangono nella disponibilita' delle regioni stesse per finalita' sanitarie)).

### Art. 31. - Adozione del bilancio d'esercizio

1. Il bilancio di esercizio e' adottato entro il 30 aprile dell' anno successivo a quello di riferimento dal direttore generale per gli enti di cui alla lettera c) del comma 2 dell' articolo 19, e dal responsabile della gestione sanitaria accentrata presso la regione per gli enti di cui alla lettera b), punto i), del comma 2 dell' articolo 19, ed e' corredato dalla relazione del collegio sindacale. Gli enti di cui alla lettera c) del comma 2 dell'articolo 19 provvedono, altresi', a trasmettere al responsabile della gestione sanitaria accentrata presso la regione il bilancio di esercizio e la relazione del collegio sindacale ai fini della: predisposizione delle necessarie operazioni di consolidamento, di cui all'articolo 32.

2. Entro la medesima data del 30 aprile dell'anno successivo a quello di riferimento, gli enti di cui alla lettera d) del comma 2 dell' articolo 19 devono trasmettere al Ministero della Salute il bilancio di esercizio corredato dalla relazione del collegio dei revisori.

### Art. 32. - Bilancio consolidato del Servizio Sanitario Regionale

1. La gestione sanitaria accentrata presso la regione predispone e sottopone all'approvazione della giunta regionale sia il bilancio preventivo economico annuale consolidato del Servizio Sanitario Regionale, di cui al comma 5, sia il bilancio d'esercizio consolidato del Servizio Sanitario Regionale, di cui al comma 7.

2. Per la redazione dei bilanci consolidati di cui al comma 1 si applicano le disposizioni del Decreto legislativo n. 127 del 1991, fatto salvo quanto disposto dal presente titolo.

3. L'area di consolidamento comprende tutti gli enti di cui alle lettere b), punto i), e c) del comma 2 dell' articolo 19 ed esclude soggetti eventualmente partecipati da questi ultimi. Il patrimonio netto consolidato e' determinato dalla somma dei valori di patrimonio netto degli enti consolidati. Con il decreto del Presidente del Consiglio dei Ministri di cui all'articolo 36, comma 2, sono definite le modalita' di sperimentazione riguardanti la previsione di un ulteriore bilancio consolidato che comprenda i soggetti controllati dagli enti di cui all'articolo 19, comma 2, lettere b), punto i), e c).

4. Il bilancio preventivo economico annuale consolidato si compone ed e' corredato dagli stessi documenti che compongono e corredano il bilancio preventivo economico annuale dei singoli enti di cui all'articolo 25. La relazione del direttore generale e' sostituita da una relazione del responsabile della gestione sanitaria accentrata presso la regione. Salvi gli adeguamenti necessari, la struttura e il contenuto dei documenti che compongono e corredano il bilancio preventivo economico annuale consolidato sono quelli prescritti per il bilancio preventivo economico annuale dei singoli enti di cui all'articolo 19, comma 2, lettere b), punto i), e c) del presente titolo.

5. La giunta regionale approva i bilanci preventivi economici annuali degli enti di cui alle lettere b), punto i), e c) del comma 2 dell'articolo 19 e il bilancio preventivo economico annuale consolidato di cui al comma 4 entro il 31 dicembre dell'anno precedente a quello cui i bilanci economici preventivi si riferiscono. Entro sessanta giorni dalla data di approvazione, i bilanci in oggetto sono pubblicati integralmente sul sito internet della regione.

6. Il bilancio d'esercizio consolidato si compone ed e' corredato dagli stessi documenti che compongono e corredano il bilancio d'esercizio dei singoli enti di cui all'articolo 26. La relazione del direttore generale e' sostituita da una relazione del responsabile della gestione sanitaria accentrata presso la regione. Salvi gli adeguamenti necessari, la struttura e il contenuto dei documenti che compongono e corredano il bilancio d'esercizio consolidato sono quelli prescritti per il bilancio d'esercizio dei singoli enti di cui all'articolo 19, comma 2, lettere b), punto i), e c). I modelli SP e CE di cui al decreto ministeriale 13 novembre 2007 e successive modificazioni ed integrazioni, da inserire nella nota integrativa del bilancio d'esercizio consolidato, ed il modello LA di cui al decreto ministeriale 18 giugno 2004 e successive modificazioni ed integrazioni, da inserire nella relazione sulla gestione, sono quelli relativi al codice 999. La nota integrativa al bilancio consolidato deve in ogni caso contenere: (a) il prospetto di cui all'articolo 22, comma 3, lettera c), che illustri l'integrale raccordo tra le poste iscritte nel bilancio d'esercizio consolidato e quelle iscritte nel rendiconto di contabilita' finanziaria; (b) un prospetto che, per ogni eventuale partecipazione detenuta dalle aziende di cui alla lettera c) del comma 2 dell'articolo 19 presso altri soggetti, indichi denominazione, sede, importo totale dell'attivo, importo del patrimonio netto, utile o perdita dell'ultimo esercizio, quota posseduta da ciascuna azienda del servizio sanitario regionale ed eventualmente dalla regione, valore attribuito nel bilancio consolidato e criterio di valutazione adottato; (c) un prospetto che, per ogni altra societa' partecipata o ente dipendente della regione che riceva a qualsiasi titolo una quota delle risorse destinate al finanziamento del fabbisogno sanitario regionale standard o delle ulteriori risorse destinate al finanziamento del servizio sanitario regionale, indichi denominazione, sede, importo totale dell' attivo, importo del patrimonio netto, utile o perdita dell'ultimo esercizio, quota posseduta dalla regione. ((3))

7. La giunta regionale approva i bilanci d'esercizio degli enti di cui alle lettere b), punto i), e c) del comma 2 dell'articolo 19 entro il termine del 31 maggio dell'anno successivo a quello di riferimento e il bilancio consolidato nel termine del 30 giugno dell'anno successivo a quello di riferimento. Entro sessanta giorni dalla data di approvazione, i bilanci in oggetto sono pubblicati integralmente sul sito internet della regione.

8. Per favorire la compatibilita' e l'uniformita' dei bilanci da consolidare, il responsabile della gestione sanitaria accentrata presso la regione puo' stabilire specifici obblighi informativi a carico degli enti di cui alla lettera c) del comma 2 dell'articolo 19 e prescrivere trattamenti contabili omogenei, nei limiti di quanto stabilito dagli articoli 28 e 29.

-------------- AGGIORNAMENTO (3) Il Decreto 20 marzo 2013 (in SO n. 30, relativo alla G.U. 15/04/2013, n. 88) ha disposto (con l'art. 1, comma 1) che "Gli schemi dello Stato Patrimoniale, del Conto Economico e della Nota Integrativa di cui agli articoli 26, comma 3 e 32, comma 6 del decreto legislativo 23 giugno 2011, n. 118, sono modificati rispettivamente secondo gli schemi di cui agli allegati 1, 2 e 3 al presente decreto".

### Art. 33. - Tassonomia per gli enti in contabilita' civilista

1. Al fine di consentire l'elaborazione dei conti di cassa consolidati delle amministrazioni pubbliche, la riclassificazione dei dati contabili degli enti di cui all'articolo 19, lettere c) e d), e' operata attraverso la rilevazione SIOPE di cui all'articolo 14, comma 6, della legge 31 dicembre 2009, n. 196.

2. ((Gli enti di cui al comma 1 allegano il prospetto concernente la ripartizione dei pagamenti per missioni e programmi, definito secondo le modalita' di cui all'allegato n. 16, al bilancio di esercizio e, a decorrere dal 2017, al bilancio preventivo economico annuale. Il prospetto allegato al bilancio di esercizio e' elaborato in coerenza con i risultati della tassonomia effettuata attraverso la rilevazione SIOPE.)) Nel caso di corrispondenza non univoca tra programma e funzioni COFOG di secondo livello, vanno individuate due o piu' funzioni COFOG con l'indicazione delle percentuali di attribuzione della spesa del programma a ciascuna di esse.

((

2-bis. Il prospetto di cui all'allegato n. 16 e' aggiornato con decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, di concerto con il Ministero dell'interno - Dipartimento per gli affari interni e territoriali e la Presidenza del Consiglio dei ministri - Dipartimento per gli affari regionali, su proposta della Commissione per l'armonizzazione contabile degli enti territoriali.

))

### Art. 34. - Aggiornamento schemi tecnici

1. In funzione di eventuali emergenti fabbisogni informativi, anche in conseguenza dell'attivita' di monitoraggio dei conti sanitari e dell'erogazione dei livelli di assistenza, ovvero di aggiornamento dei livelli essenziali di assistenza, nonche' della definizione del livello minimo di articolazione del piano dei conti integrato di cui all'articolo 36, comma 2, i relativi necessari aggiornamenti degli schemi allegati al presente decreto legislativo, di cui agli articoli 26 e 32 nonche' la tabella di cui all'articolo 29, comma 1, lettera b) sono effettuati con decreto del Ministro della Salute, di concerto con il Ministro dell'economia e delle finanze, d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano.

### Art. 35. - Sistemi informativi e statistici della Sanita'

1. Al fine di migliorare i sistemi informativi e statistici della sanita' e per il loro migliore utilizzo in termini di monitoraggio dell'organizzazione dei livelli di assistenza, con procedure analoghe a quanto previsto dall'articolo 34, con decreto del Ministro della salute vengono stabilite le procedure di anonimizzazione dei dati individuali presenti nei flussi informativi, gia' oggi acquisiti in modo univoco sulla base del codice fiscale dell'assistito, con la trasformazione del codice fiscale, ai fini di ricerca per scopi di statistica sanitaria, in codice anonimo, mediante apposito algoritmo biunivoco, in modo da tutelare l'identita' dell'assistito nel procedimento di elaborazione dei dati. I dati cosi' anonimizzati sono utilizzati per migliorare il monitoraggio e la valutazione della qualita' e dell'efficacia dei percorsi di cura, con un pieno utilizzo degli archivi informatici dell'assistenza ospedaliera, specialistica, farmaceutica.

## Ordinamento finanziario e contabile delle regioni))

### Art. 36. - (( (Principi generali in materia di finanza regionale).))

((

1. Il presente titolo disciplina i bilanci delle regioni ai sensi dell'art. 117, comma 2, lettera e), della Costituzione.

2. La finanza regionale concorre con la finanza statale e locale al perseguimento degli obiettivi di convergenza e di stabilita' derivanti dall'appartenenza dell'Italia all'Unione europea ed opera in coerenza con i vincoli che ne derivano in ambito nazionale.

3. Le regioni ispirano la propria gestione al principio della programmazione. A tal fine adottano ogni anno il bilancio di previsione finanziario, le cui previsioni, riferite ad un orizzonte temporale almeno triennale, sono elaborate sulla base delle linee strategiche e delle politiche contenute nel documento di economia e finanza regionale (DEFR), predisposto secondo le modalita' previste dal principio contabile applicato della programmazione allegato al presente decreto. Il DEFR e' approvato con una delibera del consiglio regionale. Con riferimento al periodo di programmazione decorrente dall'esercizio 2015, le regioni non sono tenute alla predisposizione del documento di economia e finanza regionale e adottano il documento di programmazione previsto dall'ordinamento contabile vigente nell'esercizio 2014. Il primo documento di economia e finanza regionale e' adottato con riferimento agli esercizi 2016 e successivi. Gli enti che hanno partecipato alla sperimentazione nel 2014 adottano la disciplina prevista dal presente articolo a decorrere dal 1° gennaio 2015.

4. La regione adotta, in relazione alle esigenze derivanti dallo sviluppo della fiscalita' regionale, una legge di stabilita' regionale, contenente il quadro di riferimento finanziario per il periodo compreso nel bilancio di previsione. Essa contiene esclusivamente norme tese a realizzare effetti finanziari con decorrenza dal primo anno considerato nel bilancio di previsione ed e' disciplinata dal principio applicato riguardante la programmazione, allegato n. 4/1 al presente decreto.

5. Le regioni adottano i principi contabili generali ed i principi contabili applicati di cui agli allegati n. 1 e n. 4 al presente decreto.

))

### Art. 37. - (( (Sistema contabile).))

((

1. Il sistema contabile delle regioni, in attuazione dell'art. 2, comma 2, lettera h), della legge 5 maggio 2009, n. 42, garantisce la rilevazione unitaria dei fatti gestionali sotto il profilo finanziario, economico e patrimoniale, attraverso l'adozione:

- a) della contabilita' finanziaria, che ha natura autorizzatoria e consente la rendicontazione della gestione finanziaria;
- b) della contabilita' economico-patrimoniale, per la rilevazione, ai fini conoscitivi, degli effetti economici e patrimoniali dei fatti gestionali, che consente la rendicontazione economico e patrimoniale.

2. Le regioni garantiscono la rilevazione unitaria dei fatti gestionali sotto il profilo finanziario ed economico patrimoniale adottando il piano dei conti integrato di cui all'art. 4.

3. Al fine di consentire la tracciabilita' di tutte le operazioni gestionali e la movimentazione delle voci del piano dei conti integrato, ad ogni transazione e' attribuita una codifica da applicare secondo le modalita' previste dagli articoli 5, 6 e 7.

4. Le previsioni di competenza e di cassa, aggregate secondo l'articolazione del piano dei conti di quarto livello, e i risultati della gestione di competenza e di cassa aggregati secondo l'articolazione del piano dei conti, sono trasmessi alla banca dati unitaria delle amministrazioni pubbliche di cui all'art. 13, comma 3, della legge 31 dicembre 2009, n. 196, sulla base di schemi, tempi e modalita' definiti con decreto del Ministro dell'economia e delle finanze.))

------------- AGGIORNAMENTO (1) La Corte Costituzionale, con sentenza 2 - 11 luglio 2012, n. 178 (in G.U. 1a s.s. 18/7/2012, n. 29), ha dichiarato "l'illegittimita' costituzionale del secondo periodo del comma 1 dell'art. 37 del decreto legislativo 23 giugno 2011, n. 118 (Disposizioni in materia di armonizzazione dei sistemi contabili e degli schemi di bilancio delle Regioni, degli enti locali e dei loro organismi, a norma degli articoli 1 e 2 della legge 5 maggio 2009, n. 42".

### Art. 38. - (( (Leggi regionali di spesa e relativa copertura finanziaria).))

((

1. Le leggi regionali che prevedono spese a carattere continuativo quantificano l'onere annuale previsto per ciascuno degli esercizi compresi nel bilancio di previsione e indicano l'onere a regime ovvero, nel caso in cui non si tratti di spese obbligatorie, possono rinviare le quantificazioni dell'onere annuo alla legge di bilancio.

2. Le leggi regionali che dispongono spese a carattere pluriennale indicano l'ammontare complessivo della spesa, nonche' la quota eventualmente a carico del bilancio in corso e degli esercizi successivi. La legge di stabilita' regionale puo' annualmente rimodulare le quote previste per ciascuno degli anni considerati nel bilancio di previsione e per gli esercizi successivi, nei limiti dell'autorizzazione complessiva di spesa.

))

### Art. 39. - (( (Il sistema di bilancio delle regioni).))

((

1. Il Consiglio regionale approva ogni anno, con legge, il bilancio di previsione finanziario che rappresenta il quadro delle risorse che la regione prevede di acquisire e di impiegare, riferite ad un orizzonte temporale almeno triennale, esponendo separatamente l'andamento delle entrate e delle spese in base alla legislazione statale e regionale in vigore.

2. Il bilancio di previsione finanziario comprende le previsioni di competenza e di cassa del primo esercizio del periodo considerato e le previsioni di competenza degli esercizi successivi ed e' redatto, secondo gli schemi previsti dall'allegato n. 9, con le modalita' previste dal principio applicato della programmazione di cui all'allegato n. 4/1, dallo statuto e dall'ordinamento contabile. Le previsioni riguardanti il primo esercizio costituiscono il bilancio di previsione finanziario annuale.

3. Il bilancio di previsione finanziario ha carattere autorizzatorio, costituendo limite:

- a) agli accertamenti e agli incassi riguardanti le accensioni di prestiti;
- b) agli impegni e ai pagamenti di spesa. Non comportano limiti alla gestione le previsioni riguardanti i rimborsi delle anticipazioni di tesoreria e le partite di giro.

4. A seguito di eventi intervenuti successivamente all'approvazione del bilancio la giunta, nelle more della necessaria variazione di bilancio, puo' limitare la natura autorizzatoria degli stanziamenti di ciascuno degli esercizi successivi considerati nel bilancio di previsione, al solo fine di garantire gli equilibri di bilancio. Con riferimento a tali stanziamenti, non possono essere assunte obbligazioni giuridiche.

5. Il bilancio di previsione finanziario indica, per ciascuna unita' di voto:

- a) l'ammontare presunto dei residui attivi o passivi alla chiusura dell'esercizio precedente a quello cui il bilancio si riferisce;
- b) l'ammontare delle previsioni di competenza definitive dell'anno precedente a quello cui si riferisce il bilancio;
- c) l'ammontare delle entrate che si prevede di accertare o delle spese di cui si autorizza l'impegno negli esercizi cui il bilancio si riferisce;
- d) l'ammontare delle entrate che si prevede di riscuotere o delle spese di cui si autorizza il pagamento nel primo esercizio considerato nel bilancio, senza distinzioni fra riscossioni e pagamenti in conto competenza e in conto residui.

6. Gli stanziamenti di spesa di competenza sono quantificati nella misura necessaria per lo svolgimento delle attivita' o interventi che sulla base della legislazione vigente daranno luogo ad obbligazioni esigibili negli esercizi considerati nel bilancio di previsione, e sono determinati esclusivamente in relazione alle esigenze funzionali ed agli obiettivi concretamente perseguibili nel periodo cui si riferisce il bilancio di previsione finanziario, restando esclusa ogni quantificazione basata sul criterio della spesa storica incrementale.

7. Nel bilancio di previsione finanziario, prima di tutte le entrate e le spese, sono iscritti:

- a) in entrata, gli importi relativi al fondo pluriennale vincolato di parte corrente e del fondo pluriennale vincolato in c/capitale;
- b) nell'entrata del primo esercizio, gli importi relativi all'utilizzo dell'avanzo di amministrazione presunto, nei casi individuati dall'art. 42, comma 8, con l'indicazione della quota vincolata del risultato di amministrazione utilizzata anticipatamente;
- c) in spesa, l'importo del disavanzo di amministrazione presunto al 31 dicembre dell'esercizio precedente cui il bilancio si riferisce. Il disavanzo di amministrazione presunto puo' essere iscritto nella spesa del bilancio di previsione secondo le modalita' previste dall'art. 42, comma 12;
- d) in entrata, il fondo di cassa presunto dell'esercizio precedente.

8. Nel bilancio, ciascun stanziamento di spesa di cui al comma 5, lettere b) e c), individua:

- a) la quota che e' gia' stata impegnata negli esercizi precedenti con imputazione all'esercizio di riferimento;
- b) la quota dello stanziamento di competenza costituita dal fondo pluriennale vincolato, destinata alla copertura degli impegni che sono stati assunti negli esercizi precedenti con imputazione agli esercizi successivi e degli impegni che si prevede di assumere nell'esercizio con imputazione agli esercizi successivi. Con riferimento a tale quota, non e' possibile impegnare e pagare con imputazione all'esercizio cui lo stanziamento si riferisce. Agli stanziamenti di spesa riguardanti il fondo pluriennale vincolato e' attribuito il medesimo codice del piano dei conti della spesa cui il fondo si riferisce.

9. Formano oggetto di specifica approvazione del consiglio regionale, le previsioni di cui al comma 5, lettere c) e d), per ogni unita' di voto e le previsioni del comma 7.

10. Contestualmente all'approvazione della legge di bilancio la giunta approva, per ciascun esercizio, la ripartizione delle unita' di voto del bilancio in categorie e macroaggregati. Tale ripartizione costituisce il documento tecnico di accompagnamento al bilancio. L'ordinamento contabile disciplina le modalita' con cui, contestualmente all'approvazione del documento tecnico di accompagnamento, la Giunta o il Segretario generale, con il bilancio finanziario gestionale, provvede, per ciascun esercizio, a ripartire le categorie e i macroaggregati in capitoli ai fini della gestione e rendicontazione, ed ad assegnare ai dirigenti titolari dei centri di responsabilita' amministrativa le risorse necessarie al raggiungimento degli obiettivi individuati per i programmi ed i progetti finanziati nell'ambito dello stato di previsione delle spese. I capitoli di entrata e di spesa sono raccordati almeno al quarto livello del piano dei conti di cui all'art. 4.

11. Alla legge concernente il bilancio di previsione finanziario sono allegati i documenti previsti dall'art. 11, comma 3, e i seguenti documenti:

- a) l'elenco dei capitoli che riguardano le spese obbligatorie;
- b) l'elenco delle spese che possono essere finanziate con il fondo di riserva per spese impreviste di cui all'art. 48, comma 1, lettera b).

12. Al documento tecnico di accompagnamento al bilancio di cui al comma 10 sono allegati i documenti previsti dall'art. 11 comma 7.

13. Al bilancio finanziario gestionale di cui al comma 10 e' allegato il prospetto riguardante le previsioni di competenza e di cassa dei capitoli di entrata e di spesa del perimetro sanitario individuate dall'art. 20, comma 1, ove previsto, per ciascun esercizio considerato nel bilancio di previsione. Il prospetto e' articolato, per quanto riguarda le entrate, in titoli, tipologie, categorie e capitoli e, per quanto riguarda le spese, in titoli, macroaggregati e capitoli. Se il bilancio gestionale della regione risulta articolato in modo da distinguere la gestione ordinaria dalla gestione sanitaria, tale allegato non e' richiesto.

14. In relazione a quanto disposto dal comma 6, le regioni adottano misure organizzative idonee a consentire l'analisi ed il controllo dei costi e dei rendimenti dell'attivita' amministrativa, della gestione e delle decisioni organizzative, nonche' la corretta quantificazione delle conseguenze finanziarie dei provvedimenti legislativi di entrata e di spesa.

15. Sono vietate le gestioni di fondi al di fuori del bilancio della regione e dei bilanci di cui all'art. 47.

16. Nella sezione del sito internet della regione dedicata ai bilanci sono pubblicati: il bilancio di previsione finanziario, il relativo documento tecnico di accompagnamento, il bilancio finanziario gestionale, le variazioni del bilancio di previsione, le variazioni del documento tecnico di accompagnamento, il bilancio di previsione assestato, il documento tecnico di accompagnamento assestato e il bilancio gestionale assestato.

))

### Art. 40. - (Equilibrio di bilanci)

1. Per ciascuno degli esercizi in cui e' articolato, il bilancio di previsione e' deliberato in pareggio finanziario di competenza, comprensivo dell'utilizzo dell'avanzo di amministrazione e del recupero del disavanzo di amministrazione, garantendo un fondo di cassa finale non negativo. Inoltre, le previsioni di competenza relative alle spese correnti sommate alle previsioni di competenza relative ai trasferimenti in c/capitale, al saldo negativo delle partite finanziarie, alle quote di capitale delle rate di ammortamento dei mutui e degli altri prestiti, con l'esclusione dei rimborsi anticipati, non possono essere complessivamente superiori alle previsioni di competenza dei primi tre titoli dell'entrata, ai contributi destinati al rimborso dei prestiti e all'utilizzo dell'avanzo di competenza di parte corrente, salvo le eccezioni tassativamente indicate nel principio applicato alla contabilita' finanziaria necessarie a garantire elementi di flessibilita' degli equilibri di bilancio ai fini del rispetto del principio dell'integrita'. Nelle more dell'applicazione del capo IV della legge 24 dicembre 2012, n. 243, il totale delle spese di cui si autorizza l'impegno puo' essere superiore al totale delle entrate che si prevede di accertare nel medesimo esercizio, purche' il relativo disavanzo sia coperto da mutui e altre forme di indebitamento autorizzati con la legge di approvazione del bilancio nei limiti di cui all'art. 62.

2. A decorrere dal 2016, il disavanzo di amministrazione derivante dal debito autorizzato e non contratto per finanziare spesa di investimento, risultante dal rendiconto 2015, puo' essere coperto con il ricorso al debito che puo' essere contratto solo per far fronte ad effettive esigenze di cassa.

((2-bis. Fermo restando quanto previsto dal comma 2, a decorrere dall'esercizio 2018, le regioni e le province autonome di Trento e di Bolzano che nell'ultimo anno hanno registrato valori degli indicatori annuali di tempestivita' dei pagamenti, calcolati e pubblicati secondo le modalita' stabilite dal decreto del Presidente del Consiglio dei ministri 22 settembre 2014, pubblicato nella Gazzetta Ufficiale n. 265 del 14 novembre 2014, rispettosi dei termini di pagamento di cui all'articolo 4 del decreto legislativo 9 ottobre 2002, n. 231, possono autorizzare spese di investimento la cui copertura sia costituita da debito da contrarre solo per far fronte a esigenze effettive di cassa. L'eventuale disavanzo di amministrazione per la mancata contrazione del debito puo' essere coperto nell'esercizio successivo con il ricorso al debito, da contrarre solo per far fronte a effettive esigenze di cassa))

### Art. 41. - (( (Il piano degli indicatori e dei risultati attesi).))

((

1. Al fine di consentire la comparazione dei bilanci, entro 30 giorni dall'approvazione del bilancio di previsione e del rendiconto, la regione presenta un documento denominato "Piano degli indicatori e dei risultati attesi di bilancio" predisposto secondo le modalita' previste dall'art. 18-bis.

))

### Art. 42. - (( (Il risultato di amministrazionei).))

((

1. Il risultato di amministrazione, distinto in fondi liberi, fondi accantonati, fondi destinati agli investimenti e fondi vincolati, e' accertato con l'approvazione del rendiconto della gestione dell'ultimo esercizio chiuso, ed e' pari al fondo di cassa aumentato dei residui attivi e diminuito dei residui passivi. Tale risultato non comprende le risorse accertate che hanno finanziato spese impegnate con imputazione agli esercizi successivi, rappresentate dal fondo pluriennale vincolato determinato in spesa del conto del bilancio. Nel caso in cui il risultato di amministrazione non presenti un importo sufficiente a comprendere le quote vincolate, destinate ed accantonate, la differenza e' iscritta nel primo esercizio considerato nel bilancio di previsione, prima di tutte le spese, come disavanzo da recuperare, secondo le modalita' previste al comma 12.

2. In occasione dell'approvazione del bilancio di previsione, e' determinato l'importo del risultato di amministrazione presunto dell'esercizio precedente cui il bilancio si riferisce.

3. I fondi accantonati del risultato di amministrazione comprendono il fondo crediti di dubbia esigibilita', l'accantonamento per i residui perenti e gli accantonamenti per passivita' potenziali.

4. I fondi destinati agli investimenti sono costituiti dalle entrate in conto capitale senza vincoli di specifica destinazione non spese, e sono utilizzabili con provvedimento di variazione di bilancio solo a seguito dell'approvazione del rendiconto. L'indicazione della destinazione nel risultato di amministrazione, per le entrate in conto capitale che hanno dato luogo ad accantonamento al fondo crediti di dubbia e difficile esazione, e' sospeso, per l'importo dell'accantonamento, sino all'effettiva riscossione delle stesse. I trasferimenti in conto capitale non sono destinati al finanziamento degli investimenti e non possono essere finanziati dal debito e dalle entrate in conto capitale destinate al finanziamento degli investimenti.

5. Costituiscono quota vincolata del risultato di amministrazione le entrate accertate e le corrispondenti economie di bilancio:

- a) nei casi in cui la legge o i principi contabili generali e applicati individuano un vincolo di specifica destinazione dell'entrata alla spesa;
- b) derivanti da mutui e finanziamenti contratti per il finanziamento di investimenti determinati;
- c) derivanti da trasferimenti erogati a favore dell'ente per una specifica destinazione;
- d) derivanti da entrate accertate straordinarie, non aventi natura ricorrente, cui la regione ha formalmente attribuito una specifica destinazione. E' possibile attribuire un vincolo di destinazione alle entrate straordinarie non aventi natura ricorrente solo se la regione non ha rinviato la copertura del disavanzo di amministrazione negli esercizi successivi e ha provveduto nel corso dell'esercizio alla copertura di tutti gli eventuali debiti fuori bilancio. L'indicazione del vincolo nel risultato di amministrazione, per le entrate vincolate che hanno dato luogo ad accantonamento al fondo crediti di dubbia e difficile esazione, e' sospeso, per l'importo dell'accantonamento, sino all'effettiva riscossione delle stesse.

6. La quota libera dell'avanzo di amministrazione dell'esercizio precedente, accertato ai sensi del comma 1, puo' essere utilizzata, nel rispetto dei vincoli di destinazione, con provvedimento di variazione di bilancio, per le finalita' di seguito indicate in ordine di priorita':

- a) per la copertura dei debiti fuori bilancio;
- b) per i provvedimenti necessari per la salvaguardia degli equilibri di bilancio previsti dalla legislazione vigente, ove non possa provvedersi con mezzi ordinari;
- c) per il finanziamento di spese di investimento;
- d) per il finanziamento delle spese correnti a carattere non permanente;
- e) per l'estinzione anticipata dei prestiti.

7. Resta salva la facolta' di impiegare l'eventuale quota del risultato di amministrazione "svincolata", in occasione dell'approvazione del rendiconto, sulla base della determinazione dell'ammontare definitivo della quota del risultato di amministrazione accantonata per il fondo crediti di dubbia esigibilita', per finanziare lo stanziamento riguardante il fondo crediti di dubbia esigibilita' nel bilancio di previsione dell'esercizio successivo a quello cui il rendiconto si riferisce.

8. Le quote del risultato di amministrazione presunto dell'esercizio precedente costituite da accantonamenti risultanti dall'ultimo consuntivo approvato o derivanti da fondi vincolati possono essere immediatamente utilizzate per le finalita' cui sono destinate, attraverso l'iscrizione di tali risorse, come posta a se' stante dell'entrata, del primo esercizio del bilancio di previsione o con provvedimento di variazione al bilancio. L'utilizzo della quota vincolata o accantonata del risultato di amministrazione e' consentito, sulla base di una relazione documentata del dirigente competente, anche in caso di esercizio provvisorio, esclusivamente per garantire la prosecuzione o l'avvio di attivita' soggette a termini o scadenza, la cui mancata attuazione determinerebbe danno per l'ente.

9. Se il bilancio di previsione impiega quote vincolate del risultato di amministrazione presunto ai sensi del comma 8, entro il 31 gennaio, la Giunta verifica l'importo delle quote vincolate del risultato di amministrazione dell'anno precedente sulla base di un preconsuntivo relativo alle entrate e alle spese vincolate e approva l'aggiornamento dell'allegato al bilancio di previsione di cui all'art. 11, comma 3, lettera a). Se la quota vincolata del risultato di amministrazione presunto e' inferiore rispetto all'importo applicato al bilancio di previsione, l'ente provvede immediatamente alle necessarie variazioni di bilancio che adeguano l'impiego del risultato di amministrazione vincolato.

10. Le quote del risultato presunto derivante dall'esercizio precedente, costituite dagli accantonamenti effettuati nel corso dell'esercizio precedente, possono essere utilizzate prima dell'approvazione del conto consuntivo dell'esercizio precedente, per le finalita' cui sono destinate, con provvedimento di variazione al bilancio, se la verifica di cui al comma 9 e l'aggiornamento dell'allegato al bilancio di previsione di cui all'art. 11, comma 4, lettera d), sono effettuate con riferimento a tutte le entrate e le spese dell'esercizio precedente e non solo alle entrate e alle spese vincolate.

11. Le variazioni di bilancio che, in attesa dell'approvazione del consuntivo, applicano al bilancio quote vincolate del risultato di amministrazione, sono effettuate dopo l'approvazione del prospetto aggiornato del risultato di amministrazione presunto da parte della Giunta di cui al comma 10. Le variazioni consistenti nella mera reiscrizione di economie di spesa, derivanti da stanziamenti di bilancio dell'esercizio precedente corrispondenti a entrate vincolate, possono essere disposte dai dirigenti se previsto dall'ordinamento contabile o, in assenza di norme, dal responsabile finanziario.

12. L'eventuale disavanzo di amministrazione accertato ai sensi del comma 1, a seguito dell'approvazione del rendiconto, al netto del debito autorizzato e non contratto di cui all'art. 40, comma 1, e' applicato al primo esercizio del bilancio di previsione dell'esercizio in corso di gestione. La mancata variazione di bilancio che, in corso di gestione, applica il disavanzo al bilancio e' equiparata a tutti gli effetti alla mancata approvazione del rendiconto di gestione. Il disavanzo di amministrazione puo' anche essere ripianato negli esercizi considerati nel bilancio di previsione, in ogni caso non oltre la durata della legislatura regionale, contestualmente all'adozione di una delibera consiliare avente ad oggetto il piano di rientro dal disavanzo nel quale siano individuati i provvedimenti necessari a ripristinare il pareggio. Il piano di rientro e' sottoposto al parere del collegio dei revisori. Ai fini del rientro, possono essere utilizzate le economie di spesa e tutte le entrate, ad eccezione di quelle provenienti dall'assunzione di prestiti e di quelle con specifico vincolo di destinazione, nonche' i proventi derivanti da alienazione di beni patrimoniali disponibili e da altre entrate in c/capitale con riferimento a squilibri di parte capitale.

13. La deliberazione di cui al comma 12 contiene l'impegno formale di evitare la formazione di ogni ulteriore potenziale disavanzo, ed e' allegata al bilancio di previsione e al rendiconto, costituendone parte integrante. Con periodicita' almeno semestrale, il Presidente della giunta regionale trasmette al Consiglio una relazione riguardante lo stato di attuazione del piano di rientro. A decorrere dal 2016, e' fatto salvo quanto previsto dall'art. 40, comma 2.

14. L'eventuale disavanzo di amministrazione presunto, accertato ai sensi del comma 2, e' applicato al bilancio di previsione dell'esercizio successivo secondo le modalita' previste al comma 12. A seguito dell'approvazione del rendiconto e dell'accertamento dell'importo definitivo del disavanzo di amministrazione dell'esercizio precedente, si provvede alle eventuali ulteriori iniziative necessarie ai sensi del comma 12.

15. A seguito dell'eventuale accertamento di un disavanzo di amministrazione presunto, nell'ambito delle attivita' previste dal comma 9 effettuate nel corso dell'esercizio provvisorio, si provvede alla tempestiva approvazione del bilancio di previsione. Nelle more dell'approvazione del bilancio, la gestione prosegue secondo le modalita' previste dal principio applicato della contabilita' finanziaria riguardante la gestione provvisoria del bilancio.

))

### Art. 43. - (( (Esercizio provvisorio e gestione provvisoria).))

((

1. Se il bilancio di previsione non e' approvato dal Consiglio entro il 31 dicembre dell'anno precedente, la gestione finanziaria dell'ente si svolge nel rispetto dei principi applicati della contabilita' finanziaria riguardanti l'esercizio provvisorio o la gestione provvisoria.

2. L'esercizio provvisorio del bilancio non puo' essere concesso se non per legge e per periodi non superiori complessivamente a quattro mesi, nei modi, nei termini e con gli effetti previsti dagli statuti e dall'ordinamento contabile dell'ente. Nel corso dell'esercizio provvisorio non e' consentito il ricorso all'indebitamento.

))

### Art. 44. - (( (Classificazione delle entrate).))

((

1. Nel bilancio della regione le entrate sono ripartite, secondo le modalita' indicate all'art. 15, in:

- a) titoli, definiti secondo la fonte di provenienza delle entrate;
- b) tipologie, definite in base alla natura delle entrate, nell'ambito di ciascuna fonte di provenienza, ai fini dell'approvazione in termini di unita' di voto.

2. Ai fini della gestione le tipologie sono ripartite in categorie, in capitoli ed eventualmente in articoli. Le categorie di entrata delle regioni sono individuate dall'elenco di cui all'allegato n. 13. Nell'ambito delle categorie e' data separata evidenza delle eventuali quote di entrata non ricorrente. La Giunta, contestualmente alla proposta di bilancio, trasmette, a fini conoscitivi, la proposta di articolazione delle tipologie in categorie.

3. Le entrate in c/capitale e derivanti da debito sono destinate esclusivamente al finanziamento di spese di investimento e non possono essere impiegate per la spesa corrente.

))

### Art. 45. - (( (Classificazione delle spese).))

((

1. Le previsioni di spesa del bilancio di previsione sono classificate secondo le modalita' indicate all'art. 14 in:

- a) missioni, che rappresentano le funzioni principali e gli obiettivi strategici perseguiti dalle regioni, utilizzando risorse finanziarie, umane e strumentali ad esse destinate;
- b) programmi, che rappresentano gli aggregati omogenei di attivita' volte a perseguire gli obiettivi definiti nell'ambito delle missioni, ai fini dell'approvazione in termini di unita' di voto. I programmi sono ripartiti in titoli e sono raccordati alla relativa codificazione COFOG di secondo livello (Gruppi), secondo le corrispondenze individuate nel glossario, di cui al comma 3-ter dell'art. 14, che costituisce parte integrante dell'allegato n. 14.

2. Ai fini della gestione, i programmi sono ripartiti in macroaggregati, capitoli ed eventualmente in articoli. I macroaggregati di spesa delle regioni sono individuati dall'elenco di cui all'allegato n. 14. La Giunta, contestualmente alla proposta di bilancio, trasmette, a fini conoscitivi, la proposta di articolazione dei programmi in macroaggregati.

))

### Art. 46. - (( (Fondo crediti di dubbia esigiblita').))

((

1. Nella missione "Fondi e Accantonamenti", all'interno del programma fondo crediti di dubbia esigibilita', e' stanziato l'accantonamento al fondo crediti di dubbia esigibilita', il cui ammontare e' determinato in considerazione dell'importo degli stanziamenti di entrata di dubbia e difficile esazione, secondo le modalita' indicate nel principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2 al presente decreto.

2. Una quota del risultato di amministrazione e' accantonata per il fondo crediti di dubbia esigibilita', il cui ammontare e' determinato, secondo le modalita' indicate nel principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2 al presente decreto, in considerazione dell'ammontare dei crediti di dubbia e difficile esazione, e non puo' essere destinata ad altro utilizzo.

3. E' data facolta' alle regioni di stanziare nella missione "Fondi e accantonamenti", all'interno del programma "Altri fondi", ulteriori accantonamenti riguardanti passivita' potenziali, sui quali non e' possibile impegnare e pagare. A fine esercizio, le relative economie di bilancio confluiscono nella quota accantonata del risultato di amministrazione, immediatamente utilizzabili ai sensi di quanto previsto dall'art. 42, comma 3. Quando si accerta che la spesa potenziale non puo' piu' verificarsi, la corrispondente quota del risultato di amministrazione e' liberata dal vincolo.

))

### Art. 47. - (( (Sistemi contabili degli organismi e degli enti strumentali della regione. Spese degli enti locali).))

((

1. Per conseguire i propri obiettivi, la regione si avvale di organismi e di enti strumentali, distinti nelle tipologie, definite in corrispondenza delle missioni del bilancio, di cui all'art. 11-ter, comma 3.

2. Gli organismi strumentali della regione sono costituiti dalle sue articolazioni organizzative, anche a livello territoriale, dotate di autonomia gestionale e contabile, prive di personalita' giuridica, escluso il consiglio regionale, al quale si applica l'art. 67. Gli organismi strumentali della regione adottano il medesimo sistema contabile della regione e adeguano la propria gestione alle disposizioni del presente decreto.

3. Gli organismi strumentali delle regioni che svolgono la funzione di organismo pagatore dei fondi europei trasmettono il proprio bilancio di previsione, le variazioni di bilancio, il consuntivo ed i dati concernenti le operazioni gestionali alla banca dati unitaria delle Amministrazioni pubbliche, di cui all'art. 13, comma 3, della legge 31 dicembre 2009, n. 196, sulla base di schemi, tempi e modalita' definiti con decreto del Ministro dell'economia e delle finanze, e non sono compresi nel rendiconto consolidato di cui all'art. 11, commi 8 e 9. Il consuntivo degli organismi pagatori dei fondi UE partecipa al bilancio consolidato di cui all'art. 11-bis.

4. Gli enti strumentali della regione sono le aziende e gli enti, pubblici e privati, dotati di personalita' giuridica, definiti dall'art. 11-ter. Gli enti strumentali in contabilita' finanziaria adottano il medesimo sistema contabile della regione e adeguano la propria gestione alle disposizioni del presente decreto. Gli enti strumentali della regione in contabilita' economico-patrimoniale adeguano il proprio sistema contabile ai principi di cui all'art. 17.

5. I bilanci degli enti e degli organismi, in qualunque forma costituiti, strumentali della regione, sono approvati annualmente nei termini e nelle forme stabiliti dallo statuto e dalle leggi regionali e sono pubblicati nel sito internet della regione.

))

### Art. 48. - (( (Fondi di riserva).))

((

1. Nel bilancio regionale sono iscritti:

- a) nella parte corrente, un «fondo di riserva per spese obbligatorie» dipendenti dalla legislazione in vigore. Le spese obbligatorie sono quelle relative al pagamento di stipendi, assegni, pensioni ed altre spese fisse, le spese per interessi passivi, quelle derivanti da obblighi comunitari e internazionali, le spese per ammortamenti di mutui, nonche' quelle cosi' identificative per espressa disposizione normativa;
- b) nella parte corrente, un «fondo di riserva per spese impreviste» per provvedere alle eventuali deficienze delle assegnazioni di bilancio, che non riguardino le spese di cui alla lettera a), e che, comunque, non impegnino i bilanci futuri con carattere di continuita';
- c) il fondo di riserva per le autorizzazioni di cassa di cui al comma 3.

2. L'ordinamento contabile della regione disciplina le modalita' e i limiti del prelievo di somme dai fondi di cui al comma 1, escludendo la possibilita' di utilizzarli per l'imputazione di atti di spesa. I prelievi dal fondo di cui al comma 1, lettera a), sono disposti con decreto dirigenziale. I prelievi dal fondo di cui al comma 1, lettera b), sono disposti con delibere della giunta regionale.

3. Il fondo di riserva per le autorizzazioni di cassa e' iscritto nel solo bilancio di cassa per un importo definito in rapporto alla complessiva autorizzazione a pagare ivi disposta, secondo modalita' indicate dall'ordinamento contabile regionale in misura non superiore ad un dodicesimo e i cui prelievi e relative destinazioni ed integrazioni degli altri programmi di spesa, nonche' dei relativi capitoli del bilancio di cassa, sono disposti con decreto dirigenziale.

))

### Art. 49. - (( (Fondi speciali).))

((

1. Nel bilancio regionale possono essere iscritti uno o piu' fondi speciali, destinati a far fronte agli oneri derivanti da provvedimenti legislativi regionali che si perfezionino dopo l'approvazione del bilancio.

2. I fondi di cui al comma 1 non sono utilizzabili per l'imputazione di atti di spesa; ma solo ai fini del prelievo di somme da iscrivere in aumento alle autorizzazioni di spesa dei programmi esistenti o dei nuovi programmi dopo l'entrata in vigore dei provvedimenti legislativi che autorizzano le spese medesime.

3. I fondi di cui al comma 1 sono tenuti distinti a seconda che siano destinati al finanziamento di spese correnti o di spese in conto capitale.

4. Le quote dei fondi speciali, non utilizzate al termine dell'esercizio secondo le modalita' di cui al comma 2, costituiscono economie di spesa.

5. Ai fini della copertura finanziaria di spese derivanti da provvedimenti legislativi non approvati entro il termine dell'esercizio relativo, ma in corso di approvazione da parte del Consiglio, puo' farsi riferimento alle quote non utilizzate dei relativi fondi speciali di detto esercizio. A tal fine, le economie di spesa derivanti dalle quote non utilizzate di tali fondi speciali costituiscono una quota accantonata del risultato di amministrazione, destinata alla copertura finanziaria di spese derivanti dai relativi provvedimenti legislativi, purche' tali provvedimenti siano approvati entro il termine dell'esercizio immediatamente successivo.

))

### Art. 50. - (Assestamento del bilancio)

1. Entro il 31 luglio, la regione approva con legge l'assestamento delle previsioni di bilancio, anche sulla scorta della consistenza dei residui attivi e passivi, del fondo pluriennale vincolato e del fondo crediti di dubbia esigibilita', accertati in sede di rendiconto dall'esercizio scaduto il 31 dicembre precedente, fermi restando i vincoli di cui all'art. 40.

2. La legge di assestamento del bilancio da' atto del permanere degli equilibri generali di bilancio e, in caso di accertamento negativo, assume i necessari provvedimenti di riequilibrio.

3. Alla legge di assestamento e' allegata una nota integrativa nella quale sono indicati:

- a) la destinazione del risultato economico dell'esercizio precedente o i provvedimenti atti al contenimento e assorbimento del disavanzo economico;
- b) la destinazione della quota libera del risultato di amministrazione;
- c) le modalita' di copertura dell'eventuale disavanzo di amministrazione tenuto conto della struttura e della sostenibilita' del ricorso all'indebitamento, con particolare riguardo ai contratti di mutuo, alle garanzie prestate e alla conformita' dei relativi oneri alle condizioni previste dalle convenzioni con gli istituti bancari e i valori di mercato, evidenziando gli oneri sostenuti in relazione ad eventuali anticipazioni di cassa concesse dall'istituto tesoriere.

((3-bis. Nelle more della conclusione del giudizio di parificazione del rendiconto dell'esercizio precedente da parte della Corte dei conti, i consigli regionali e delle province autonome di Trento e di Bolzano approvano la legge di assestamento del bilancio anche sulla base delle risultanze del rendiconto approvato dalla giunta, fermo restando l'obbligo di apportare le eventuali variazioni di bilancio che si dovessero rendere necessarie a seguito dell'approvazione definitiva del rendiconto dopo la decisione di parificazione. In ogni caso, l'eventuale avanzo di amministrazione libero e quello destinato agli investimenti possono essere applicati al bilancio di previsione solo a seguito dell'approvazione con legge del rendiconto che ne certifica la sussistenza))

### Art. 51. - (Variazioni del bilancio di previsione, del documento tecnico di accompagnamento e del bilancio gestionale)

1. Nel corso dell'esercizio, il bilancio di previsione puo' essere oggetto di variazioni autorizzate con legge.

2. Nel corso dell'esercizio la giunta, con provvedimento amministrativo, autorizza le variazioni del documento tecnico di accompagnamento e le variazioni del bilancio di previsione riguardanti:

- a) l'istituzione di nuove tipologie di bilancio, per l'iscrizione di entrate derivanti da assegnazioni vincolate a scopi specifici nonche' per l'iscrizione delle relative spese, quando queste siano tassativamente regolate dalla legislazione in vigore;
- b) variazioni compensative tra le dotazioni delle missioni e dei programmi riguardanti l'utilizzo di risorse comunitarie e vincolate, nel rispetto della finalita' della spesa definita nel provvedimento di assegnazione delle risorse, o qualora le variazioni siano necessarie per l'attuazione di interventi previsti da intese istituzionali di programma o da altri strumenti di programmazione negoziata;
- c) variazioni compensative tra le dotazioni delle missioni e dei programmi limitatamente alle spese per il personale, conseguenti a provvedimenti di trasferimento del personale all'interno dell'amministrazione;
- d) variazioni compensative tra le dotazioni di cassa delle missioni e dei programmi di diverse missioni;
- e) variazioni riguardanti il fondo pluriennale di cui all'art. 3, comma 4;
- f) le variazioni riguardanti l'utilizzo del fondo di riserva per le spese impreviste di cui all'art. 48, lettera b);
- g) le variazioni necessarie per l'utilizzo della quota accantonata del risultato di amministrazione riguardante i residui perenti.

3. L'ordinamento contabile regionale disciplina le modalita' con cui la giunta regionale o il Segretario generale, con provvedimento amministrativo, autorizza le variazioni del bilancio gestionale che non sono di competenza dei dirigenti e del responsabile finanziario.

4. Salva differente previsione definita dalle Regioni nel proprio ordinamento contabile, i dirigenti responsabili della spesa o, in assenza di disciplina, il responsabile finanziario della regione possono effettuare variazioni del bilancio gestionale compensative fra capitoli di entrata della medesima categoria e fra i capitoli di spesa del medesimo macroaggregato, le variazioni di bilancio riguardanti la mera reiscrizione di economie di spesa derivanti da stanziamenti di bilancio dell'esercizio precedente corrispondenti a entrate vincolate, secondo le modalita' previste dall'art. 42, commi 8 e 9, levariazioni necessarie per l'adeguamento delle previsioni, compresa l'istituzione di tipologie e programmi, riguardanti le partite di giro e le operazioni per conto di terzi, le variazioni degli stanziamenti riguardanti i versamenti ai conti di tesoreria statale intestati all'ente e i versamenti a depositi bancari intestati all'ente, e le variazioni di bilancio riguardanti il fondo pluriennale vincolato escluse quelle previste dall'art. 3, comma 4, di competenza della giunta , nonche' le variazioni di bilancio, in termini di competenza o di cassa, relative a stanziamenti riguardanti le entrate da contributi a rendicontazione o riferiti a operazioni di indebitamento gia' autorizzate o perfezionate, contabilizzate secondo l'andamento della correlata spesa, necessarie a seguito delle variazioni di esigibilita' della spesa stessa. Salvo differente autorizzazione della giunta, con riferimento ai macroggregati riguardanti i trasferimenti correnti, i contributi agli investimenti e ai trasferimenti in conto capitale, i dirigenti responsabili della spesa o, in assenza di disciplina, il responsabile finanziario, possono effettuare variazioni compensative solo dei capitoli di spesa appartenenti al medesimo macroaggregato e al medesimo codice di quarto livello del piano dei conti. ((Il responsabile finanziario della regione puo' altresi' variare l'elenco di cui all'articolo 11, comma 5, lettera d), al solo fine di modificare la distribuzione delle coperture finanziarie tra gli interventi gia' programmati per spese di investimento)).

5. Sono vietate le variazioni amministrative compensative tra macroaggregati appartenenti a titoli diversi e spostamenti di somme tra residui e competenza.

6. Nessuna variazione al bilancio puo' essere approvata dopo il 30 novembre dell'anno a cui il bilancio stesso si riferisce, fatta salva:

- a) l'istituzione di tipologie di entrata di cui al comma 2, lettera a);
- b) l'istituzione di tipologie di entrata, nei casi non previsti dalla lettera a) con stanziamento pari a zero, a seguito di accertamento e riscossione di entrate non previste in bilancio, secondo le modalita' previste dal principio applicato della contabilita' finanziaria;
- c) le variazioni del fondo pluriennale vincolato;
- d) le variazioni necessarie per consentire la reimputazione di obbligazioni gia' assunte agli esercizi in cui sono esigibili;
- e) i prelievi dai fondi di riserva per le spese obbligatorie, per le spese impreviste, per l'utilizzo della quota accantonata del risultato di amministrazione riguardante i residui perenti e le spese potenziali;
- f) le variazioni necessarie alla reimputazione agli esercizi in cui sono esigibili, di obbligazioni riguardanti entrate vincolate gia' assunte e, se necessario, delle spese correlate;
- g) le variazioni delle dotazioni di cassa di cui al comma 2, lettera d);
- h) le variazioni degli stanziamenti riguardanti i versamenti ai conti correnti di tesoreria statale intestati all'ente e i versamenti a depositi bancari intestati all'ente.

7. I provvedimenti amministrativi che dispongono le variazioni al bilancio di previsione e, nei casi previsti dal presente decreto, non possono disporre variazioni del documento tecnico di accompagnamento o del bilancio gestionale.

8. Salvo quanto disposto dal presente articolo e dagli articoli 48 e 49, sono vietate le variazioni compensative degli stanziamenti di competenza da un programma all'altro del bilancio con atto amministrativo.

9. Le variazioni al bilancio di previsione sono trasmesse al tesoriere inviando il prospetto di cui all'art. 10, comma 4, allegato alla legge o al provvedimento di approvazione della variazione. Sono altresi' trasmesse al tesoriere:

- a) le variazioni dei residui a seguito del loro riaccertamento;
- b) le variazioni del fondo pluriennale vincolato effettuate nel corso dell'esercizio finanziario.

10. Nel corso dell'esercizio 2015 sono applicate le norme concernenti le variazioni di bilancio vigenti nell'esercizio 2014, fatta salva la disciplina del fondo pluriennale vincolato e del riaccertamento straordinario dei residui. Gli enti che hanno partecipato alla sperimentazione nel 2014 adottano la disciplina prevista dal presente articolo a decorrere dal 1° gennaio 2015.

### Art. 52. - (( (La gestione delle entrate e delle spese).))

((

1. La gestione delle entrate si attua attraverso le fasi dell'accertamento, della riscossione e del versamento.

2. La gestione delle spese si attua attraverso le fasi dell'impegno, della liquidazione, dell'ordinazione e del pagamento.

))

### Art. 53. - (( (Accertamenti).))

((

1. Tutte le obbligazioni giuridicamente perfezionate attive, da cui derivano entrate per la regione, devono essere registrate nelle scritture contabili quando l'obbligazione e' perfezionata, con imputazione all'esercizio in cui l'obbligazione viene a scadenza, secondo le modalita' previste dal principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2. Le entrate sono registrate nelle scritture contabili anche se non determinano movimenti di cassa effettivi.

2. L'accertamento costituisce la prima fase della gestione dell'entrata con la quale il funzionario competente, sulla base di idonea documentazione verifica la ragione del credito e la sussistenza di un idoneo titolo giuridico che da' luogo all'obbligazione attiva giuridicamente perfezionata, individua il debitore, quantifica la somma da incassare, individua la relativa scadenza, e registra il diritto di credito imputandolo contabilmente all'esercizio finanziario nel quale viene a scadenza. Non possono essere riferite ad un determinato esercizio finanziario le entrate il cui diritto di credito non venga a scadenza nello stesso esercizio finanziario. E' vietato l'accertamento attuale di entrate future.

))

### Art. 54. - (( (La riscossione).))

((

1. La riscossione consiste nel materiale introito da parte del tesoriere o di altri eventuali incaricati della riscossione delle somme dovute all'ente.

2. La riscossione e' disposta a mezzo di ordinativo di incasso, fatto pervenire al tesoriere nelle forme e nei tempi previsti dalla convenzione di tesoreria, anche nei casi in cui l'entrata non da' luogo ad effettivi movimenti di cassa.

3. L'ordinativo d'incasso e' sottoscritto dal responsabile del servizio finanziario o da un suo delegato e contiene almeno:

- a) l'indicazione del debitore;
- b) l'ammontare della somma da riscuotere;
- c) la causale;
- d) l'indicazione del titolo e delle tipologia di bilancio cui e' riferita l'entrata, con le relative codifiche, distintamente per residui o competenza;
- e) i codici della transazione elementare di cui agli articoli da 5 a 7, inseriti nei campi liberi dell'ordinativo a disposizione dell'ente, non gestiti dal tesoriere;
- f) il numero progressivo;
- g) l'esercizio finanziario e la data di emissione;
- h) la codifica SIOPE di cui all'art. 14 della legge 31 dicembre 2009, n. 196.

4. Il tesoriere deve accettare, senza pregiudizio per i diritti della regione, la riscossione di ogni somma, versata in favore della regione, ivi comprese le entrate di cui al comma 6, anche senza la preventiva emissione di ordinativo d'incasso. In tale ipotesi, il tesoriere ne da' immediata comunicazione alla regione, richiedendo la regolarizzazione. La regione procede alla regolarizzazione dell'incasso entro i successivi 60 giorni.

5. Gli ordinativi di incasso che si riferiscono ad entrate di competenza dell'esercizio in corso sono tenuti distinti da quelli relativi ai residui, garantendone la numerazione unica per esercizio e progressiva. Entrambi sono imputati contabilmente all'esercizio in cui il tesoriere li ha eseguiti, anche se la relativa comunicazione e' pervenuta nell'esercizio successivo.

6. Gli incassi derivanti dalle accensioni di prestiti sono disposti nei limiti dei rispettivi stanziamenti di cassa.

7. E' vietata l'imputazione provvisoria degli incassi in attesa di regolarizzazione alle partite di giro.

8. Gli ordinativi d'incasso non riscossi entro il termine dell'esercizio sono restituiti dal tesoriere alla regione per l'annullamento e la successiva emissione nell'esercizio successivo in conto residui.

9. I codici di cui al comma 3, lettera e), possono essere applicati all'ordinativo di incasso a decorrere dal 1° gennaio 2016.

))

### Art. 55. - (( (Il versamento).))

((

1. Il versamento costituisce l'ultima fase dell'entrata, consistente nel trasferimento delle somme riscosse nelle casse della regione. 2.Gli incaricati della riscossione interni ed esterni, versano al tesoriere le somme riscosse nei termini e nei modi fissati dai regolamenti di contabilita' e dagli accordi convenzionali. 3. Gli incaricati interni, designati con provvedimento formale della regione, versano le somme riscosse presso la tesoreria della regione con cadenza stabilita dall'ordinamento contabile regionale, non superiore ai quindici giorni lavorativi.

))

### Art. 56. - (Impegni di spesa)

1. Tutte le obbligazioni giuridicamente perfezionate passive, da cui derivano spese per la regione, devono essere registrate nelle scritture contabili quando l'obbligazione e' perfezionata, con imputazione all'esercizio in cui l'obbligazione viene a scadenza, secondo le modalita' previste. dal principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2. Le spese sono registrate nelle scritture contabili anche se non determinano movimenti di cassa effettivi.

2. L'impegno costituisce la fase della spesa con la quale viene riconosciuto il perfezionamento di un'obbligazione giuridica passiva, ed e' determinata la ragione del debito, la somma da pagare, il soggetto creditore, la specificazione del vincolo costituito sullo stanziamento di bilancio e la data di scadenza.

3. Gli impegni di spesa sono assunti nei limiti dei rispettivi stanziamenti di competenza del bilancio di previsione, con imputazione agli esercizi in cui le obbligazioni sono esigibili. Gli impegni riguardanti le partite di giro e i rimborsi delle anticipazioni di tesoreria sono assunti in relazione alle esigenze della gestione.

4. Durante la gestione, con riferimento agli stanziamenti del bilancio di previsione, possono essere prenotati impegni relativi a procedure in via di espletamento. I provvedimenti relativi, per i quali entro il termine dell'esercizio non e' stata assunta dalla regione l'obbligazione di spesa verso i terzi, decadono e costituiscono economia di bilancio, concorrendo alla determinazione del risultato di amministrazione di cui all'art. 42. ((Le economie riguardanti le spese di investimento per lavori pubblici concorrono alla determinazione del fondo pluriennale secondo le modalita' definite, entro il 30 aprile 2019, con decreto del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, di concerto con il Ministero dell'interno - Dipartimento per gli affari interni e territoriali e con la Presidenza del Consiglio dei ministri - Dipartimento per gli affari regionali e le autonomie, su proposta della Commissione per l'armonizzazione degli enti territoriali di cui all'articolo 3-bis, al fine di adeguare il principio contabile applicato concernente la contabilita' finanziaria previsto dall'allegato n. 4/2 del presente decreto)).

5. Costituiscono economia le minori spese sostenute rispetto all'impegno assunto nel corso dell'esercizio, verificate con la conclusione della fase della liquidazione.

6. Al fine di evitare ritardi nei pagamenti e la formazione di debiti pregressi, il funzionario della Regione che adotta provvedimenti che comportano impegni di spesa ha l'obbligo di accertare preventivamente che il programma dei conseguenti pagamenti sia compatibile con i relativi stanziamenti di bilancio e con le regole di finanza pubblica; la violazione dell'obbligo di accertamento di cui al presente comma comporta responsabilita' disciplinare ed amministrativa. Qualora lo stanziamento di bilancio, per ragioni sopravvenute, non consenta di far fronte all'obbligo contrattuale, l'amministrazione adotta le opportune iniziative, anche di tipo contabile, amministrativo o contrattuale, per evitare la formazione di debiti pregressi.

7. Nel caso di spese riguardanti trasferimenti e contributi ad amministrazioni pubbliche, somministrazioni, forniture, appalti e prestazioni professionali, il responsabile del procedimento di spesa comunica al destinatario della spesa le informazioni relative all'impegno. La comunicazione dell'avvenuto impegno delle spese riguardanti somministrazioni, forniture e prestazioni professionali e' effettuata contestualmente all'ordinazione della prestazione con l'avvertenza che la successiva fattura deve essere completata con gli estremi della suddetta comunicazione. In mancanza della comunicazione, il terzo interessato ha facolta' di non eseguire la prestazione sino a quando i dati non gli vengano comunicati.

8. L'ordinamento contabile della regione disciplina le modalita' attraverso le quali le fatture o i documenti contabili equivalenti che attestano l'avvenuta cessione di beni, lo stato di avanzamento di lavori, la prestazione di servizi nei confronti dell'ente, sono annotate entro 10 giorni nel registro delle fatture ricevute secondo le modalita' previste dall'art. 42 del decreto-legge 24 aprile 2014, n. 66, convertito in legge, con modificazioni, dalla legge 23 giugno 2014, n. 89. Per il protocollo di tali documenti e' istituito un registro unico nel rispetto della disciplina in materia di documentazione amministrativa di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, ed e' esclusa la possibilita' di ricorrere a registri di settore o di reparto.

### Art. 57. - (( (Liquidazione della spesa).))

((

1. La liquidazione costituisce la fase del procedimento di spesa con la quale, in base ai documenti ed ai titoli atti a comprovare il diritto del creditore, si determina la somma da pagare nei limiti dell'ammontare dell'impegno definitivo assunto. 2 La liquidazione e' una registrazione contabile effettuata quando l'obbligazione diviene effettivamente esigibile, a seguito della acquisizione completa della documentazione necessaria a comprovare il diritto del creditore e a seguito del riscontro operato sulla regolarita' della fornitura o della prestazione e sulla rispondenza della stessa ai requisiti quantitativi e qualitativi, ai termini ed alle condizioni pattuite.

))

### Art. 58. - (( (Il pagamento della spesa).))

((

1. Il pagamento delle spese e' ordinato al tesoriere entro i limiti delle previsioni di cassa, mediante l'emissione di mandati di pagamento numerati in ordine progressivo e contrassegnati da evidenze informatiche del capitolo. Gli stanziamenti riguardanti i rimborsi delle anticipazioni di tesoreria e le partite di giro non costituiscono limite ai pagamenti.

2. Al pagamento delle spese, conseguenti alle deliberazioni o agli atti con i quali sono assunti i relativi impegni, si provvede esclusivamente se tali deliberazioni o atti siano divenuti esecutivi, ovvero risultino immediatamente eseguibili.

3. I mandati di pagamento sono firmati dal responsabile del servizio finanziario o da un suo delegato e contengono almeno i seguenti elementi:

- a) il numero progressivo del mandato per esercizio finanziario;
- b) la data di emissione;
- c) l'indicazione della missione, del programma e del titolo di bilancio cui e' riferita la spesa, distintamente per residui o competenza, e della relativa disponibilita' in termini di cassa;
- d) l'indicazione del creditore e, se si tratta di persona diversa, del soggetto tenuto a rilasciare quietanza, nonche' il relativo codice fiscale o la partita IVA;
- e) l'ammontare della somma dovuta e la scadenza, qualora sia prevista dalla legge o sia stata concordata con il creditore;
- f) la causale e gli estremi dell'atto esecutivo che legittima l'erogazione della spesa;
- g) le modalita' di pagamento se richieste dal creditore;
- h) la codifica SIOPE di cui all'art. 14 della legge 31 dicembre 2009, n. 196;
- i) i codici della transazione elementare di cui agli articoli da 5 a 7, inseriti nei campi liberi del mandato a disposizione dell'ente, non gestiti dal tesoriere;
- j) il codice che identifica le spese non soggette al controllo dei dodicesimi previsto dal principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2, in caso di esercizio provvisorio.

4. I codici di cui al comma 3, lettera i), possono essere applicati al mandato a decorrere dal 1° gennaio 2016.

5. Il tesoriere effettua i pagamenti derivanti da obblighi tributari, da somme iscritte a ruolo, da delegazioni di pagamento e da altri obblighi di legge, anche in assenza della preventiva emissione del relativo mandato di pagamento. Entro trenta giorni, la regione emette il relativo mandato ai fini della regolarizzazione.

6. I mandati che si riferiscono alla competenza sono tenuti distinti da quelli relativi ai residui, garantendone la numerazione unica per esercizio e progressiva. Entrambi sono imputati all'esercizio in cui il tesoriere li ha eseguiti, anche se la relativa comunicazione e' pervenuta nell'esercizio successivo.

7. E' vietata l'imputazione provvisoria dei pagamenti in attesa di regolarizzazione alle partite di giro.

8. I mandati di pagamento, non pagati entro il termine dell'esercizio, sono commutati dal tesoriere, nelle forme e nelle modalita' previste dalla legge, in assegni postali localizzati o altri mezzi equipollenti offerti dal sistema bancario o postale, al fine di rendere possibile, al 31 dicembre di ciascun anno, la parificazione dei mandati emessi dall'ente con quelli pagati dal tesoriere.

))

### Art. 59. - (( (Modalita' di estinzione dei titoli di pagamento).))

((

1. Le regioni possono disporre, su richiesta scritta del creditore e con spese a suo carico, che i mandati di pagamento siano estinti mediante:

- a) accreditamento in conto corrente postale intestato al creditore;
- b) commutazione in vaglia cambiario o in assegno circolare, non trasferibile, all'ordine del creditore;
- c) accreditamento in conto corrente bancario;
- d) altre forme di pagamento previste dai sistemi bancari e postali.

2. Le dichiarazioni di accreditamento o di commutazione, che sostituiscono la quietanza del creditore, devono risultare da annotazione sul mandato di pagamento, o su evidenze informatiche, recante gli estremi relativi alle operazioni))

### Art. 60. - (( (Gestione dei residui).))

((

1. Costituiscono residui attivi le somme accertate e non riscosse e versate entro il termine dell'esercizio, da iscriversi nel bilancio di previsione dell'esercizio successivo.

2. Costituiscono residui passivi le somme impegnate a norma dell'art. 56,liquidate o liquidabili, e non pagate entro il termine dell'esercizio, da iscriversi nel bilancio di previsione dell'esercizio successivo. Non e' ammessa la conservazione nel conto dei residui di somme non impegnate a norma dell'art. 56.

3. A decorrere dall'entrata in vigore del presente decreto, non e' consentita la cancellazione dei residui passivi dalle scritture contabili per perenzione. L'istituto della perenzione amministrativa si applica per l'ultima volta in occasione della predisposizione del rendiconto dell'esercizio 2014. A tal fine, una quota del risultato di amministrazione al 31 dicembre 2014 e' accantonata per garantire la copertura della reiscrizione dei residui perenti, per un importo almeno pari all'incidenza delle richieste di reiscrizione dei residui perenti degli ultimi tre esercizi rispetto all'ammontare dei residui perenti e comunque incrementando annualmente l'entita' dell'accantonamento di almeno il 20 per cento, fino al 70 per cento dell'ammontare dei residui perenti.

4. La gestione della competenza e' separata da quella dei residui.

5. I residui attivi e passivi di ciascun esercizio sono trasferiti ai corrispondenti capitoli dell'esercizio successivo, separatamente dagli stanziamenti di competenza dello stesso.

6. Tutte le somme iscritte tra le entrate di competenza del bilancio e non accertate entro il termine dell'esercizio costituiscono minori accertamenti rispetto alle previsioni ed a tale titolo concorrono a determinare i risultati finali della gestione.

7. Tutte le somme iscritte negli stanziamenti di competenza del bilancio e non impegnate, a norma dell'art. 56, entro il termine dell'esercizio costituiscono economia di spesa e a tale titolo concorrono a determinare i risultati finali della gestione, escluse le somme iscritte negli stanziamenti relativi ai fondi pluriennali vincolati in corrispondenza di impegni imputati agli esercizi successivi.

))

### Art. 61. - (( (Fondi statali per interventi speciali).))

((

1. Nel caso di assegnazioni dello Stato per interventi speciali, la regione ha facolta' di stanziare e di erogare somme eccedenti quelle assegnate dallo Stato, di compensare tali maggiori spese con minori erogazioni per lo stesso scopo nei due esercizi immediatamente successivi.

))

### Art. 62. - (( (Mutui e altre forme di indebitamento).))

((

1. Il ricorso al debito da parte delle regioni, fatto salvo quanto previsto dall'art. 40, comma 2, e' ammesso esclusivamente nel rispetto di quanto previsto dalle leggi vigenti in materia, con particolare riferimento agli articoli 81 e 119 della Costituzione, all'art. 3, comma 16, della legge 24 dicembre 2003, n. 350, e, a decorrere dal 1° gennaio 2016, dagli articoli 9 e 10 della legge 24 dicembre 2012, n. 243.

2. Non puo' essere autorizzata la contrazione di nuovo indebitamento, se non e' stato approvato dal consiglio regionale il rendiconto dell'esercizio di due anni precedenti a quello al cui bilancio il nuovo indebitamento si riferisce.

3. L'autorizzazione all'indebitamento, concessa con la legge di approvazione del bilancio o con leggi di variazione del medesimo, decade al termine dell'esercizio cui il bilancio si riferisce.

4. Le entrate derivanti da operazioni di debito sono immediatamente accertate a seguito del perfezionamento delle relative obbligazioni, anche se non sono riscosse, e sono imputate agli esercizi in cui e' prevista l'effettiva erogazione del finanziamento. Contestualmente e' impegnata la spesa complessiva riguardante il rimborso dei prestiti, con imputazione agli esercizi secondo il piano di ammortamento, distintamente per la quota interessi e la quota capitale.

5. Le somme iscritte nello stato di previsione dell'entrata in relazione ad operazioni di indebitamento autorizzate, ma non perfezionate entro il termine dell'esercizio, costituiscono minori entrate rispetto alle previsioni.

6. Le regioni possono autorizzare nuovo debito solo se l'importo complessivo delle annualita' di ammortamento per capitale e interesse dei mutui e delle altre forme di debito in estinzione nell'esercizio considerato, al netto dei contributi erariali sulle rate di ammortamento dei mutui in essere al momento della sottoscrizione del finanziamento e delle rate riguardanti debiti espressamente esclusi dalla legge, non supera il 20 per cento dell'ammontare complessivo delle entrate del titolo "Entrate correnti di natura tributaria, contributiva e perequativa" al netto di quelle della tipologia "Tributi destinati al finanziamento della sanita'" ed a condizione che gli oneri futuri di ammortamento trovino copertura nell'ambito del bilancio di previsione della regione stessa, fatto salvo quanto previsto dall'art. 8, comma 2-bis, della legge n. 183 del 2011. Nelle entrate di cui al periodo precedente, sono comprese le risorse del fondo di cui all'art. 16-bis del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, alimentato dalle compartecipazioni al gettito derivante dalle accise. Concorrono al limite di indebitamento le rate sulle garanzie prestate dalla regione a favore di enti e di altri soggetti ai sensi delle leggi vigenti, salvo quelle per le quali la regione ha accantonato l'intero importo del debito garantito. Il limite e' determinato anche con riferimento ai finanziamenti imputati contabilmente agli esercizi successivi.

7. In caso di superamento del limite di cui al comma 6, determinato dalle garanzie prestate dalla regione alla data del 31 dicembre 2014, la regione non puo' assumere nuovo debito fino a quando il limite non risulta rispettato.

8. La legge regionale che autorizza il ricorso al debito deve specificare l'incidenza dell'operazione sui singoli esercizi finanziari futuri, nonche' i mezzi necessari per la copertura degli oneri, e deve, altresi', disporre, per i prestiti obbligazionari, che l'effettuazione dell'operazione sia deliberata dalla giunta regionale, che ne determina le condizioni e le modalita'.

9. Ai mutui e alle anticipazioni contratti dalle Regioni, si applica il trattamento fiscale previsto per i corrispondenti atti dell'Amministrazione dello Stato.

))

### Art. 63. - (( (Rendiconto generale).))

((

1. I risultati della gestione sono dimostrati nel rendiconto generale annuale della regione.

2. Il rendiconto generale, composto dal conto del bilancio relativo alla gestione finanziaria, dai relativi riepiloghi, dai prospetti riguardanti il quadro generale riassuntivo e la verifica degli equilibri, dal conto economico e dallo stato patrimoniale, e' predisposto secondo lo schema di cui all'allegato n. 10 al presente decreto.

3. Contestualmente al rendiconto, la regione approva il rendiconto consolidato, comprensivo dei risultati del consiglio regionale e degli eventuali organismi strumentali secondo le modalita' previste dall'art. 11, commi 8 e 9.

4. Al rendiconto della gestione sono allegati i documenti previsti dall'art. 11, comma 4, l'elenco delle delibere di prelievo dal fondo di riserva per spese impreviste di cui all'art. 48, comma 1, lettera b), con l'indicazione dei motivi per i quali si e' proceduto ai prelevamentie il prospetto relativo alla gestione del perimetro sanitario di cui all'art. 20, comma 1.

5. Il conto del bilancio dimostra i risultati finali della gestione rispetto alle autorizzazioni contenute nel primo esercizio considerato nel bilancio di previsione. Per ciascuna tipologia di entrata e per ciascun programma della spesa, il conto del bilancio comprende, distintamente per residui e competenza:

- a) per l'entrata le somme accertate, con distinzione della parte riscossa e di quella ancora da riscuotere;
- b) per la spesa le somme impegnate, con distinzione della parte pagata, di quella ancora da pagare e di quella impegnata con imputazione agli esercizi successivi, che costituisce il fondo pluriennale vincolato.

6. Il conto economico evidenzia i componenti positivi e negativi della gestione di competenza economica dell'esercizio considerato, rilevati dalla contabilita' economico-patrimoniale, nel rispetto del principio contabile generale n. 17 di cui all'allegato n. 1 e dei principi applicati della contabilita' economico-patrimoniale di cui all'allegato n. 4/3.

7. Lo stato patrimoniale rappresenta la consistenza del patrimonio al termine dell'esercizio. Il patrimonio delle regioni e' costituito dal complesso dei beni e dei rapporti giuridici, attivi e passivi, di pertinenza della regione, ed attraverso la cui rappresentazione contabile e' determinata la consistenza netta della dotazione patrimoniale comprensiva del risultato economico dell'esercizio. Le regioni includono nel conto del patrimonio anche:

- a) i beni del demanio, con specifica distinzione, ferme restando le caratteristiche proprie, in relazione alle disposizioni del codice civile. Le regioni valutano i beni del demanio e del patrimonio, comprensivi delle relative manutenzioni straordinarie, secondo le modalita' previste dal principio applicato della contabilita' economico-patrimoniale di cui all'allegato n. 4/3;
- b) i crediti inesigibili, stralciati dal conto del bilancio, sino al compimento dei termini di prescrizione. Al rendiconto della gestione e' allegato l'elenco di tali crediti distintamente rispetto a quello dei residui attivi.

8. In attuazione del principio contabile generale della competenza finanziaria allegato al presente decreto, le regioni, prima di inserire i residui attivi e passivi nel rendiconto della gestione, provvedono al riaccertamento degli stessi, consistente nella revisione delle ragioni del mantenimento in tutto o in parte dei residui.

9. Possono essere conservate tra i residui attivi le entrate accertate esigibili nell'esercizio di riferimento, ma non incassate. Possono essere conservate tra i residui passivi le spese impegnate, liquidate o liquidabili nel corso di tale esercizio, ma non pagate. Le entrate e le spese accertate e impegnate non esigibili nell'esercizio considerato, sono immediatamente reimputate all'esercizio in cui sono esigibili. Le variazioni agli stanziamenti del fondo pluriennale vincolato dell'esercizio in corso e dell'esercizio precedente necessarie alla reimputazione delle entrate e delle spese riaccertate sono effettuate con provvedimento amministrativo della giunta entro i termini previsti per l'approvazione del rendiconto dell'esercizio precedente.

10. I residui attivi possono essere ridotti od eliminati soltanto dopo che siano stati esperiti tutti gli atti per ottenerne la riscossione, a meno che il costo per tale esperimento superi l'importo da recuperare.

11. Le variazioni dei residui attivi e passivi e la loro reimputazione ad altri esercizi in considerazione del principio generale della competenza finanziaria di cui all'allegato n. 4/3, formano oggetto di apposito decreto del responsabile del procedimento, previa attestazione dell'inesigibilita' dei crediti o il venir meno delle obbligazioni giuridicamente vincolanti posta in essere dalla struttura regionale competente in materia, sentito il collegio dei revisori dei conti, che in proposito manifesta il proprio parere. Dette variazioni trovano evidenza nel conto economico e nel risultato di amministrazione, tenuto conto dell'accantonamento al fondo crediti di dubbia esigibilita'.

))

### Art. 64. - (( (Gli inventari).))

((

1. L'amministrazione del patrimonio delle regioni e' disciplinata dalle norme dello Stato in materia di beni, salvo quanto previsto nel presente decreto e dai principi contabili applicati.

2. Gli inventari costituiscono la principale fonte descrittiva e valutativa dello stato patrimoniale.

3. I beni sono valutati secondo le norme del codice civile e conformemente ai criteri di iscrizione e valutazione di cui al principio applicato della contabilita' economico-patrimoniale (allegato n. 4/3), salvo quanto previsto per gli eventuali beni della gestione sanitaria accentrata dal titolo II.

4. Almeno ogni cinque anni, per i beni mobili, ed ogni dieci anni, per gli immobili, la regione provvede alla ricognizione e al conseguente rinnovo degli inventari.

5. Nel proprio ordinamento contabile le regioni disciplinano le modalita' di inventariazione, di classificazione e di gestione dei beni, nonche' la nomina dei consegnatari dei beni mobili, nel rispetto dei principi contabili applicati.

))

### Art. 65. - (( (Rendiconti degli enti strumentali della regione e spese degli enti locali).))

((

1. I rendiconti degli enti e degli organismi, in qualunque forma costituiti, strumentali della regione sono sottoposti al Consiglio regionale, entro i termini e per le determinazioni previsti dallo statuto e dall'ordinamento contabile regionale e sono pubblicati nel bollettino ufficiale e nel sito internet della regione.

2. I rendiconti degli organismi strumentali e degli enti di cui al comma 1 che adottano la contabilita' finanziaria sono redatti secondo lo schema previsto dall'allegato n. 10 al presente decreto.

))

### Art. 66. - (( (Modalita' per la formazione e l'approvazione del rendiconto).))

((

1. Il rendiconto generale della regione e' approvato con legge regionale entro il 31 luglio dell'anno successivo all'esercizio cui questo si riferisce. L'ordinamento contabile regionale disciplina le modalita' e i termini per la sua presentazione al consiglio regionale.

2. Nel sito internet della regione dedicato ai bilanci e' pubblicata la versione integrale del rendiconto della gestione, comprensivo anche della gestione in capitoli, con il relativo allegato concernente la gestione del perimetro sanitario di cui all'art. 63, comma 4, del rendiconto consolidato, comprensivo della gestione in capitoli e del rendiconto semplificato per il cittadino di cui all'art. 11, comma 2.

))

### Art. 67. - (( (Autonomia contabile del consiglio regionale).))

((

1. Le regioni, sulla base delle norme dei rispettivi statuti, assicurano l'autonomia contabile del consiglio regionale, nel rispetto di quanto previsto dal decreto-legge 10 ottobre 2012, n. 174, convertito, con modificazioni, dalla legge 7 dicembre 2012, n. 213, e dai principi contabili stabiliti dal presente decreto riguardanti gli organismi strumentali.

2. Il consiglio regionale adotta il medesimo sistema contabile e gli schemi di bilancio e di rendiconto della regione adeguandosi ai principi contabili generali e applicati allegati al presente decreto.

3. La presidenza del consiglio regionale sottopone all'assemblea consiliare, secondo le norme previste nel regolamento interno di questa, il rendiconto del Consiglio regionale. Le relative risultanze finali confluiscono nel rendiconto consolidato di cui all'art. 63, comma 3. Al fine di consentire il predetto consolidato, l'assemblea consiliare approva il proprio rendiconto entro il 30 giugno dell'anno successivo.

))

### Art. 68. - (( (Il bilancio consolidato).))

((

1. La regione redige il bilancio consolidato con i propri enti ed organismi strumentali, aziende, societa' controllate e partecipate, secondo le modalita' ed i criteri individuati dal presente decreto.

2. Gli enti strumentali, le aziende e le societa' considerate nel bilancio consolidato della regione costituiscono il "Gruppo della regione".

3. Le regioni adottano lo schema di bilancio consolidato di cui all'allegato n. 11 del presente decreto.

4. Al bilancio consolidato del gruppo della regione sono allegati:

- a) la relazione sulla gestione che comprende la nota integrativa,
- b) la relazione del collegio dei revisori dei conti.

5. Il bilancio consolidato e' approvato dal Consiglio regionale entro il 30 settembre dell'anno successivo secondo le modalita' previste dalla disciplina contabile della Regione.

))

### Art. 69. - (Servizio di tesoreria della regione)

1. Il servizio di tesoreria delle regioni e' affidato, in base ad apposita convenzione sottoscritta dal dirigente competente, a imprese autorizzate all'esercizio dell'attivita' bancaria ai sensi del decreto legislativo 1° settembre 1993, n. 385, e successive modificazioni.

2. Il servizio e' aggiudicato secondo le modalita' previste nell'ordinamento contabile regionale, previo esperimento di apposita gara ad evidenza pubblica, con modalita' che rispettino i principi della concorrenza. La convenzione deve prevedere la partecipazione alla rilevazione SIOPE, disciplinata dall'art. 14 della legge 31 dicembre 2009, n. 196, e successive modificazioni e dai relativi decreti attuativi.

3. Per eventuali danni causati alla regione o a terzi, il tesoriere risponde con tutte le proprie attivita' e con il proprio patrimonio.

4. Ogni deposito o conto corrente comunque costituito e' intestato alla regione e viene gestito dal tesoriere

5. La regione puo' avvalersi dei conti correnti postali, nonche' di conti correnti bancari, per l'espletamento di particolari servizi. Unico traente e' l'istituto tesoriere, previa emissione di apposita reversale da parte della regione almeno ogni 15 giorni

6. Le modalita' per l'espletamento del servizio di tesoreria devono essere coerenti con le disposizioni sulla tesoreria unica di cui alla legge 29 ottobre 1984, n. 720, e successive modificazioni, e relativi decreti attuativi.

7. Il servizio di tesoreria puo' essere gestito con modalita' e criteri informatici e con l'uso di ordinativi di pagamento e di riscossione informatici in luogo di quelli cartacei le cui evidenze informatiche valgono ai fini della rendicontazione.

8. Gli incassi effettuati dal tesoriere mediante i servizi elettronici interbancari danno luogo al rilascio di quietanza o evidenza bancaria ad effetto liberatorio per il debitore.

9. Le Regioni possono contrarre anticipazioni unicamente allo scopo di fronteggiare temporanee deficienze di cassa, per un importo non eccedente il 10 per cento dell'ammontare complessivo delle entrate di competenza del titolo "Entrate correnti di natura tributaria, contributiva e perequativa". Le anticipazioni devono essere estinte nell'esercizio finanziario in cui sono contratte. ((La convenzione di tesoreria di cui al comma 1 puo' prevedere un limite piu' basso. L'importo dell'anticipazione specificata in convenzione e' da ritenersi vincolante sia per la regione che per l'istituto tesoriere)).

9-bis. Gli enti pubblici strumentali delle regioni possono contrarre anticipazioni unicamente allo scopo di fronteggiare temporanee deficienze di cassa, per un importo non eccedente il 10 per cento dell'ammontare complessivo delle entrate di competenza derivanti dai trasferimenti correnti a qualunque titolo dovuti dalla regione.

10. Gli interessi sulle anticipazioni di tesoreria decorrono dall'effettivo utilizzo delle somme con le modalita' previste dalla convenzione.

11. La regione registra le operazioni di anticipazione e i relativi rimborsi secondo le modalita' indicate nel principio applicato della contabilita' finanziaria allegato al presente decreto.

### Art. 70. - (( (Cooperazione Stato-Regioni).))

((

1. Gli organi statali e le regioni sono tenuti a fornirsi, reciprocamente e a richiesta, ogni notizia utile allo svolgimento delle proprie funzioni nella materia di cui al presente decreto, nonche' a concordare le modalita' di utilizzazione comune dei rispettivi sistemi informativi e le altre forme di collaborazione.

2. In attuazione di quanto previsto dal comma 1, le regioni trasmettono alla banca dati delle amministrazioni pubbliche tutte le informazioni previste dall'art. 13 della legge 31 dicembre 2009 n. 196, e accedono alla medesima banca dati secondo le modalita' previste con apposito decreto del Ministro dell'economia e delle finanze.

))

### Art. 71. - (( (Responsabilita' verso l'ente degli amministratori e dei dipendenti, competenza della Corte dei conti e obblighi di denunzia).))

((

1. Gli amministratori e i dipendenti della regione, per danni arrecati nell'esercizio delle loro funzioni, rispondono nei soli casi e negli stessi limiti di cui alla legge 14 gennaio 1994, n. 20, e successive modificazioni. Si applicano alle indicate ipotesi di responsabilita' gli istituti processuali valevoli per i dipendenti delle amministrazioni statali.

))

### Art. 72. - (( (Il Collegio dei revisori dei conti).))

((

1. Il collegio dei revisori dei conti, istituito ai sensi e secondo le modalita' previste dall'art. 14, comma 1, lettera e), del decreto-legge 3 agosto 2011, n. 138, convertito, con modificazioni, dalla legge 14 settembre 2011, n. 148, svolge la funzione di vigilanza sulla regolarita' contabile, finanziaria ed economica della gestione della regione, delle sue articolazioni organizzative dotate di autonomia contabile e di bilancio, compreso il Consiglio regionale, ove non sia presente un proprio organo di revisione.

2. Il collegio svolge i compiti previsti dall'art. 20 del decreto legislativo 30 giugno 2011, n. 123. Restano fermi gli ulteriori adempimenti previsti dal presente articolo. L'ordinamento contabile regionale puo' prevedere ampliamenti delle funzioni affidate al collegio dei revisori.

3. Nello svolgimento dell'attivita' di controllo, il collegio si conforma ai principi di onorabilita', professionalita' e indipendenza previsti dall'art. 2387 del codice civile.

4. Al fine di garantire lo svolgimento delle proprie funzioni, il collegio dei revisori ha diritto di accesso agli atti e documenti della regione. I singoli componenti hanno diritto di eseguire ispezioni e controlli individuali.

5. Il registro dei verbali e' custodito presso la sede della regione. Copia del verbale e' inviata al presidente della regione, al Consiglio regionale, alla sezione regionale di controllo della Corte dei conti e al responsabile finanziario della regione.

))

### Art. 73. - (Riconoscimento di legittimita' di debiti fuori bilancio delle Regioni)

1. Il Consiglio regionale riconosce con legge, la legittimita' dei debiti fuori bilancio derivanti da:

- a) sentenze esecutive;
- b) copertura dei disavanzi di enti, societa' ed organismi controllati, o, comunque, dipendenti dalla Regione, purche' il disavanzo derivi da fatti di gestione;
- c) ricapitalizzazione, nei limiti e nelle forme previste dal codice civile o da norme speciali, delle societa' di cui alla lettera b);
- d) procedure espropriative o di occupazione d'urgenza per opere di pubblica utilita';
- e) acquisizione di beni e servizi in assenza del preventivo impegno di spesa.

2. Per il pagamento la Regione puo' provvedere anche mediante un piano di rateizzazione, della durata di tre esercizi finanziari compreso quello in corso, convenuto con i creditori.

3. Qualora il bilancio della Regione non rechi le disponibilita' finanziarie sufficienti per effettuare le spese conseguenti al riconoscimento dei debiti fuori bilancio, la Regione e' autorizzata a deliberare aumenti, sino al limite massimo consentito dalla vigente legislazione, dei tributi, delle addizionali, delle aliquote ovvero delle maggiorazioni di aliquote ad essa attribuite, nonche' ad elevare ulteriormente la misura dell'imposta regionale di cui all' art. 17, comma 1, del decreto legislativo 21 dicembre 1990, n. 398, fino a un massimo di cinque centesimi per litro, ulteriori rispetto alla misura massima consentita.

4. Al riconoscimento della legittimita' dei debiti fuori bilancio di cui al comma 1, lettera a), ((il Consiglio regionale o la Giunta regionale provvedono entro trenta giorni)) dalla ricezione della relativa proposta. Decorso inutilmente tale termine, la legittimita' di detto debito si intende riconosciuta.

## Adeguamento delle disposizioni riguardanti la finanza regionale e locale))

### Art. 74. - (Adeguamento dell'ordinamento contabile degli enti locali)

1. Nel decreto legislativo 18 agosto 2000, n. 267, e successive modificazioni, recante il testo unico delle leggi sull'ordinamento degli enti locali, sono apportate le seguenti modificazioni: 1) all'art. 114:

- a) al comma 1 e' aggiunto, in fine, il seguente periodo: «L'azienda speciale conforma la propria gestione ai principi contabili generali contenuti nell'allegato n. 1 al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, ed ai principi del codice civile.»;
- b) al comma 2 e' aggiunto, in fine, il seguente periodo: «L'istituzione conforma la propria gestione ai principi contabili generali e applicati allegati al decreto legislativo 23 giugno 2011, n. 118 e successive modificazioni e integrazioni ed adotta il medesimo sistema contabile dell'ente locale che lo ha istituito, nel rispetto di quanto previsto dall'art. 151, comma 2. L'ente locale che si avvale della facolta' di non tenere la contabilita' economico patrimoniale di cui all'art. 232, comma 3, puo' imporre alle proprie istituzioni l'adozione della contabilita' economico-patrimoniale.»;
- c) al comma 4, la parola: «informano» e' sostituita dalla seguente: «conformano», e le parole: «del pareggio di bilancio da perseguire attraverso l'equilibrio dei costi e dei ricavi, compresi i trasferimenti.» sono sostituite dalle seguenti: «dell'equilibrio economico, considerando anche i proventi derivanti dai trasferimenti, fermo restando, per l'istituzione, l'obbligo del pareggio finanziario.»;
- d) al comma 8, dopo le parole: « i seguenti atti» sono inserite le seguenti: « dell'azienda»;
- e) le lettere b), c) e d) del comma 8 sono sostituite dalle seguenti: «b) il budget economico almeno triennale; c) il bilancio di esercizio; d) il piano degli indicatori di bilancio.» ((...))
- f) (( f) )) dopo il comma 8 e' aggiunto, in fine, il seguente: «8-bis. Ai fini di cui al comma 6, sono fondamentali i seguenti atti dell'istituzione da sottoporre all'approvazione del consiglio comunale: a) il piano-programma, di durata almeno triennale, che costituisce il documento di programmazione dell'istituzione; b) il bilancio di previsione almeno triennale, predisposto secondo lo schema di cui all'allegato n. 9 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, completo dei relativi allegati; c) le variazioni di bilancio; d) il rendiconto della gestione predisposto secondo lo schema di cui all'allegato n. 10 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, completo dei relativi allegati.»; 2) alla lettera d) del comma 2 dell'art. 147 dopo le parole: «la ((redazione)) del bilancio consolidato» sono inserite le seguenti: «nel rispetto di quanto previsto dal decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni»; 3) al comma 4 dell'art. 147-quater, dopo le parole: «secondo la competenza economica» sono inserite le seguenti: «, predisposto secondo le modalita' previste dal decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni»; 4) all'art. 150: a) al comma 1, dopo le parole: «dalle disposizioni di principio del presente testo unico» sono aggiuntele seguenti: «e del decreto legislativo 23 giugno 2011, n. 118.»; b) il comma 3 e' abrogato; 5) l'art. 151 e' sostituito dal seguente: «Art. 151. (Principi generali). - 1. Gli enti locali ispirano la propria gestione al principio della programmazione. A tal fine presentano il Documento unico di programmazione entro il 31 luglio di ogni anno e il bilancio di previsione finanziario entro il 31 dicembre, riferiti ad un orizzonte temporale almeno triennale. Le previsioni del bilancio sono elaborate sulla base delle linee strategiche contenute nel documento unico di programmazione, osservando i principi contabili generali ed applicati allegati al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. I termini possono essere differiti con decreto del Ministro dell'interno, d'intesa con il Ministro dell'economia e delle finanze, sentita la Conferenza Stato-citta' ed autonomie locali, in presenza di motivate esigenze. 2. Il Documento unico di programmazione e' composto dalla Sezione strategica, della durata pari a quelle del mandato amministrativo, e dalla Sezione operativa di durata pari a quello del bilancio di previsione finanziario. 3. Il bilancio di previsione finanziario comprende le previsioni di competenza e di cassa del primo esercizio del periodo considerato e le previsioni di competenza degli esercizi successivi. Le previsioni riguardanti il primo esercizio costituiscono il bilancio di previsione finanziario annuale. 4. Il sistema contabile degli enti locali garantisce la rilevazione unitaria dei fatti gestionali sotto il profilo finanziario, economico e patrimoniale, attraverso l'adozione: a) della contabilita' finanziaria, che ha natura autorizzatoria e consente la rendicontazione della gestione finanziaria; b) della contabilita' economico-patrimoniale ai fini conoscitivi, per la rilevazione degli effetti economici e patrimoniali dei fatti gestionali e per consentire la rendicontazione economico e patrimoniale. 5. I risultati della gestione finanziaria, economico e patrimoniale sono dimostrati nel rendiconto comprendente il conto del bilancio, il conto economico e lo stato patrimoniale. 6. Al rendiconto e' allegata una relazione della Giunta sulla gestione che esprime le valutazioni di efficacia dell'azione condotta sulla base dei risultati conseguiti, e gli altri documenti previsti dall'art. 11, comma 4, del decreto legislativo 23 giugno 2011, n. 118. 7. Il rendiconto e' deliberato dall'organo consiliare entro il 30 aprile dell'anno successivo. 8. Entro il 31 luglio l'ente approva il bilancio consolidato con i bilanci dei propri organismi e enti strumentali e delle societa' controllate e partecipate, secondo il principio applicato n. 4/4 di cui al decreto legislativo 23 giugno 2011, n. 118.»; 6) all'art. 152: a) al comma 1, dopo le parole: «i principi contabili stabiliti dal presente testo unico» sono inserite le seguenti: «e dal decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni»; b) le lettere a), b), c), d), ed e), del comma 4 sono sostituite dalle seguenti: «a) art. 177; b) art. 185, comma 3; c) articoli 197 e 198; d) art. 205; e) articoli 213 e219»; 7) al comma 4 dell'art. 153, le parole: ((«annuale o pluriennale»)) sono sostituite dalle seguenti: «di previsione», dopo le parole: «dello stato di accertamento delle entrate e di impegno delle spese» sono inserite le seguenti:«, alla regolare tenuta della contabilita' economico-patrimoniale e» e dopo la parola: «finanziari» e' inserita la seguente: «e»; 8) all'art. 154: a) i commi da 1 a 4 sono sostituiti dai seguenti «1. E' istituito, senza nuovi o maggiori oneri per la finanza pubblica, presso il Ministero dell'interno l'Osservatorio sulla finanza e la contabilita' degli enti locali. 2. L'Osservatorio ha il compito di promuovere, in raccordo con la Commissione per l'armonizzazione contabile degli enti territoriali di cui all'art. 3-bis del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, l'adeguamento e la corretta applicazione dei principi contabili da parte degli enti locali e di monitorare la situazione della finanza pubblica locale attraverso studi ed analisi, anche in relazione agli effetti prodotti dall'applicazione della procedura di riequilibrio finanziario pluriennale di cui all'art. 243-bis. Nell'ambito dei suoi compiti, l'Osservatorio esprime pareri, indirizzi ed orientamenti. 3. Con decreto del Ministro dell'interno, di concerto con il Ministro dell'economia e delle finanze, sentita la Conferenza Stato-citta', sono disciplinate le modalita' di organizzazione e di funzionamento.»; 4. La partecipazione ai lavori dell'Osservatorio e' a titolo gratuito e non da' diritto ad alcun compenso o rimborso spese.»; b) il comma 7 e' abrogato; 9) all'art. 157: a) al comma1, le parole: «25, 29 e 30 della legge 5 agosto 1978, n. 468, e successive modificazioni ed integrazioni» sono sostituite dalle seguenti: «13, 14 e 15 della legge 31 dicembre 2009, n. 196, e successive modificazioni, e di cui al titolo I del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.»; b) dopo il comma 1 sono aggiunti i seguenti: «1-bis. Per le stesse finalita' di cui al comma 1 gli enti locali garantiscono la rilevazione unitaria dei fatti gestionali attraverso l'adozione di un piano integrato dei conti, articolato in piano finanziario, economico e patrimoniale secondo lo schema di cui all'allegato n. 6 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. Il livello minimo di articolazione del piano dei conti finanziario, ai fini del raccordo con i capitoli e gli articoli, ove previsti, del piano esecutivo di gestione e' costituito almeno dal quarto livello. 1-ter. Al fine di garantire la tracciabilita' di tutte le operazioni gestionali e la movimentazione delle voci del piano dei conti integrato, ad ogni transazione e' attribuita una codifica da applicare secondo le modalita' previste dagli articoli 5, 6 e 7 del decreto legislativo 23 giugno 2011, n. 118, e successive integrazioni. 1-quater. Le previsioni di competenza e di cassa, aggregate secondo l'articolazione del piano dei conti di quarto livello, ed i risultati della gestione aggregati secondo l'articolazione del piano dei conti, sono trasmessi alla banca dati unitaria delle amministrazioni pubbliche di cui all'art. 13 della legge 31 dicembre 2009, n. 196, sulla base di schemi, tempi e modalita' definiti con decreto del Ministro dell'economia e delle finanze.»; 10) l'art. 160 e' abrogato; 11) all'art. 162: a) al comma 1, le parole: «redatto in termini di competenza, per l'anno successivo, osservando i principi di unita', annualita', universalita' ed integrita', veridicita', pareggio finanziario e pubblicita'. La situazione corrente, come definita al comma 6 del presente articolo, non puo' presentare un disavanzo» sono sostituite dalle seguenti:«riferito ad almeno un triennio, comprendente le previsioni di competenza e di cassa del primo esercizio del periodo considerato e le previsioni di competenza degli esercizi successivi, osservando i principi contabili generali e applicati allegati al decreto legislativo 23 giugno 2011, n. 118 ((, e successive modificazioni»;)) b) il comma 6 e' sostituito dal seguente: «6.Il bilancio di previsione e' deliberato in pareggio finanziario complessivo per la competenza, comprensivo dell'utilizzo dell'avanzo di amministrazione e del recupero del disavanzo di amministrazione e garantendo un fondo di cassa finale non negativo. Inoltre, le previsioni di competenza relative alle spese correnti sommate alle previsioni di competenza relative ai trasferimenti in c/capitale,al saldo negativo delle partite finanziarie e alle quote di capitale delle rate di ammortamento dei mutui e degli altri prestiti, con l'esclusione dei rimborsi anticipati, non possono essere complessivamente superiori alle previsioni di competenza dei primi tre titoli dell'entrata, ai contribuiti destinati al rimborso dei prestiti e all'utilizzo dell'avanzo di competenza di parte corrente e non possono avere altra forma di finanziamento, salvo le eccezioni tassativamente indicate nel principio applicato alla contabilita' finanziaria necessarie a garantire elementi di flessibilita' degli equilibri di bilancio ai fini del rispetto del principio dell'integrita'.»; 12) l'art. 163 e' sostituito dal seguente: «Art. 163. (Esercizio provvisorio e gestione provvisoria). - 1. Se il bilancio di previsione non e' approvato dal Consiglio entro il 31 dicembre dell'anno precedente, la gestione finanziaria dell'ente si svolge nel rispetto dei principi applicati della contabilita' finanziaria riguardanti l'esercizio provvisorio o la gestione provvisoria.Nel corso dell'esercizio provvisorio o della gestione provvisoria, gli enti gestiscono gli stanziamenti di competenza previsti nell'ultimo bilancio approvato per l'esercizio cui si riferisce la gestione o l'esercizio provvisorio, ed effettuano i pagamenti entro i limiti determinati dalla somma dei residui al 31 dicembre dell'anno precedente e degli stanziamenti di competenza al netto del fondo pluriennale vincolato. 2. Nel caso in cui il bilancio di esercizio non sia approvato entro il 31 dicembre e non sia stato autorizzato l'esercizio provvisorio, o il bilancio non sia stato approvato entro i termini previsti ai sensi del comma 3, e' consentita esclusivamente una gestione provvisoria nei limiti dei corrispondenti stanziamenti di spesa dell'ultimo bilancio approvato per l'esercizio cui si riferisce la gestione provvisoria. Nel corso della gestione provvisoria l'ente puo' assumere solo obbligazioni derivanti da provvedimenti giurisdizionali esecutivi, quelle tassativamente regolate dalla legge e quelle necessarie ad evitare che siano arrecati danni patrimoniali certi e gravi all'ente. Nel corso della gestione provvisoria l'ente puo' disporre pagamenti solo per l'assolvimento delle obbligazioni gia' assunte, delle obbligazioni derivanti da provvedimenti giurisdizionali esecutivi e di obblighi speciali tassativamente regolati dalla legge, per le spese di personale, di residui passivi, di rate di mutuo, di canoni, imposte e tasse, ed, in particolare, per le sole operazioni necessarie ad evitare che siano arrecati danni patrimoniali certi e gravi all'ente. 3. L'esercizio provvisorio e' autorizzato con legge o con decreto del Ministro dell'interno che, ai sensi di quanto previsto dall'art. 151, primo comma, differisce il termine di approvazione del bilancio, d'intesa con il Ministro dell'economia e delle finanze, sentita la Conferenza Stato-citta' ed autonomia locale, in presenza di motivate esigenze. Nel corso dell'esercizio provvisorio non e' consentito il ricorso all'indebitamento e gli enti possono impegnare solo spese correnti, le eventuali spese correlate riguardanti le partite di giro, lavori pubblici di somma urgenza o altri interventi di somma urgenza. Nel corso dell'esercizio provvisorio e' consentito il ricorso all'anticipazione di tesoreria di cui all'art. 222. 4. All'avvio dell'esercizio provvisorio o della gestione provvisoria l'ente trasmette al tesoriere l'elenco dei residui presunti alla data del 1° gennaio e gli stanziamenti di competenza riguardanti l'anno a cui si riferisce l'esercizio provvisorio o la gestione provvisoria previsti nell'ultimo bilancio di previsione approvato, aggiornati alle variazioni deliberate nel corso dell'esercizio precedente, indicanti - per ciascuna missione, programma e titolo - gli impegni gia' assunti e l'importo del fondo pluriennale vincolato. 5. Nel corso dell'esercizio provvisorio, gli enti possono impegnare mensilmente,unitamente alla quota dei dodicesimi non utilizzata nei mesi precedenti, per ciascun programma, le spese di cui al comma 3, per importi non superiori ad un dodicesimo degli stanziamenti del secondo esercizio del bilancio di previsione deliberato l'anno precedente, ridotti delle somme gia' impegnate negli esercizi precedenti e dell'importo accantonato al fondo pluriennale vincolato, con l'esclusione delle spese: a) tassativamente regolate dalla legge; b) non suscettibili di pagamento frazionato in dodicesimi; c) a carattere continuativo necessarie per garantire il mantenimento del livello qualitativo e quantitativo dei servizi esistenti, impegnate a seguito della scadenza dei relativi contratti. 6. I pagamenti riguardanti spese escluse dal limite dei dodicesimi di cui al comma 5 sono individuati nel mandato attraverso l'indicatore di cui all'art. 185, comma 2, lettera i-bis). 7. Nel corso dell'esercizio provvisorio, sono consentite le variazioni di bilancio previste dall'art. 187, comma 3-quinquies, quelle riguardanti le variazioni del fondo pluriennale vincolato, quelle necessarie alla reimputazione agli esercizi in cui sono esigibili, di obbligazioni riguardanti entrate vincolate gia' assunte, e delle spese correlate, nei casi in cui anche la spesa e' oggetto di reimputazione l'eventuale aggiornamento delle spese gia' impegnate. Tali variazioni rilevano solo ai fini della gestione dei dodicesimi.»; 13) l'art. 164 e' sostituito dal seguente: «Art. 164. - (Caratteristiche del bilancio) - 1. L'unita' di voto del bilancio per l'entrata e' la tipologia e per la spesa e' il programma, articolato in titoli. 2. Il bilancio di previsione finanziario ha carattere autorizzatorio, costituendo limite, per ciascuno degli esercizi considerati: a) agli accertamenti e agli incassi riguardanti le accensioni di prestiti; b) agli impegni e ai pagamenti di spesa. Non comportano limiti alla gestione le previsioni riguardanti i rimborsi delle anticipazioni di tesoreria e le partite di giro.»; 14) all'art. 165: a) al comma 1, la parola: «annuale» e' sostituita dalla seguente: «finanziario », dopo le parole: «all'entrata ed alla spesa» sono inserite le seguenti: «ed e' redatto secondo lo schema previsto dall'allegato n. 9 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.»; b) i commi da 2 a 14 sono sostituiti dai seguenti: «2. Le previsioni di entrata del bilancio di previsione sono classificate, secondo le modalita' indicate all'art. 15 del decreto legislativo 23 giugno 2011, n. 118, in: a) titoli, definiti secondo la fonte di provenienza delle entrate; b) tipologie, definite in base alla natura delle entrate, nell'ambito di ciascuna fonte di provenienza. 3. Ai fini della gestione, nel Piano esecutivo di gestione, le tipologie sono ripartite in categorie, in capitoli ed eventualmente in articoli. Le categorie di entrata degli enti locali sono individuate nell'elenco di cui all'allegato n. 13/2 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. Nell'ambito delle categorie e' data separata evidenza delle eventuali quote di entrata non ricorrente. La Giunta, contestualmente alla proposta di bilancio, trasmette, a fini conoscitivi, la proposta di articolazione delle tipologie in categorie. 4. Le previsioni di spesa del bilancio di previsione sono classificate secondo le modalita' indicate all'art. 14 del decreto legislativo 23 giugno 2011, n. 118 in: a) missioni, che rappresentano le funzioni principali e gli obiettivi strategici perseguiti dagli enti locali, utilizzando risorse finanziarie, umane e strumentali ad esse destinate; b) programmi, che rappresentano gli aggregati omogenei di attivita' volte a perseguire gli obiettivi definiti nell'ambito delle missioni. I programmi sono ripartiti in titoli e sono raccordati alla relativa codificazione COFOG di secondo livello (Gruppi), secondo le corrispondenze individuate nel glossario, di cui al comma 3-ter dell'art. 14, che costituisce parte integrante dell'allegato n. 14. 5. Ai fini della gestione, nel Piano esecutivo di gestione, i programmi sono ripartiti in titoli, macroaggregati, capitoli ed eventualmente in articoli. I macroaggregati di spesa degli enti locali sono individuati nell'elenco di cui all'allegato n. 14 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. La Giunta, contestualmente alla proposta di bilancio trasmette, a fini conoscitivi, la proposta di articolazione dei programmi in macroaggregati. ((...)) 6. Il bilancio di previsione finanziario indica, per ciascuna unita' di voto: a) l'ammontare presunto dei residui attivi o passivi alla chiusura dell'esercizio precedente a quello cui il bilancio si riferisce; b) l'ammontare delle previsioni di competenza e di cassa definitive dell'anno precedente a quello cui si riferisce il bilancio; c) l'ammontare degli accertamenti e degli impegni che si prevede di imputare in ciascuno degli esercizi cui il bilancio si riferisce, nel rispetto del principio della competenza finanziaria; d) l'ammontare delle entrate che si prevede di riscuotere o delle spese di cui si autorizza il pagamento nel primo esercizio considerato nel bilancio, senza distinzioni fra riscossioni e pagamenti in conto competenza e in conto residui. 7. In bilancio, prima di tutte le entrate e le spese, sono iscritti: a) in entrata gli importi relativi al fondo pluriennale vincolato di parte corrente e al fondo pluriennale vincolato in c/capitale; b) in entrata del primo esercizio gli importi relativi all'utilizzo dell'avanzo di amministrazione presunto, nei casi individuati dall'art. 187, commi 3 e 3-bis, con l'indicazione della quota vincolata del risultato di amministrazione utilizzata anticipatamente; c) in uscita l'importo del disavanzo di amministrazione presunto al 31 dicembre dell'esercizio precedente cui il bilancio si riferisce. Il disavanzo di amministrazione presunto puo' essere iscritto nella spesa degli esercizi successivi secondo le modalita' previste dall'art. 188; d) in entrata del primo esercizio il fondo di cassa presunto dell'esercizio precedente. 8. In bilancio, gli stanziamenti di competenza relativi alla spesa di cui al comma 6, lettere b) e c), individuano: a) la quota che e' gia' stata impegnata negli esercizi precedenti con imputazione all'esercizio cui si riferisce il bilancio; b) la quota di competenza costituita dal fondo pluriennale vincolato, destinata alla copertura degli impegni che sono stati assunti negli esercizi precedenti con imputazione agli esercizi successivi e degli impegni che si prevede di assumere nell'esercizio con imputazione agli esercizi successivi. Con riferimento a tale quota non e' possibile impegnare e pagare con imputazione all'esercizio cui lo stanziamento si riferisce. Agli stanziamenti di spesa riguardanti il fondo pluriennale vincolato e' attribuito il codice della missione e del programma di spesa cui il fondo si riferisce e il codice del piano dei conti relativo al fondo pluriennale vincolato. 9. I bilanci di previsione degli enti locali recepiscono, per quanto non contrasta con la normativa del presente testo unico, le norme recate dalle leggi delle rispettive regioni di appartenenza riguardanti le entrate e le spese relative a funzioni delegate, al fine di consentire la possibilita' del controllo regionale sulla destinazione dei fondi assegnati agli enti locali e l'omogeneita' delle classificazioni di dette spese nei bilanci di previsione degli enti rispetto a quelle contenute nei rispettivi bilanci di previsione regionali. Le entrate e le spese per le funzioni delegate dalle regioni non possono essere collocate tra i servizi per conto di terzi nei bilanci di previsione degli enti locali. 10. Il bilancio di previsione si conclude con piu' quadri riepilogativi, secondo gli schemi previsti dall'allegato n. 9 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. 11. Formano oggetto di specifica approvazione del consiglio le previsioni di cui al comma 6, lettere c) e d), per ogni unita' di voto, e le previsioni del comma 7.»; 15) all'art. 166: a) il comma 1 e' sostituito dal seguente «1. Nella missione "Fondi e Accantonamenti", all'interno del programma "Fondo di riserva", gli enti locali iscrivono un fondo di riserva non inferiore allo 0,30 e non superiore al 2 per cento del totale delle spese correnti di competenza inizialmente previste in bilancio. »; b) dopo il comma 2-ter e' aggiunto il seguente: «2-quater. Nella missione "Fondi e Accantonamenti", all'interno del programma "Fondo di riserva", gli enti locali iscrivono un fondo di riserva di cassa non inferiore allo 0,2 per cento delle spese finali, utilizzato con deliberazioni dell'organo esecutivo.»; 16) l'art. 167 e' sostituito dal seguente: «Art. 167. (Fondo crediti di dubbia esigibilita' e altri fondi per spese potenziali). - 1. Nella missione "Fondi e Accantonamenti", all'interno del programma "Fondo crediti di dubbia esigibilita'" e' stanziato l'accantonamento al fondo crediti di dubbia esigibilita', il cui ammontare e' determinato in considerazione dell'importo degli stanziamenti di entrata di dubbia e difficile esazione, secondo le modalita' indicate nel principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2 al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. 2. Una quota del risultato di amministrazione e' accantonata per il fondo crediti di dubbia esigibilita', il cui ammontare e' determinato, secondo le modalita' indicate nel principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2 al decreto legislativo 23 giugno 2011, n. 118 e successive modificazioni e integrazioni, in considerazione dell'ammontare dei crediti di dubbia e difficile esazione, e non puo' essere destinata ad altro utilizzo. 3. E' data facolta' agli enti locali di stanziare nella missione "Fondi e accantonamenti", all'interno del programma "Altri fondi", ulteriori accantonamenti riguardanti passivita' potenziali, sui quali non e' possibile impegnare e pagare. A fine esercizio, le relative economie di bilancio confluiscono nella quota accantonata del risultato di amministrazione, utilizzabili ai sensi di quanto previsto dall'art. 187, comma 3. Quando si accerta che la spesa potenziale non puo' piu' verificarsi, la corrispondente quota del risultato di amministrazione e' liberata dal vincolo.»; 17) all'art. 168: a) alla rubrica, sono aggiunte le seguenti parole: « e le partite di giro»; b) al comma 1, dopo le parole: «servizi per conto di terzi» sono inserite le seguenti: «e le partite di giro», le parole: «ivi compresi i fondi economali, e» sono soppresse, le parole: «sono ordinati esclusivamente in capitoli, secondo la partizione contenuta nel regolamento di cui all'art. 160.» sono sostituite dalle seguenti: « comprendono le transazioni poste in essere per conto di altri soggetti, in assenza di qualsiasi discrezionalita' come individuate dal principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.»; ((c) )) il comma 2 e' sostituito dal seguente: «2. Le partite di giro riguardano le operazioni effettuate come sostituto di imposta, per la gestione dei fondi economali e le altre operazioni previste nel principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.»; ((d) )) dopo il comma 2 sono inseriti i seguenti: «2-bis. Le previsioni e gli accertamenti d'entrata riguardanti i servizi per conto di terzi e le partite di giro conservano l'equivalenza con le corrispondenti previsioni e impegni di spesa, e viceversa. A tal fine, le obbligazioni giuridicamente perfezionate attive e passive che danno luogo ad entrate e spese riguardanti tali operazioni sono registrate e imputate all'esercizio in cui l'obbligazione e' perfezionata, in deroga al principio contabile generale n. 16. 2-ter. Non comportando discrezionalita' e autonomia decisionale, gli stanziamenti riguardanti le operazioni per conto di terzi e le partite di giro non hanno natura autorizzatoria.»; 18) l'art. 169 e' sostituito dal seguente: «Art. 169. (Piano esecutivo di gestione). - 1. La giunta delibera il piano esecutivo di gestione (PEG) entro venti giorni dall'approvazione del bilancio di previsione, in termini di competenza . Con riferimento al primo esercizio il PEG e' redatto anche in termini di cassa. Il PEG e' riferito ai medesimi esercizi considerati nel bilancio, individua gli obiettivi della gestione ed affida gli stessi, unitamente alle dotazioni necessarie, ai responsabili dei servizi. 2. Nel PEG le entrate sono articolate in titoli, tipologie, categorie, capitoli, ed eventualmente in articoli, secondo il rispettivo oggetto. Le spese sono articolate in missioni, programmi, titoli, macroaggregati, capitoli ed eventualmente in articoli. I capitoli costituiscono le unita' elementari ai fini della gestione e della rendicontazione, e sono raccordati al quarto livello del piano dei conti finanziario di cui all'art. 157. 3. L'applicazione dei commi 1 e 2 del presente articolo e' facoltativa per gli enti locali con popolazione inferiore a 5.000 abitanti, fermo restando l'obbligo di rilevare unitariamente i fatti gestionali secondo la struttura del piano dei conti di cui all'art. 157, comma 1-bis. 3-bis. Il PEG e' deliberato in coerenza con il bilancio di previsione e con il documento unico di programmazione. Al PEG e' allegato il prospetto concernente la ripartizione delle tipologie in categorie e dei programmi in macroaggregati, secondo lo schema di cui all'allegato n. 8 al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. Il piano dettagliato degli obiettivi di cui all'art. 108, comma 1, del presente testo unico e il piano della performance di cui all'art. 10 del decreto legislativo 27 ottobre 2009, n. 150, sono unificati organicamente nel PEG .»; 19) l'art. 170 e' sostituito dal seguente: «Art. 170. (Documento unico di programmazione). - 1. Entro il 31 luglio di ciascun anno la Giunta presenta al Consiglio il Documento unico di programmazione per le conseguenti deliberazioni. Entro il 15 novembre di ciascun anno, con lo schema di delibera del bilancio di previsione finanziario, la Giunta presenta al Consiglio la nota di aggiornamento del Documento unico di programmazione.Con riferimento al periodo di programmazione decorrente dall'esercizio 2015, gli enti locali non sono tenuti alla predisposizione del documento unico di programmazione e allegano al bilancio annuale di previsione una relazione previsionale e programmatica che copra un periodo pari a quello del bilancio pluriennale, secondo le modalita' previste dall'ordinamento contabile vigente nell'esercizio 2014. Il primo documento unico di programmazione e' adottato con riferimento agli esercizi 2016 e successivi. Gli enti che hanno partecipato alla sperimentazione adottano la disciplina prevista dal presente articolo a decorrere dal 1° gennaio 2015. 2. Il Documento unico di programmazione ha carattere generale e costituisce la guida strategica ed operativa dell'ente. 3. Il Documento unico di programmazione si compone di due sezioni: la Sezione strategica e la Sezione operativa. La prima ha un orizzonte temporale di riferimento pari a quello del mandato amministrativo, la seconda pari a quello del bilancio di previsione. 4. Il documento unico di programmazione e' predisposto nel rispetto di quanto previsto dal principio applicato della programmazione di cui all'allegato n. 4/1 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. 5. Il Documento unico di programmazione costituisce atto presupposto indispensabile per l'approvazione del bilancio di previsione. 6. Gli enti locali con popolazione fino a 5.000 abitanti predispongono il Documento unico di programmazione semplificato previsto dall'allegato n. 4/1 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. 7. Nel regolamento di contabilita' sono previsti i casi di inammissibilita' e di improcedibilita' per le deliberazioni del Consiglio e della Giunta che non sono coerenti con le previsioni del Documento unico di programmazione.»; 20) l'art. 171 e' abrogato; 21) l'art. 172 e' sostituito dal seguente: «Art. 172. (Altri allegati al bilancio di previsione). - 1. Al bilancio di previsione sono allegati i documenti previsti dall'art. 11, comma 3, del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, e i seguenti documenti: a) l'elenco degli indirizzi internet di pubblicazione del rendiconto della gestione, del bilancio consolidato deliberati e relativi al penultimo esercizio antecedente quello cui si riferisce il bilancio di previsione, dei rendiconti e dei bilanci consolidati delle unioni di comuni e dei soggetti considerati nel gruppo "amministrazione pubblica" di cui al principio applicato del bilancio consolidato allegato al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, relativi al penultimo esercizio antecedente quello cui il bilancio si riferisce. Tali documenti contabili sono allegati al bilancio di previsione qualora non integralmente pubblicati nei siti internet indicati nell'elenco; b) la deliberazione, da adottarsi annualmente prima dell'approvazione del bilancio, con la quale i comuni verificano la quantita' e qualita' di aree e fabbricati da destinarsi alla residenza, alle attivita' produttive e terziarie - ai sensi delle leggi 18 aprile 1962, n. 167, 22 ottobre 1971, n. 865, e 5 agosto 1978, n. 457, che potranno essere ceduti in proprieta' od in diritto di superficie; con la stessa deliberazione i comuni stabiliscono il prezzo di cessione per ciascun tipo di area o di fabbricato; c) le deliberazioni con le quali sono determinati, per l'esercizio successivo, le tariffe, le aliquote d'imposta e le eventuali maggiori detrazioni, le variazioni dei limiti di reddito per i tributi locali e per i servizi locali, nonche', per i servizi a domanda individuale, i tassi di copertura in percentuale del costo di gestione dei servizi stessi; d) la tabella relativa ai parametri di riscontro della situazione di deficitarieta' strutturale prevista dalle disposizioni vigenti in materia; e) il prospetto della concordanza tra bilancio di previsione e obiettivo programmatico del patto di stabilita' interno.»; 22) all'art. 174: a) al comma 1, la parola: «annuale» e' abrogata, le parole: «la relazione previsionale e programmatica e lo schema di bilancio pluriennale» sono sostituite dalle seguenti: «finanziario e il Documento unico di programmazione», dopo le parole: «organo di revisione» sono aggiunte le seguenti: «entro il 15 novembre di ogni anno»; b) al comma 2, dopo le parole: «dell'organo consiliare» sono inserite le seguenti: «e dalla Giunta» le parole: «predisposti dall'organo esecutivo» sono soppresse. Dopo il primo periodo, e' aggiunto il seguente: «A seguito di variazioni del quadro normativo di riferimento sopravvenute, l'organo esecutivo presenta all'organo consiliare emendamenti allo schema di bilancio e alla nota di aggiornamento al Documento unico di programmazione in corso di approvazione.»; c) al comma 3, la parola: «annuale» e' abrogata, dopo le parole : «di previsione» e' inserita la seguente: «finanziario». Il secondo periodo e' soppresso; d) il comma 4 e' sostituito dal seguente: «4. Nel sito internet dell'ente locale sono pubblicati il bilancio di previsione, il piano esecutivo di gestione, le variazioni al bilancio di previsione, il bilancio di previsione assestato ed il piano esecutivo di gestione assestato.»; 23) all'art. 175: a) al comma 1, dopo le parole: «il bilancio di previsione» e' inserita la seguente: «finanziario», dopo le parole: «di competenza» sono inserite le seguenti: « e di cassa» e dopo le parole: «relativa alle spese» sono aggiunte le seguenti: «,per ciascuno degli esercizi considerati nel documento.»; b) al comma 2, dopo le parole: «dell'organo consiliare» sono aggiunte le seguenti: «salvo quelle previste dai commi 5-bis e 5-quater.»; c) al comma 3, dopo le parole: «non oltre il 30 novembre di ciascun anno» sono aggiunte le seguenti: «, fatte salve le seguenti variazioni, che possono essere deliberate sino al 31 dicembre di ciascun anno: a) l'istituzione di tipologie di entrata a destinazione vincolata e il correlato programma di spesa; b) l'istituzione di tipologie di entrata senza vincolo di destinazione, con stanziamento pari a zero, a seguito di accertamento e riscossione di entrate non previste in bilancio, secondo le modalita' disciplinate dal principio applicato della contabilita' finanziaria; c) l'utilizzo delle quote del risultato di amministrazione vincolato ed accantonato per le finalita' per le quali sono stati previsti; d) quelle necessarie alla reimputazione agli esercizi in cui sono esigibili, di obbligazioni riguardanti entrate vincolate gia' assunte e, se necessario, delle spese correlate; e) le variazioni delle dotazioni di cassa di cui al comma 5-bis, lettera d); f) le variazioni di cui al comma 5-quater, lettera b); g) le variazioni degli stanziamenti riguardanti i versamenti ai conti di tesoreria statale intestati all'ente e i versamenti a depositi bancari intestati all'ente»; d) al comma 4, dopo le parole: « in via d'urgenza» sono inserite le seguenti: «opportunamente motivata,»; e) dopo il comma 5, sono inseriti i seguenti: «5-bis. L'organo esecutivo con provvedimento amministrativo approva le variazioni del piano esecutivo di gestione, salvo quelle di cui al comma 5-quater, e le seguenti variazioni del bilancio di previsione non aventi natura discrezionale, che si configurano come meramente applicative delle decisioni del Consiglio, per ciascuno degli esercizi considerati nel bilancio: a) variazioni riguardanti l'utilizzo della quota vincolata e accantonata del risultato di amministrazione nel corso dell'esercizio provvisorio consistenti nella mera reiscrizione di economie di spesa derivanti da stanziamenti di bilancio dell'esercizio precedente corrispondenti a entrate vincolate, secondo le modalita' previste dall'art. 187, comma 3-quinquies; b) variazioni compensative tra le dotazioni delle missioni e dei programmi riguardanti l'utilizzo di risorse comunitarie e vincolate, nel rispetto della finalita' della spesa definita nel provvedimento di assegnazione delle risorse, o qualora le variazioni siano necessarie per l'attuazione di interventi previsti da intese istituzionali di programma o da altri strumenti di programmazione negoziata, gia' deliberati dal Consiglio; c) variazioni compensative tra le dotazioni delle missioni e dei programmi limitatamente alle spese per il personale, conseguenti a provvedimenti di trasferimento del personale all'interno dell'ente; d) variazioni delle dotazioni di cassa, salvo quelle previste dal comma 5-quater, garantendo che il fondo di cassa alla fine dell'esercizio sia non negativo; e) variazioni riguardanti il fondo pluriennale vincolato di cui all'art. 3, comma 5, del decreto legislativo 23 giugno 2011, n. 118, effettuata entro i termini di approvazione del rendiconto in deroga al comma 3. 5-ter. Con il regolamento di contabilita' si disciplinano le modalita' di comunicazione al Consiglio delle variazioni di bilancio di cui al comma 5-bis. 5-quater. Nel rispetto di quanto previsto dai regolamenti di contabilita', i responsabili della spesa o, in assenza di disciplina, il responsabile finanziario, possono effettuare, per ciascuno degli esercizi del bilancio: a) le variazioni compensative del piano esecutivo di gestione fra capitoli di entrata della medesima categoria e fra i capitoli di spesa del medesimo macroaggregato, escluse le variazioni dei capitoli appartenenti ai macroaggregati riguardanti i trasferimenti correnti, i contribuiti agli investimenti, ed ai trasferimenti in conto capitale, che sono di competenza della Giunta; b) le variazioni di bilancio fra gli stanziamenti riguardanti il fondo pluriennale vincolato e gli stanziamenti correlati, in termini di competenza e di cassa, escluse quelle previste dall'art. 3, comma 5, del decreto legislativo 23 giugno 2011, n. 118. Le variazioni di bilancio riguardanti le variazioni del fondo pluriennale vincolato sono comunicate trimestralmente alla giunta; c) le variazioni di bilancio riguardanti l'utilizzo della quota vincolata del risultato di amministrazione derivanti da stanziamenti di bilancio dell'esercizio precedente corrispondenti a entrate vincolate, in termini di competenza e di cassa, secondo le modalita' previste dall'art. 187, comma 3-quinquies; d) le variazioni degli stanziamenti riguardanti i versamenti ai conti di tesoreria statale intestati all'ente e i versamenti a depositi bancari intestati all'ente; e) le variazioni necessarie per l'adeguamento delle previsioni, compresa l'istituzione di tipologie e programmi, riguardanti le partite di giro e le operazioni per conto di terzi. 5-quinquies. Le variazioni al bilancio di previsione disposte con provvedimenti amministrativi, nei casi previsti dal presente decreto, e le variazioni del piano esecutivo di gestione non possono essere disposte con il medesimo provvedimento amministrativo. Le determinazioni dirigenziali di variazione compensativa dei capitoli del piano esecutivo di gestione di cui al comma 5-quater sono effettuate al fine di favorire il conseguimento degli obiettivi assegnati ai dirigenti.»; f) il comma 6 e' sostituito dal seguente: «6. Sono vietate le variazioni di giunta compensative tra macroaggregati appartenenti a titoli diversi.»;
- g) al comma 7, le parole: « nei servizi per conto di terzi » sono sostituite dalle seguenti: «nei titoli riguardanti le entrate e le spese per conto di terzi e partite di giro»;
- h) al comma 8, le parole: «30 novembre» sono sostituite dalle seguenti: «31 luglio» e dopo le parole: «fondo di riserva» sono inserite le seguenti: «ed il fondo di cassa,»;
- i) al comma 9, dopo le parole: «dell'organo esecutivo» sono inserite le seguenti: «, salvo quelle previste dal comma 5-quater, » e dopo le parole: «entro il 15 dicembre di ciascun anno» sono aggiunte le seguenti: «, fatte salve le variazioni correlate alle variazioni di bilancio previste al comma 3, che possono essere deliberate sino al 31 dicembre di ciascun anno.»;
- l) dopo il comma 9 e' aggiunto, in fine, il seguente: «9-bis. Le variazioni al bilancio di previsione sono trasmesse al tesoriere inviando il prospetto di cui all'art. 10, comma 4, del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, allegato al provvedimento di approvazione della variazione. Sono altresi' trasmesse al tesoriere: a) le variazioni dei residui a seguito del loro riaccertamento; b) le variazioni del fondo pluriennale vincolato effettuate nel corso dell'esercizio finanziario.»;
- m) dopo il comma 9-bis e' aggiunto il seguente: «9-ter. Nel corso dell'esercizio 2015 sono applicate le norme concernenti le variazioni di bilancio vigenti nell'esercizio 2014, fatta salva la disciplina del fondo pluriennale vincolato e del riaccertamento straordinario dei residui. Gli enti che hanno partecipato alla sperimentazione nel 2014 adottano la disciplina prevista dal presente articolo a decorrere dal 1° gennaio 2015.» 24) all'art. 176: a) alla rubrica, dopo le parole: «Prelevamenti dal fondo di riserva» sono aggiunte le seguenti: «e dai fondi spese potenziali»; b) dopo le parole: «fondo di riserva» sono inserite le seguenti: «, dal fondo di riserva di cassa e dai fondi spese potenziali»; 25) all'art. 179: a) dopo il primo periodo del comma 1 e' aggiunto il seguente: «Le entrate relative al titolo "Accensione prestiti" sono accertate nei limiti dei rispettivi stanziamenti di competenza del bilancio.»; b) al comma 2, dopo le parole: «l'accertamento delle entrate avviene» sono aggiunte le seguenti: «distinguendo le entrate ricorrenti da quelle non ricorrenti attraverso la codifica della transazione elementare di cui agli articoli 5 e 6 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, seguendo le seguenti disposizioni»; c) alla lettera c) del comma 2, dopo le parole: «delle spese» sono inserite le seguenti: «del titolo "Servizi per conto terzi e partite di giro",»; d) dopo la lettera c) del comma 2 e' inserita la seguente: «c-bis) per le entrate derivanti da trasferimenti e contributi da altre amministrazioni pubbliche a seguito della comunicazione dei dati identificativi dell'atto amministrativo di impegno dell'amministrazione erogante relativo al contributo o al finanziamento;»; e) alla lettera d) del comma 2, dopo le parole: «atti amministrativi specifici» sono aggiunte le seguenti: «, salvo i casi, tassativamente previsti nel principio applicato della contabilita' finanziaria, per cui e' previsto l'accertamento per cassa.»; f) al comma 3, dopo le parole: «regolamento di contabilita' dell'ente» sono aggiunte le seguenti:«, nel rispetto di quanto previsto dal presente decreto e dal principio generale della competenza finanziaria e dal principio applicato della contabilita' finanziaria di cui agli allegati n. 1 e n. 4/2 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.»; g) dopo il comma 3 e' aggiunto il seguente: «3-bis. L'accertamento dell'entrata e' registrato quando l'obbligazione e' perfezionata, con imputazione alle scritture contabili riguardanti l'esercizio in cui l'obbligazione viene a scadenza. Non possono essere riferite ad un determinato esercizio finanziario le entrate il cui diritto di credito non venga a scadenza nello stesso esercizio finanziario. E' vietato l'accertamento attuale di entrate future. Le entrate sono registrate nelle scritture contabili anche se non determinano movimenti di cassa effettivi.»; 26) all'art. 180: a) alla lettera d) del comma 3, la parola: «somme» e' sostituita dalle seguenti: ((entrate derivanti da legge)), da trasferimenti o da prestiti»; b) alla lettera e) del comma 3, le parole: «della risorsa o del capitolo di bilancio cui e' riferita l'entrata» sono sostituite dalle seguenti: «del titolo e della tipologia»; c) alla lettera f) del comma 3, dopo le parole: «la codifica» sono aggiunte le seguenti: «di bilancio»; d) dopo la lettera h) del comma 3 sono aggiunte le seguenti: « h-bis) la codifica SIOPE di cui all'art. 14 della legge 31 dicembre 2009, n. 196; h-ter) i codici della transazione elementare di cui agli articoli da 5 a 7, del decreto legislativo 23 giugno 2011, n. 118.»; e) al primo periodo del comma 4, dopo le parole: «versata in favore dell'ente,» sono inserite le seguenti: «ivi comprese le entrate di cui al comma 4-ter,». Dopo il secondo periodo e' aggiunto il seguente: «L'ente procede alla regolarizzazione dell'incasso entro i successivi 60 giorni e, comunque, entro i termini previsti per la resa del conto del tesoriere.»; f) dopo il comma 4 sono aggiunti, in fine, i seguenti: «4-bis. Gli ordinativi di incasso che si riferiscono ad entrate di competenza dell'esercizio in corso sono tenuti distinti da quelli relativi ai residui, garantendone la numerazione unica per esercizio e progressiva. Gli ordinativi di incasso, sia in conto competenza sia in conto residui, sono imputati contabilmente all'esercizio in cui il tesoriere ha incassato le relative entrate, anche se la comunicazione e' pervenuta all'ente nell'esercizio successivo. 4-ter. Gli incassi derivanti dalle accensioni di prestiti sono disposti nei limiti dei rispettivi stanziamenti di cassa. 4-quater. E' vietata l'imputazione provvisoria degli incassi in attesa di regolarizzazione alle partite di giro. 4-quinquies. Gli ordinativi d'incasso non riscossi entro il termine dell'esercizio sono restituiti dal tesoriere all'ente per l'annullamento e la successiva emissione nell'esercizio successivo in conto residui. 4-sexies. I codici di cui al comma 3, lettera h-ter), possono essere applicati all'ordinativo di incasso a decorrere dal 1° gennaio 2016.»; 27) al comma 3 dell'art. 181, dopo le parole: «dal regolamento di contabilita'» sono aggiunte le seguenti:«, non superiori ai quindici giorni lavorativi»; 28) all'art. 183: a) al comma 1, dopo le parole: «indicata la ragione» sono inserite le seguenti: «e la relativa scadenza»; b) alla lettera b) del comma 2 dopo le parole: «oneri accessori» sono aggiunte le seguenti: «nei casi in cui non si sia provveduto all'impegno nell'esercizio in cui il contratto di finanziamento e' stato perfezionato»; c) la lettera c) del comma 2 e' sostituita dalla seguente: «c) per contratti di somministrazione riguardanti prestazioni continuative, nei casi in cui l'importo dell'obbligazione sia definita contrattualmente. Se l'importo dell'obbligazione non e' predefinito nel contratto, con l'approvazione del bilancio si provvede alla prenotazione della spesa, per un importo pari al consumo dell'ultimo esercizio per il quale l'informazione e' disponibile.»; d) il terzo periodo del comma 3 e' sostituito dai seguenti: «Le spese di investimento per lavori pubblici prenotate negli esercizi successivi, la cui gara e' stata formalmente indetta, concorrono alla determinazione del fondo pluriennale vincolato e non del risultato di amministrazione. In assenza di aggiudicazione definitiva della gara entro l'anno successivo le economie di bilancio confluiscono nell'avanzo di amministrazione vincolato per la riprogrammazione dell'intervento in c/capitale e il fondo pluriennale e' ridotto di pari importo.»; e) i commi 5, 6, 7 e 8, sono sostituiti dai seguenti: «5. Tutte le obbligazioni passive giuridicamente perfezionate, devono essere registrate nelle scritture contabili quando l'obbligazione e' perfezionata, con imputazione all'esercizio in cui l'obbligazione viene a scadenza, secondo le modalita' previste dal principio applicato della contabilita' finanziaria di cui all'allegato n. 4/2 del decreto legislativo 23 giugno 2011, n. 118. Non possono essere riferite ad un determinato esercizio finanziario le spese per le quali non sia venuta a scadere nello stesso esercizio finanziario la relativa obbligazione giuridica. Le spese sono registrate anche se non determinano movimenti di cassa effettivi. 6. Gli impegni di spesa sono assunti nei limiti dei rispettivi stanziamenti di competenza del bilancio di previsione, con imputazione agli esercizi in cui le obbligazioni passive sono esigibili. Non possono essere assunte obbligazioni che danno luogo ad impegni di spesa corrente: a) sugli esercizi successivi a quello in corso, a meno che non siano connesse a contratti o convenzioni pluriennali o siano necessarie per garantire la continuita' dei servizi connessi con le funzioni fondamentali, fatta salva la costante verifica del mantenimento degli equilibri di bilancio, anche con riferimento agli esercizi successivi al primo; b) sugli esercizi non considerati nel bilancio, a meno delle spese derivanti da contratti di somministrazione, di locazione, relative a prestazioni periodiche o continuative di servizi di cui all'art. 1677 del codice civile, delle spese correnti correlate a finanziamenti comunitari e delle rate di ammortamento dei prestiti, inclusa la quota capitale. Le obbligazioni che comportano impegni riguardanti le partite di giro e i rimborsi delle anticipazioni di tesoreria sono assunte esclusivamente in relazione alle esigenze della gestione. 7. I provvedimenti dei responsabili dei servizi che comportano impegni di spesa sono trasmessi al responsabile del servizio finanziario e sono esecutivi con l'apposizione del visto di regolarita' contabile attestante la copertura finanziaria. 8. Al fine di evitare ritardi nei pagamenti e la formazione di debiti pregressi, il responsabile della spesa che adotta provvedimenti che comportano impegni di spesa ha l'obbligo di accertare preventivamente che il programma dei conseguenti pagamenti sia compatibile con i relativi stanziamenti di cassa e con le regole del patto di stabilita' interno; la violazione dell'obbligo di accertamento di cui al presente comma comporta responsabilita' disciplinare ed amministrativa. Qualora lo stanziamento di cassa, per ragioni sopravvenute, non consenta di far fronte all'obbligo contrattuale, l'amministrazione adotta le opportune iniziative, anche di tipo contabile, amministrativo o contrattuale, per evitare la formazione di debiti pregressi.»; f) al primo periodo del comma 9, dopo le parole: «assumono atti di impegno» sono inserite le seguenti: «nel rispetto dei principi contabili generali e del principio applicato della contabilita' finanziaria di cui agli allegati n. 1 e n. 4/2del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.» ((e, al secondo periodo, le parole: «all'art. 151, comma 4»)) sono sostituite dalle seguenti: «ai commi 7 e 8.»; g) dopo il comma 9 e' inserito il seguente: «9-bis.Gli impegni sono registrati distinguendo le spese ricorrenti da quelle non ricorrenti attraverso la codifica della transazione elementare di cui agli articoli 5 e 6 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.» 29) all'art. 185: a) il comma 1 e' sostituito dal seguente: «1. Gli ordinativi di pagamento sono disposti nei limiti dei rispettivi stanziamenti di cassa, salvo i pagamenti riguardanti il rimborso delle anticipazioni di tesoreria, i servizi per conto terzi e le partite di giro.»; b) la lettera c) del comma 2 e' sostituita dalla seguente: «c) l'indicazione della missione, del programma e del titolo di bilancio cui e' riferita la spesa e la relativa disponibilita', distintamente per residui o competenza e cassa;»; c) alla lettera d) del comma 2, dopo la parola: «codifica» sono aggiunte le seguenti: «di bilancio»; d) alla lettera e) del comma 2, le parole: «, ove richiesto,» sono soppresse; e) alla lettera i) della comma 2,dopo le parole: «vincoli di destinazione» sono aggiunte le seguenti: «stabiliti per legge o relativi a trasferimenti o ai prestiti;»; f) dopo la lettera i) del comma 2 sono inserite le seguenti: «i-bis) la codifica SIOPE di cui all'art. 14 della legge 31 dicembre 2009, n. 196; i-ter) i codici della transazione elementare di cui agli articoli da 5 a 7, del decreto legislativo 23 giugno 2011, n. 118. i-quater) l'identificazione delle spese non soggette al controllo dei dodicesimi di cui all'art. 163, comma 5, in caso di esercizio provvisorio.»; g) al comma 3, dopo le parole: «della liquidazione» sono inserite le seguenti: «e al rispetto dell'autorizzazione di cassa,»; h) al secondo periodo del comma 4, le parole: «Entro quindici giorni e comunque entro il termine del mese in corso» sono sostituite dalle seguenti: «Entro trenta giorni» e dopo le parole: «ai fini della regolarizzazione» sono aggiunte le seguenti: «, imputandolo contabilmente all'esercizio in cui il tesoriere ha effettuato il pagamento, anche se la relativa comunicazione e' pervenuta all'ente nell'esercizio successivo.»; i) dopo il comma 4 e' aggiunto il seguente: «4-bis. I codici di cui al comma 2, lettera i-bis), possono essere applicati al mandato a decorrere dal 1° gennaio 2016.»; 30) all'art. 186: a) dopo il primo periodo del comma 1 e' aggiunto il seguente: «Tale risultato non comprende le risorse accertate che hanno finanziato spese impegnate con imputazione agli esercizi successivi, rappresentate dal fondo pluriennale vincolato determinato in spesa del conto del bilancio.»; b) dopo il comma 1 e' aggiunto il seguente: «1-bis. In occasione dell'approvazione del bilancio di previsione e' determinato l'importo del risultato di amministrazione presunto dell'esercizio precedente cui il bilancio si riferisce.»; 31) all'art. 187: a) la rubrica e' sostituita dalla seguente: «Composizione del risultato di amministrazione»; b) i commi 1, 2 e 3 sono sostituiti dai seguenti: «1. Il risultato di amministrazione e' distinto in fondi liberi, fondi vincolati, fondi destinati agli investimenti e fondi accantonati. I fondi destinati agli investimenti sono costituiti dalle entrate in c/capitale senza vincoli di specifica destinazione non spese, e sono utilizzabili con provvedimento di variazione di bilancio solo a seguito dell'approvazione del rendiconto. L'indicazione della destinazione nel risultato di amministrazione per le entrate in conto capitale che hanno dato luogo ad accantonamento al fondo crediti di dubbia e difficile esazione e' sospeso, per l'importo dell'accantonamento, sino all'effettiva riscossione delle stesse. I trasferimenti in conto capitale non sono destinati al finanziamento degli investimenti e non possono essere finanziati dal debito e dalle entrate in conto capitale destinate al finanziamento degli investimenti. I fondi accantonati comprendono gli accantonamenti per passivita' potenziali e il fondo crediti di dubbia esigibilita'. Nel caso in cui il risultato di amministrazione non sia sufficiente a comprendere le quote vincolate, destinate e accantonate, l'ente e' in disavanzo di amministrazione. Tale disavanzo e' iscritto come posta a se stante nel primo esercizio del bilancio di previsione secondo le modalita' previste dall'art. 188. 2. La quota libera dell'avanzo di amministrazione dell'esercizio precedente, accertato ai sensi dell'art. 186 e quantificato ai sensi del comma 1, puo' essere utilizzato con provvedimento di variazione di bilancio, per le finalita' di seguito indicate in ordine di priorita': a) per la copertura dei debiti fuori bilancio; b) per i provvedimenti necessari per la salvaguardia degli equilibri di bilancio di cui all'art. 193 ove non possa provvedersi con mezzi ordinari; c) per il finanziamento di spese di investimento; d) per il finanziamento delle spese correnti a carattere non permanente; e) per l'estinzione anticipata dei prestiti. Resta salva la facolta' di impiegare l'eventuale quota del risultato di amministrazione "svincolata", in occasione dell'approvazione del rendiconto, sulla base della determinazione dell'ammontare definitivo della quota del risultato di amministrazione accantonata per il fondo crediti di dubbia esigibilita', per finanziare lo stanziamento riguardante il fondo crediti di dubbia esigibilita' nel bilancio di previsione dell'esercizio successivo a quello cui il rendiconto si riferisce. 3. Le quote del risultato presunto derivanti dall'esercizio precedente, costituite da accantonamenti risultanti dall'ultimo consuntivo approvato o derivanti da fondi vincolati possono essere utilizzate per le finalita' cui sono destinate prima dell'approvazione del conto consuntivo dell'esercizio precedente, attraverso l'iscrizione di tali risorse, come posta a se' stante dell'entrata, nel primo esercizio del bilancio di previsione o con provvedimento di variazione al bilancio. L'utilizzo della quota vincolata o accantonata del risultato di amministrazione e' consentito, sulla base di una relazione documentata del dirigente competente, anche in caso di esercizio provvisorio, esclusivamente per garantire la prosecuzione o l'avvio di attivita' soggette a termini o scadenza, la cui mancata attuazione determinerebbe danno per l'ente, secondo le modalita' individuate al comma 3-quinquies.»; c) dopo il comma 3-bis sono inseriti i seguenti: «3-ter. Costituiscono quota vincolata del risultato di amministrazione le entrate accertate e le corrispondenti economie di bilancio: a) nei casi in cui la legge o i principi contabili generali e applicati individuano un vincolo di specifica destinazione dell'entrata alla spesa; b) derivanti da mutui e finanziamenti contratti per il finanziamento di investimenti determinati; c) derivanti da trasferimenti erogati a favore dell'ente per una specifica destinazione determinata; d) derivanti da entrate accertate straordinarie, non aventi natura ricorrente, cui l'amministrazione ha formalmente attribuito una specifica destinazione. E' possibile attribuire un vincolo di destinazione alle entrate straordinarie non aventi natura ricorrente solo se l'ente non ha rinviato la copertura del disavanzo di amministrazione negli esercizi successivi e ha provveduto nel corso dell'esercizio alla copertura di tutti gli eventuali debiti fuori bilancio, compresi quelli di cui all'art. 193. L'indicazione del vincolo nel risultato di amministrazione per le entrate vincolate che hanno dato luogo ad accantonamento al fondo crediti di dubbia e difficile esazione e' sospeso, per l'importo dell'accantonamento, sino all'effettiva riscossione delle stesse. 3-quater. Se il bilancio di previsione impiega quote vincolate del risultato di amministrazione presunto ai sensi del comma 3, entro il 31 gennaio la Giunta verifica l'importo delle quote vincolate del risultato di amministrazione presunto sulla base di un preconsuntivo relativo alle entrate e alle spese vincolate ed approva l'aggiornamento dell'allegato al bilancio di previsione di cui all'art. 11, comma 3, lettera a), del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. Se la quota vincolata del risultato di amministrazione presunto e' inferiore rispetto all'importo applicato al bilancio di previsione, l'ente provvede immediatamente alle necessarie variazioni di bilancio che adeguano l'impiego del risultato di amministrazione vincolato. 3-quinquies. Le variazioni di bilancio che, in attesa dell'approvazione del consuntivo, applicano al bilancio quote vincolate o accantonate del risultato di amministrazione, sono effettuate solo dopo l'approvazione del prospetto aggiornato del risultato di amministrazione presunto da parte della Giunta di cui al comma 3-quater. Le variazioni consistenti nella mera re-iscrizione di economie di spesa derivanti da stanziamenti di bilancio dell'esercizio precedente corrispondenti a entrate vincolate, possono essere disposte dai dirigenti se previsto dal regolamento di contabilita' o, in assenza di norme, dal responsabile finanziario. In caso di esercizio provvisorio tali variazioni sono di competenza della Giunta. 3-sexies. Le quote del risultato presunto derivante dall'esercizio precedente costituite dagli accantonamenti effettuati nel corso dell'esercizio precedente possono essere utilizzate prima dell'approvazione del conto consuntivo dell'esercizio precedente, per le finalita' cui sono destinate, con provvedimento di variazione al bilancio, se la verifica di cui al comma 3-quater e l'aggiornamento dell'allegato al bilancio di previsione di cui all'art. 11, comma 3, lettera a), del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, sono effettuate con riferimento a tutte le entrate e le spese dell'esercizio precedente e non solo alle entrate e alle spese vincolate.»; 32) all'art. 188: a) al comma 1, dopo la parola: «e'» e' inserita la seguente: «immediatamente» e le parole: «al bilancio di previsione nei modi e nei termini di cui all'art. 193, in aggiunta alle quote di ammortamento accantonate e non disponibili nel risultato contabile di amministrazione» sono sostituite dalle seguenti: «((...)) all'esercizio in corso di gestione contestualmente alla delibera di approvazione del rendiconto.»; b) al comma 1, dopo il primo periodo, sono aggiunti i seguenti: «La mancata adozione della delibera che applica il disavanzo al bilancio in corso di gestione e' equiparata a tutti gli effetti alla mancata approvazione del rendiconto di gestione. Il disavanzo di amministrazione puo' anche essere ripianato negli esercizi successivi considerati nel bilancio di previsione, in ogni caso non oltre la durata della consiliatura, contestualmente all'adozione di una delibera consiliare avente ad oggetto il piano di rientro dal disavanzo nel quale siano individuati i provvedimenti necessari a ripristinare il pareggio. Il piano di rientro e' sottoposto al parere del collegio dei revisori. Ai fini del rientro possono essere utilizzate le economie di spesa e tutte le entrate, ad eccezione di quelle provenienti dall'assunzione di prestiti e di quelle con specifico vincolo di destinazione, nonche' i proventi derivanti da alienazione di beni patrimoniali disponibili e da altre entrate in c/capitale con riferimento a squilibri di parte capitale. Ai fini del rientro, in deroga all'art. 1, comma 169, della legge 27 dicembre 2006, n. 296, contestualmente, l'ente puo' modificare le tariffe e le aliquote relative ai tributi di propria competenza. La deliberazione, contiene l'analisi delle cause che hanno determinato il disavanzo, l'individuazione di misure strutturali dirette ad evitare ogni ulteriore potenziale disavanzo, ed e' allegata al bilancio di previsione e al rendiconto, costituendone parte integrante. Con periodicita' almeno semestrale il sindaco o il presidente trasmette al Consiglio una relazione riguardante lo stato di attuazione del piano di rientro, con il parere del collegio dei revisori. L'eventuale ulteriore disavanzo formatosi nel corso del periodo considerato nel piano di rientro deve essere coperto non oltre la scadenza del piano di rientro in corso.»; c) dopo il comma 1 sono inseriti i seguenti: «1-bis. L'eventuale disavanzo di amministrazione presunto accertato ai sensi dell'art. 186, comma 1-bis, e' applicato al bilancio di previsione dell'esercizio successivo secondo le modalita' previste al comma 1. A seguito dell'approvazione del rendiconto e dell'accertamento dell'importo definitivo del disavanzo di amministrazione dell'esercizio precedente, si provvede all'adeguamento delle iniziative assunte ai sensi del presente comma. 1-ter. A seguito dell'eventuale accertamento di un disavanzo di amministrazione presunto nell'ambito delle attivita' previste dall'art. 187, comma 3-quinquies, effettuate nel corso dell'esercizio provvisorio nel rispetto di quanto previsto dall'art. 187, comma 3, si provvede alla tempestiva approvazione del bilancio di previsione. Nelle more dell'approvazione del bilancio la gestione prosegue secondo le modalita' previste dall'art. 163, comma 3. 1-quater. Agli enti locali che presentino, nell'ultimo rendiconto deliberato, un disavanzo di amministrazione ovvero debiti fuori bilancio, ancorche' da riconoscere, nelle more della variazione di bilancio che dispone la copertura del disavanzo e del riconoscimento e finanziamento del debito fuori bilancio, e' fatto divieto di assumere impegni e pagare spese per servizi non espressamente previsti per legge. Sono fatte salve le spese da sostenere a fronte di impegni gia' assunti nei precedenti esercizi.»; 33) all'art. 189: a) al comma 2 le parole: «nonche' le somme derivanti dalla stipulazione di contratti di apertura di credito» sono sostituite dalle seguenti: «esigibile nell'esercizio, secondo i principi applicati della contabilita' finanziaria di cui all'allegato n. 4/2 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.»; b) al comma 3 le parole: «costituiscono residui attivi le somme derivanti da mutui per i quali e' intervenuta la concessione definitiva da parte della Cassa depositi e prestiti o degli Istituti di previdenza ovvero la stipulazione del contratto per i mutui concessi da altri Istituti di credito.» sono sostituite dalle seguenti: «le somme rese disponibili dalla Cassa depositi e prestiti a titolo di finanziamento e non ancora prelevate dall'ente costituiscono residui attivi a valere dell'entrata classificata come prelievi da depositi bancari, nell'ambito del titolo Entrate da riduzione di attivita' finanziarie, tipologia Altre entrate per riduzione di attivita' finanziarie.»; c) al comma 4 la parola: «accertamenti» e' sostituita dalla seguente: «entrate»; 34) all'art. 191: a) al comma 1 le parole: «intervento o capitolo» sono sostituite dalla seguente: «programma». Il secondo periodo e' sostituito dai seguenti: «Nel caso di spese riguardanti trasferimenti e contributi ad altre amministrazioni pubbliche, somministrazioni, forniture, appalti e prestazioni professionali, il responsabile del procedimento di spesa comunica al destinatario le informazioni relative all'impegno. La comunicazione dell'avvenuto impegno e della relativa copertura finanziaria, riguardanti le somministrazioni, le forniture e le prestazioni professionali, e' effettuata contestualmente all'ordinazione della prestazione con l'avvertenza che la successiva fattura deve essere completata con gli estremi della suddetta comunicazione.»; b) al comma 2 le parole: «all'intervento o capitolo» sono sostituite dalle seguenti: «alla missione e al programma», dopo le parole: «di bilancio» sono inserite le seguenti: «e al relativo capitolo di spesa del piano esecutivo di gestione»; c) il comma 5 e' sostituito dal seguente: «5. Il regolamento di contabilita' dell'ente disciplina le modalita' attraverso le quali le fatture o i documenti contabili equivalenti che attestano l'avvenuta cessione di beni, lo stato di avanzamento di lavori, la prestazione di servizi nei confronti dell'ente sono protocollate ed, entro 10 giorni, annotate nel registro delle fatture ricevutesecondo le modalita' previste dall'art. 42 del decreto-legge 24 aprile 2014, n. 66, convertito in legge, con modificazioni, dalla legge 23 giugno 2014, n. 89. Per il protocollo di tali documenti e' istituito un registro uniconel rispetto della disciplina in materia di documentazione amministrativa di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, ed e' esclusa la possibilita' di ricorrere a protocolli di settore o di reparto.((».)) 35) all'art. 193: a) al comma 1, dopo le parole: «dal presente testo unico» sono aggiunte le seguenti: «, con particolare riferimento agli equilibri di competenza e di cassa di cui all'art. 162, comma 6.»; b) al comma 2, le parole: «30 settembre» sono sostituite dalle seguenti: «31 luglio», le parole: «ad effettuare la ricognizione sullo stato di attuazione dei programmi. In tale sede l'organo consiliare da'», sono sostituite dalle seguenti: «a dare», e le parole: «, adotta contestualmente i provvedimenti necessari per il ripiano degli eventuali debiti di cui all'art. 194, per il ripiano dell'eventuale disavanzo di amministrazione risultante dal rendiconto approvato e, qualora i dati della gestione finanziaria facciano prevedere un disavanzo, di amministrazione o di gestione, per squilibrio della gestione di competenza ovvero della gestione dei residui, adotta le misure necessarie a ripristinare il pareggio.» sono sostituite dalle seguenti: «ad adottare, contestualmente: a) le misure necessarie a ripristinare il pareggio qualora i dati della gestione finanziaria facciano prevedere un disavanzo, di gestione o di amministrazione, per squilibrio della gestione di competenza, di cassa ovvero della gestione dei residui; b) i provvedimenti per il ripiano degli eventuali debiti di cui all'art. 194; c) le iniziative necessarie ad adeguare il fondo crediti di dubbia esigibilita' accantonato nel risultato di amministrazione in caso di gravi squilibri riguardanti la gestione dei residui.»; c) il comma 3 e' sostituito dal seguente: «3.Ai fini del comma 2, fermo restando quanto stabilito dall'art. 194, comma 2, possono essere utilizzate per l'anno in corso e per i due successivi le possibili economie di spesa e tutte le entrate, ad eccezione di quelle provenienti dall'assunzione di prestiti e di quelle con specifico vincolo di destinazione, nonche' i proventi derivanti da alienazione di beni patrimoniali disponibili e da altre entrate in c/capitale con riferimento a squilibri di parte capitale. Ove non possa provvedersi con le modalita' sopra indicate e' possibile impiegare la quota libera del risultato di amministrazione. Per il ripristino degli equilibri di bilancio e in deroga all'art. 1, comma 169, della legge 27 dicembre 2006, n. 296, l'ente puo' modificare le tariffe e le aliquote relative ai tributi di propria competenza entro la data di cui al comma 2.»; 36) all'art. 195 a) la rubrica e' sostituita dalla seguente: «Utilizzo di entrate vincolate»: b) al comma 1, le parole: «di entrate aventi specifica destinazione» sono sostituite dalle seguenti: «delle entrate vincolate di cui all'art. 180, comma 3, lettera d)». Dopo il primo periodo, e' aggiunto il seguente: «I movimenti di utilizzo e di reintegro delle somme vincolate di cui all'art. 180, comma 3, sono oggetto di registrazione contabile secondo le modalita' indicate nel principio applicato della contabilita' finanziaria.»; c) al comma 2, le parole: «somme a specifica destinazione» sono sostituite dalle seguenti: «entrate vincolate», le parole: «dal tesoriere su specifiche richieste del servizio finanziario dell'ente» sono sostituite dalle seguenti: «dall'ente con l'emissione di appositi ordinativi di incasso e pagamento di regolazione contabile»; d) al comma 3, le parole: «somme a specifica destinazione» sono sostituite dalle seguenti: «entrate vincolate». Dopo il secondo periodo del comma 3 e' aggiunto il seguente: « La ricostituzione dei vincoli e' perfezionata con l'emissione di appositi ordinativi di incasso e pagamento di regolazione contabile.»; e) al comma 4, le parole: «somme a specifica destinazione» sono sostituite dalle seguenti: «entrate vincolate»; 37) la lettera a) del comma 2 dell'art. 197 e' sostituita dalla seguente: «a) predisposizione del piano esecutivo di gestione;»; 38) all'art. 199: a) alla lettera b) del comma 1 dell'art. 199, le parole: «avanzi di» sono sostituite dalle seguenti: «avanzo di parte corrente del», la parola : «costituiti» e' sostituita dalla seguente: «costituito»; b) dopo il comma 1, e' inserito il seguente: «1-bis. Le entrate di cui al comma 1, lettere a), c), d) ed f) sono destinate esclusivamente al finanziamento di spese di investimento e non possono essere impiegate per la spesa corrente.»; 39) all'art. 200: a) la rubrica e' sostituita dalla seguente: «Gli investimenti»: ((b) al comma 1, le parole: «pluriennale originario, eventualmente modificato)) dall'organo consiliare,» sono sostituite dalle seguenti: «di previsione»; c) dopo il comma 1, sono aggiunti, in fine, i seguenti: «1-bis. La copertura finanziaria delle spese di investimento imputate agli esercizi successivi e' costituita: a) da risorse accertate esigibili nell'esercizio in corso di gestione, confluite nel fondo pluriennale vincolato accantonato per gli esercizi successivi; b) da risorse accertate esigibili negli esercizi successivi, la cui esigibilita' e' nella piena discrezionalita' dell'ente o di altra pubblica amministrazione; c) dall'utilizzo del risultato di amministrazione nel primo esercizio considerato nel bilancio di previsione, nel rispetto di quanto previsto dall'art. 187. Il risultato di amministrazione puo' confluire nel fondo pluriennale vincolato accantonato per gli esercizi successivi. 1-ter. Per l'attivita' di investimento che comporta impegni di spesa che vengono a scadenza in piu' esercizi finanziari, deve essere dato specificamente atto, al momento dell'attivazione del primo impegno, di aver predisposto la copertura finanziaria per l'effettuazione della complessiva spesa dell'investimento, anche se la forma di copertura e' stata gia' indicata nell'elenco annuale del piano delle opere pubbliche di cui all'art. 128 del decreto legislativo n. 163 del 2006.»; 40) all'art. 201: a) al comma 1, dopo le parole: «sono autorizzate» sono inserite le seguenti: «, nel rispetto dei limiti imposti dall'ordinamento alla possibilita' di indebitamento,»; b) al comma 2, le parole: «al miliardo di lire» sono sostituite dalle seguenti: «a cinquecentomila euro»; 41) all'art. 203: a) alla lettera b) del comma 1, la parola: «annuale» e' sostituita dalle seguenti: «di previsione» le parole: «incluse le relative previsioni» sono sostituite dalle seguenti: «iscritti i relativi stanziamenti»; b) al comma 2, la parola: «annuale» e' sostituita dalla seguente: «di previsione» e le parole: «modifica il bilancio pluriennale e la relazione previsionale e programmatica» sono sostituite dalle seguenti: «adegua il documento unico di programmazione e di conseguenza le previsioni del bilancio degli esercizi successivi»; 42) all'art. 204: a) al comma 1, le parole: «Per le comunita' montane si fa riferimento ai primi due titoli delle entrate.» sono soppresse; b) alla fine del comma 1 sono aggiunti i seguenti periodi: «Il rispetto del limite e' verificato facendo riferimento anche agli interessi riguardanti i finanziamenti contratti e imputati contabilmente agli esercizi successivi. Non concorrono al limite di indebitamento le garanzie prestate per le quali l'ente ha accantonato l'intero importo del debito garantito.»; c) al comma 2, le parole: «dall'Istituto nazionale di previdenza per i dipendenti dell'amministrazione pubblica» sono soppresse. Alla lettera f), le parole: «Ministro del tesoro, bilancio e programmazione economica» sono sostituite dalle seguenti: «dal Ministro dell'economia e delle finanze»; d) il secondo periodo del comma 3 e' soppresso; 43) all'art. 205-bis: a) alla lettera a) del comma 3, le parole: «L'erogazione dell'intero importo messo a disposizione al momento della contrazione dell'apertura di credito ha luogo nel termine massimo di tre anni, ferma restando la possibilita' per l'ente locale di disciplinare contrattualmente le condizioni economiche ((di un eventuale utilizzo parziale;» sono soppresse)); b) dopo il comma 3 e' inserito il seguente: «3-bis. Il contratto di cui al comma 3 puo' prevedere l'erogazione dei singoli tiraggi sulla base di scritture private ovvero di atti di quietanza, fermo restando, al termine di periodi di tempo contrattualmente predeterminati, la formalizzazione dell'insieme dei tiraggi effettuati con unico atto pubblico.»; 44) all'art. 206: a) al comma 1, la parola: «annuale» e' sostituita dalle seguenti: «di previsione»; b) il secondo periodo del comma 1 e' soppresso; 45) all'art. 207: a) al comma 1, dopo le parole: «dalle comunita' montane di cui fanno parte» sono aggiunte le seguenti: «che possono essere destinatari di contributi agli investimenti finanziati da debito, come definiti dall'art. 3, comma 18, lettere g) ed h), della legge 24 dicembre 2003, n. 350.»; b) al comma 3, dopo le parole: «anche a favore di terzi» sono inserite le seguenti: «, che possono essere destinatari di contributi agli investimenti finanziati da debito, come definiti dall'art. 3, comma 18, lettere g) ed h), della legge 24 dicembre 2003, n. 350,»; c) dopo il comma 4 e' aggiunto, in fine, il seguente: «4-bis. Con il regolamento di contabilita' l'ente puo' limitare la possibilita' di rilasciare fideiussioni.»; 46) alla lettera b) del comma 1 all'art. 208, le parole: «lire 1 miliardo» sono sostituite dalle seguenti: «cinquecentomila euro»; 47) all'art. 209, dopo il comma 3 e' aggiunto il seguente: «3-bis. Il tesoriere tiene contabilmente distinti gli incassi di cui all'art. 180, comma 3, lettera d). I prelievi di tali risorse sono consentiti solo con i mandati di pagamento di cui all'art. 185, comma 2, lettera i). E' consentito l'utilizzo di risorse vincolate secondo le modalita' e nel rispetto dei limiti previsti dall'art. 195.»; 48) dopo il comma 1 dell'art. 215 e' aggiunto il seguente: «1-bis. Il tesoriere non gestisce i codici della transazione elementare di cui agli articoli da 5 a 7, del decreto legislativo 23 giugno 2011, n. 118, inseriti nei campi liberi dell'ordinativo a disposizione dell'ente.»; 49) all'art. 216: a) al comma 1 le parole: «solo se i mandati risultano emessi entro i limiti dei rispettivi interventi stanziati in bilancio o dei capitoli per i servizi per conto di terzi» sono sostituite dalle seguenti: «nei limiti degli stanziamenti di cassa. I mandati in conto competenza non possono essere pagati per un importo superiore alla differenza tra il relativo stanziamento di competenza e la rispettiva quota riguardante il fondo pluriennale vincolato.». Al secondo periodo, dopo le parole: «debitamente esecutive» sono aggiunte, in fine, le seguenti: «riguardanti l'esercizio in corso di gestione. Il tesoriere gestisce solo il primo esercizio del bilancio di previsione e registra solo le delibere di variazione del fondo pluriennale vincolate effettuate entro la chiusura dell'esercizio finanziario.»; b) al comma 2, dopo le parole: «se privo della codifica» sono aggiunte, in fine, le seguenti: «,compresa la codifica SIOPE di cui all'art. 14 della legge 31 dicembre 2009, n. 196. Il tesoriere non gestisce i codici della transazione elementare di cui agli articoli da 5 a 7, del decreto legislativo 23 giugno 2011, n. 118, inseriti nei campi liberi del mandato a disposizione dell'ente»; c) il comma 3 e' sostituito dal seguente: «3. I mandati in conto residui non possono essere pagati per un importo superiore all'ammontare dei residui risultanti in bilancio per ciascun programma.»; 50) all'art. 222 le parole: «per i comuni, le province, le citta' metropolitane e le unioni di comuni» e «e per le comunita' montane ai primi due titoli» sono soppresse; 51) all'art. 224, dopo il comma 1 e' aggiunto il seguente: «1-bis. Il regolamento di contabilita' dell'ente disciplina le modalita' di svolgimento della verifica straordinaria di cassa.»; 52) alla lettera c) del comma 1 dell'art. 225, dopo la parola: «conservazione» sono inserite le seguenti: «per almeno cinque anni» e la parola: «periodiche» e' soppressa; 53) all'art. 226: a) al comma 2, le parole: «su modello approvato col regolamento di cui all'art. 160» sono sostituite dalle seguenti: «su modello di cui all'allegato n. 17 al decreto legislativo 23 giugno 2011, n. 118»; b) alla lettera a) del comma 2 la parola: «risorsa» e' sostituita dalla seguente: «tipologia», la parola: «intervento» e' sostituita dalla seguente: «programma», le parole: «nonche' per ogni capitolo di entrata e di spesa per i servizi per conto di terzi» sono soppresse; c) alla lettera c) del comma 2, la parola: «meccanografici» e' sostituita dalla seguente: «informatici»; 54) all'art. 227: a) al comma 1, dopo la parola: «rendiconto» sono inserite le seguenti: «della gestione», le parole: «ed il conto del patrimonio» sono sostituite dalle seguenti: «e lo stato patrimoniale»; b) il comma 2 e' sostituito dal seguente: «2. Il rendiconto della gestione e' deliberato entro il 30 aprile dell'anno successivo dall'organo consiliare, tenuto motivatamente conto della relazione dell'organo di revisione. La proposta e' messa a disposizione dei componenti dell'organo consiliare prima dell'inizio della sessione consiliare in cui viene esaminato il rendiconto entro un termine, non inferiore a venti giorni, stabilito dal regolamento di contabilita'.»; c) dopo il comma 2-bis e' inserito il seguente: «2-ter. Contestualmente al rendiconto, l'ente approva il rendiconto consolidato, comprensivo dei risultati degli eventuali organismi strumentali secondo le modalita' previste dall'art. 11, commi 8 e 9, del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.»; d) il comma 3 e' sostituito dal seguente: «3. Nelle more dell'adozione della contabilita' economico-patrimoniale, gli enti locali con popolazione inferiore a 5.000 abitanti che si avvalgono della facolta', prevista dall'art. 232, non predispongono il conto economico, lo stato patrimoniale e il bilancio consolidato.»; e) il comma 5 e' sostituito dal seguente: «5. Al rendiconto della gestione sono allegati i documenti previsti dall'art. 11 comma 4 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, ed i seguenti documenti: a) l'elenco degli indirizzi internet di pubblicazione del rendiconto della gestione, del bilancio consolidato deliberati e relativi al penultimo esercizio antecedente quello cui si riferisce il bilancio di previsione, dei rendiconti e dei bilanci consolidati delle unioni di comuni di cui il comune fa parte e dei soggetti considerati nel gruppo "amministrazione pubblica" di cui al principio applicato del bilancio consolidato allegato al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, relativi al penultimo esercizio antecedente quello cui il bilancio si riferisce. Tali documenti contabili sono allegati al rendiconto della gestione qualora non integralmente pubblicati nei siti internet indicati nell'elenco; b) la tabella dei parametri di riscontro della situazione di deficitarieta' strutturale; c) il piano degli indicatori e dei risultati di bilancio.»; f) dopo il comma 6, sono aggiunti, in fine, i seguenti: «6-bis. Nel sito internet dell'ente, nella sezione dedicata ai bilanci, e' pubblicata la versione integrale del rendiconto della gestione, comprensivo anche della gestione in capitoli, dell'eventuale rendiconto consolidato, comprensivo della gestione in capitoli ed una versione semplificata per il cittadino di entrambi i documenti. 6-ter. I modelli relativi alla resa del conto da parte degli agenti contabili sono quelli previsti dal decreto del Presidente della Repubblica 31 gennaio 1996, n. 194. Tali modelli sono aggiornati con le procedure previste per l'aggiornamento degli allegati al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. 6-quater. Contestualmente all'approvazione del rendiconto, la giunta adegua, ove necessario, i residui, le previsioni di cassa e quelle riguardanti il fondo pluriennale vincolato alle risultanze del rendiconto, fermo restando quanto previsto dall'art. 188, comma 1, in caso di disavanzo di amministrazione.»; 55) all'art. 228 sono apportate le seguenti modificazioni: a) al comma 1, le parole: «autorizzatoria contenuta nel bilancio annuale rispetto alle previsioni» sono sostituite dalle seguenti: «rispetto alle autorizzazioni contenute nel primo esercizio considerato nel bilancio di previsione»; b) al comma 2, le parole: «risorsa dell'»sono sostituite dalle seguenti: «tipologia di» e le parole: «intervento della» sono sostituite dalle seguenti: «programma di» e le parole: «nonche' per ciascun capitolo dei servizi per conto di terzi,» sono soppresse; c) alla lettera b) del comma 2, dopo le parole: «di quella ancora da pagare» sono aggiunte le seguenti: «e di quella impegnata con imputazione agli esercizi successivi rappresentata dal fondo pluriennale vincolato»; d) al comma 3, dopo le parole: «in parte dei residui» sono aggiunte le seguenti: «e della corretta imputazione in bilancio, secondo le modalita' di cui all'art. 3, comma 4, del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni»; e) al comma 4, le parole: «contabile di gestione e con quello contabile di amministrazione, in termini di avanzo, pareggio o disavanzo» sono sostituite dalle seguenti: «della gestione di competenza e della gestione di cassa e del risultato di amministrazione alla fine dell'esercizio»; f) il comma 5 e' sostituito dal seguente: «5. Al rendiconto sono allegati la tabella dei parametri di riscontro della situazione di deficitarieta' strutturale ed il piano degli indicatori e dei risultati di bilancio. La tabella dei parametri di riscontro della situazione di deficitarieta' strutturale e il piano degli indicatori e dei risultati di bilancio sono altresi' allegati al certificato del rendiconto.»; g) al comma 7, la parola: «sui» e' sostituita dalla seguente: «riguardante», le parole: «gestionali dei servizi degli enti locali indicati» sono sostituite dalla seguente: «contenuti» e le parole: «nella Gazzetta Ufficiale della Repubblica italiana.» sono sostituite dalle seguenti: «nel sito internet del Ministero dell'interno.»; h) al comma 8, le parole: «e le tabelle di cui al comma 5sono approvati con il regolamento di cui all'art. 160» sono sostituite dalle seguenti: «sono predisposti secondo lo schema di cui all'allegato n. 10 al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.»; 56) all'art. 229: a) i commi 1 e 2 sono sostituiti dai seguenti: «1. Il conto economico evidenzia i componenti positivi e negativi della gestione di competenza economica dell'esercizio considerato, rilevati dalla contabilita' economico-patrimoniale ,nel rispetto del principio contabile generale n. 17 e dei principi applicati della contabilita' economico-patrimoniale di cui all'allegato n. 1 e n. 10 al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, e rileva il risultato economico dell'esercizio. 2. Il conto economico e' redatto secondo lo schema di cui all'allegato n. 10 al decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.»; b) i commi 3,4, 5, 6,7, 9 e 10 sono abrogati; 57) all'art. 230: a) alla rubrica, le parole: «conto del patrimonio» sono sostituite dalle seguenti: «Lo stato patrimoniale»: b) il comma 1 e' sostituito dal seguente: «1. Lo stato patrimoniale rappresenta i risultati della gestione patrimoniale e la consistenza del patrimonio al termine dell'esercizio ed e' predisposto nel rispetto del principio contabile generale n. 17 e dei principi applicati della contabilita' economico-patrimoniale di cui all'allegato n. 1 e n. 4/3 al decreto legislativo 23 giugno 2011, n. 118, ((e successive modificazioni.»)) c) al comma 2, le parole: «, suscettibili di valutazione ed attraverso la cui rappresentazione contabile ed il relativo risultato finale differenziale e' determinata la consistenza netta della dotazione patrimoniale» sono soppresse. Dopo il primo periodo e' aggiunto il seguente: «Attraverso la rappresentazione contabile del patrimonio e' determinata la consistenza netta della dotazione patrimoniale.»; d) al comma 3, le parole: «nel conto del patrimonio» sono sostituite dalle seguenti: «nello stato patrimoniale»; e) al comma 4, le parole: «come segue:» sono sostituite dalle seguenti: «, secondo le modalita' previste dal principio applicato della contabilita' economico-patrimoniale di cui all'allegato n. 4/3 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.» e le lettere a), b), c), d), e), f), g) ed h) sono soppresse; f) il comma 5 e' sostituito dal seguente: «5. Lo stato patrimoniale comprende anche i crediti inesigibili, stralciati dal conto del bilancio, sino al compimento dei termini di prescrizione. Al rendiconto della gestione e' allegato l'elenco di tali crediti distintamente rispetto a quello dei residui attivi.»; g) il comma 6 e' sostituito dal seguente: «6. Il regolamento di contabilita' puo' prevedere la compilazione di conti patrimoniali di inizio e fine mandato degli amministratori.»; h) il comma 9 e' sostituito dal seguente: «9. Lo stato patrimoniale e' redatto secondo lo schema di cui all'allegato n. 4/3 al decreto legislativo 23 giugno 2011, n. 118 e successive modificazioni e integrazioni.»; f) dopo il comma 9 e' inserito il seguente: «9-bis. Nell'apposita sezione dedicata ai bilanci del sito internet degli enti locali e' pubblicato il rendiconto della gestione, il conto del bilancio articolato per capitoli, e il rendiconto semplificato per il cittadino di cui all'art. 11 del decreto legislativo 23 giugno 2011, n. 118 e successive modificazioni e integrazioni.»; 58) l'art. 231 e' sostituito dal seguente: «Art. 231. (La relazione sulla gestione). - 1. La relazione sulla gestione e' un documento illustrativo della gestione dell'ente, nonche' dei fatti di rilievo verificatisi dopo la chiusura dell'esercizio, contiene ogni eventuale informazione utile ad una migliore comprensione dei dati contabili, ed e' predisposto secondo le modalita' previste dall'art. 11, comma 6, del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni.»; 59) l'art. 232 e' sostituito dal seguente: «Art. 232. (Contabilita' economico-patrimoniale). - Gli enti locali garantiscono la rilevazione dei fatti gestionali sotto il profilo economico-patrimoniale nel rispetto del principio contabile generale n. 17 della competenza economica e dei principi applicati della contabilita' economico-patrimoniale di cui agli allegati n. 1 e n. 4/3del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. 2. Gli enti locali con popolazione inferiore a 5.000 abitanti possono non tenere la contabilita' economico-patrimoniale fino all'esercizio 2017.»; 60) dopo l'art. 233 e' inserito il seguente: «Art. 233-bis. (Il bilancio consolidato). - 1. Il bilancio consolidato di gruppo e' predisposto secondo le modalita' previste dal decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni. 2. Il bilancio consolidato e' redatto secondo lo schema previsto dall'allegato n. 11 del decreto legislativo 23 giugno 2011. n. 118, e successive modificazioni. 3. Gli enti locali con popolazione inferiore a 5.000 abitanti possono non predisporre il bilancio consolidato fino all'esercizio 2017.»; 61) all'art. 239: a) al comma 1, lettera b), numero 2),dopole parole:«variazioni di bilancio» sono aggiunte le seguenti: «escluse quelle attribuite alla competenza della giunta, del responsabile finanziario e dei dirigenti, a meno che il parere dei revisori sia espressamente previsto dalle norme o dai principi contabili, fermo restando la necessita' dell'organo di revisione di verificare, in sede di esame del rendiconto della gestione, dandone conto nella propria relazione, l'esistenza dei presupposti che hanno dato luogo alle variazioni di bilancio approvate nel corso dell'esercizio, comprese quelle approvate nel corso dell'esercizio provvisorio.»; b) alla lettera d) del comma 1, dopo le parole: «di deliberazione consiliare» sono inserite le seguenti: «di approvazione». Al secondo periodo, dopo le parole: «La relazione» sono inserite le seguenti: «dedica un'apposita sezione all'eventuale rendiconto consolidato di cui all'art. 11, commi 8 e 9, e»; c) dopo la lettera d) e' inserita la seguente: «d-bis) relazione sulla proposta di deliberazione consiliare di approvazione del bilancio consolidato di cui all'art. 233-bis e sullo schema di bilancio consolidato, entro il termine previsto dal regolamento di contabilita' e comunque non inferiore a 20 giorni, decorrente dalla trasmissione della stessa proposta approvata dall'organo esecutivo;»; 62) al comma 4 dell'art. 246, le parole: «bilancio preventivo per l'esercizio successivo» sono sostituite dalle seguenti: «bilancio di previsione per il triennio successivo»; 63) al primo periodo del comma 1 dell'art. 250, dopo le parole: «nell'ultimo bilancio approvato» sono inserite le seguenti: «con riferimento all'esercizio in corso,»; 64) al primo periodo del comma 5 dell'art. 268-bis, le parole: «nei bilanci annuale e pluriennale» sono sostituite dalle seguenti: «in ciascuno degli esercizi considerati nel bilancio di previsione.».

### Art. 75. - (( (Adeguamento della definizione di indebitamento).))

((

1. Nella legge 24 dicembre 2003, n. 350, sono apportate le seguenti modificazioni:

- a) il comma 17 dell'art. 3 e' sostituito dal seguente: «17. Per gli enti di cui al comma 16, costituiscono indebitamento, agli effetti dell'art. 119, sesto comma, della Costituzione, l'assunzione di mutui, l'emissione di prestiti obbligazionari, le cartolarizzazioni relative a flussi futuri di entrata, a crediti e a attivita' finanziarie e non finanziarie, l'eventuale somma incassata al momento del perfezionamento delle operazioni derivate di swap (cosiddetto upfront), le operazioni di leasing finanziario stipulate dal 1° gennaio 2015, il residuo debito garantito dall'ente a seguito della definitiva escussione della garanzia. Inoltre, costituisce indebitamento il residuo debito garantito a seguito dell'escussione della garanzia per tre annualita' consecutive, fermo restando il diritto di rivalsa nei confronti del debitore originario. Dal 2015, gli enti di cui al comma 16 rilasciano garanzie solo a favore dei soggetti che possono essere destinatari di contributi agli investimenti finanziati da debito e per le finalita' definite dal comma 18.Non costituiscono indebitamento, agli effetti del citato art. 119, le operazioni che non comportano risorse aggiuntive, ma consentono di superare, entro il limite massimo stabilito dalla normativa statale vigente, una momentanea carenza di liquidita' e di effettuare spese per le quali e' gia' prevista idonea copertura di bilancio.»;
- b) al comma 18 dell'art. 3, le parole: « Trasferimenti in conto capitale» sono sostituite dalle seguenti: «Contributi agli investimenti e i trasferimenti in conto capitale a seguito di escussione delle garanzie».

))

### Art. 76. - (( (Adeguamento delle disposizioni in materia di trasparenza dei bilanci).))

((

1. Gli enti soggetti al titolo I del presente decreto pubblicano nel proprio sito istituzionale, nella sezione dedicata ai bilanci, tutti i documenti contabili previsti dai rispettivi ordinamenti.

2. Dal 1° gennaio 2015 agli enti di cui al comma 1 non si applicano:

- a) l'art. 6 della legge n. 25 febbraio 1987, n. 67, recante rinnovo della legge 5 agosto 1981, n. 416, recante disciplina delle imprese editrici e provvidenze per l'editoria;
- b) il decreto del Presidente della Repubblica 15 febbraio 1989, n. 90, recante approvazione dei modelli degli estratti di bilancio che gli enti pubblici devono compilare e pubblicare sui giornali quotidiani e periodici, ai sensi dell'art. 6 della legge n. 25 febbraio 1987, n. 67.

))

### Art. 77. - (( (Abrogazioni).))

((

1. A decorrere dal 1° gennaio 2015 sono abrogati:

- a) l'art. 10 della legge 16 maggio 1970, n. 281;
- b) la legge 6 dicembre 1973, n. 853, concernente autonomia contabile e funzionale dei consigli regionali delle regioni a statuto ordinario;
- c) il decreto legislativo 28 marzo 2000, n. 76, concernente principi fondamenti e norme di coordinamento in materia di bilancio e di contabilita' delle regioni in attuazione dell'art. 1, comma 4, della legge 25 giugno 1999, n. 208;
- d) il decreto legislativo 12 aprile 2006 n. 170, concernente ricognizione dei principi fondamentali in materia di armonizzazione dei bilanci pubblici, a norma dell'art. 1 della legge 5 giugno 2003, n. 131;
- e) il comma 4 dell'art. 6 del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, fatta salva l'applicazione ai fini della rendicontazione dell'esercizio 2014;
- f) il comma 17 dell'art. 6 del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, fatta salva l'applicazione all'esercizio 2014;
- g) l'art. 4, comma 3, della legge 14 gennaio 2013, n. 10, concernente norme per lo sviluppodegli spazi verdi urbani;
- h) al decreto del Presidente della Repubblica 31 gennaio 1996, n. 194: 1) le lettere da a) a v) del comma 1 dell'art. 1; 2) i commi 2, 3 e 5 dell'art. 1; 3) gli articoli 2, 3 e 4.

))

## Disposizioni finali e transitorie))

### Art. 78. - (( (Sperimentazione).))

((

1. Al fine di verificare l'effettiva rispondenza del nuovo assetto contabile definito dal presente decreto alle esigenze conoscitive della finanza pubblica e per individuare eventuali criticita' del sistema e le conseguenti modifiche intese a realizzare una piu' efficace disciplina della materia, a decorrere dal 2012 e' avviata una sperimentazione, della durata di tre esercizi finanziari, riguardante l'attuazione delle disposizioni di cui al titolo I, con particolare riguardo all'adozione del bilancio di previsione finanziario annuale di competenza e di cassa, e della classificazione per missioni e programmi di cui all'art. 33.

2. Ai fini della sperimentazione, entro 120 giorni dalla data di entrata in vigore del presente decreto, con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro dell'economia e delle finanze, di concerto con il Ministro dell'interno, il Ministro delle riforme per il federalismo, il Ministro per i rapporti con le regioni e per la coesione territoriale e il Ministro per la semplificazione normativa, d'intesa con la Conferenza unificata di cui all'art. 8 del decreto legislativo 28 agosto 1997, n. 281, sono definiti le modalita' della sperimentazione, i principi contabili applicati di cui all'art. 3, il livello minimo di articolazione del piano dei conti integrato comune e del piano dei conti integrato di ciascun comparto di cui all'art. 4, la codifica della transazione elementare di cui all'art. 6, gli schemi di bilancio di cui agli articoli 11 e 12, i criteri di individuazione dei Programmi sottostanti le missioni, le metodologie comuni ai diversi enti per la costruzione di un sistema di indicatori di risultato semplici, misurabili e riferiti ai programmi del bilancio e le modalita' di attuazione della classificazione per missioni e programmi di cui all' art. 17 e le eventuali ulteriori modifiche e integrazioni alle disposizioni concernenti il sistema contabile delle amministrazioni coinvolte nella sperimentazione di cui al comma 1. Il decreto di cui al primo periodo prevede la sperimentazione della tenuta della contabilita' finanziaria sulla base di una configurazione del principio della competenza finanziaria secondo la quale le obbligazioni attive e passive giuridicamente perfezionate, che danno luogo a entrate e spese per l'ente di riferimento sono registrate nelle scritture contabili con l'imputazione all'esercizio nel quale esse vengono a scadenza, ferma restando, nel caso di attivita' di investimento che comporta impegni di spesa che vengono a scadenza in piu' esercizi finanziari, la necessita' di predisporre, sin dal primo anno, la copertura finanziaria per l'effettuazione della complessiva spesa dell'investimento. Ai fini della sperimentazione, il bilancio di previsione annuale e il bilancio di previsione pluriennale hanno carattere autorizzatorio, costituendo limite agli impegni di spesa, fatta eccezione per le partite di giro, i servizi per conto di terzi e per i rimborsi delle anticipazioni di cassa. Per i comuni con popolazione inferiore a 5000 abitanti possono essere sperimentati sistemi di contabilita' e schemi di bilancio semplificati. La tenuta della contabilita' delle amministrazioni coinvolte nella sperimentazione e' disciplinata dalle disposizioni di cui al titolo I e al decreto di cui al presente comma, nonche' dalle discipline contabili vigenti alla data di entrata in vigore del presente decreto, in quanto con esse compatibili. Per le regioni, in via sperimentale, puo' essere verificata la possibilita' di individuare appositi programmi anche di carattere strumentale in relazione alle specifiche competenze ad esse attribuiti e nel rispetto dei principi di omogeneita' di classificazione delle spese di cui all'art. 12 della presente legge. Al termine del primo esercizio finanziario in cui ha avuto luogo la sperimentazione e, successivamente, ogni sei mesi, il Ministro dell'economia e delle finanze trasmette alle Camere una relazione sui relativi risultati. Nella relazione relativa all'ultimo semestre della sperimentazione, il Governo fornisce una valutazione sulle risultanze della medesima sperimentazione, anche ai fini dell'attuazione del comma 4.

3. Lo schema del decreto di cui al comma 2 e' trasmesso alle Camere, ai fini dell'acquisizione del parere della Commissione parlamentare per l'attuazione del federalismo fiscale e delle Commissioni parlamentari competenti per i profili di carattere finanziario, da esprimere entro trenta giorni dalla trasmissione. Decorso tale termine, il decreto puo' comunque essere adottato.

4. Entro 150 giorni dalla data di entrata in vigore del presente decreto, con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro dell'economia e delle finanze, di concerto con il Ministro dell'interno e con il Ministro per i rapporti con le regioni e per la coesione territoriale, d'intesa con la Conferenza unificata ai sensi dell' art. 3 del decreto legislativo 28 agosto 1997, n. 281, sono individuate le amministrazioni coinvolte nella sperimentazione, secondo criteri che tengano conto della collocazione geografica e della dimensione demografica. Per le amministrazioni non interessate dalla sperimentazione continua ad applicarsi, sino all'entrata in vigore dei decreti legislativi di cui al comma 5, la vigente disciplina contabile.

5. In considerazione degli esiti della sperimentazione, con i decreti legislativi di cui all'art. 2, comma 7, della legge 5 maggio 2009, n. 42, sono definiti i contenuti specifici del principio della competenza finanziaria di cui al punto 16 dell'allegato n. 1 e possono essere ridefiniti i principi contabili generali; inoltre sono definiti i principi contabili applicati di cui all'art. 3, il livello minimo di articolazione del piano dei conti integrato comune e del piano dei conti integrato di ciascun comparto di cui all'art. 4, la codifica della transazione elementare di cui all'art. 6, gli schemi di bilancio di cui agli articoli 11 e 12, i criteri di individuazione dei Programmi sottostanti le missioni, le metodologie comuni ai diversi enti per la costruzione di un sistema di indicatori di risultato semplici, misurabili e riferiti ai programmi del bilancio, le modalita' di attuazione della classificazione per missioni e programmi di cui all' art. 17, nonche' della definizione di spese rimodulabili e non rimodulabili di cui all'art. 16.

6. Il decreto del Presidente del Consiglio dei ministri di cui al comma 2, individua un sistema premiante, senza nuovi o maggiori oneri per la finanza pubblica, a favore delle amministrazioni pubbliche che partecipano alla sperimentazione.

))

### Art. 79. - (( (Disposizioni concernenti le Regioni a statuto speciale e le province autonome di Trento e di Bolzano).))

((

1. La decorrenza e le modalita' di applicazione delle disposizioni di cui al presente decreto legislativo nei confronti delle Regioni a statuto speciale e delle province autonome di Trento e di Bolzano, nonche' nei confronti degli enti locali ubicati nelle medesime Regioni speciali e province autonome, sono stabilite, in conformita' con i relativi statuti, con le procedure previste dall'art. 27 della legge 5 maggio 2009, n. 42.

))

### Art. 80. - (( (Disposizioni finali ed entrata in vigore).))

((

1. Le disposizioni del Titolo I, III, IV e V si applicano, ove non diversamente previsto nel presente decreto, a decorrere dall'esercizio finanziario 2015, con la predisposizione dei bilanci relativi all'esercizio 2015 e successivi, e le disposizioni del Titolo II si applicano a decorrere dall'anno successivo a quello di entrata in vigore del presente decreto legislativo.

2. Per quanto non diversamente disposto dal titolo II del presente decreto, restano confermate le disposizioni di cui all'art. 5 del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni.

3. All'attuazione del presente decreto si provvede nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente e, comunque, senza nuovi o maggiori oneri per la finanza pubblica.

4. Ogni richiamo agli articoli 36, 37 e 38 del decreto legislativo 23 giugno 2011, n. 118, contenuti in decreti, disposizioni di legge e atti aventi forza di legge vigenti, deve intendersi riferito, rispettivamente, agli articoli 78, 79 e 80 del presente decreto.))

